*********************************************************************************************************************************
/*	PROJECT INFORMATION
	Author: BB	
	Date started: 15/9/10 (based on 2009 BHPS files)
	Date completed:
	END OF PROJECT INFORMATION		*/
*********************************************************************************************************************************

// Options and clearing data
set more off, permanently
*version 11							// I changed this on 20/12/2010, but primarily because the previous 'version 10' didn't appear to have an effect					
version 12							// For the revisions in 2013
clear all
macro drop _all						// Must do this BEFORE setting the dir globals below!
pause on
 

// Directories
/* DIRECTORIES FOR MAIN COMPUTER */
capture cd "C:\Users\bpb\Desktop\Work Reference"
if _rc==0	{
	global dodir 			"C:\Users\bpb\Dropbox\Thesis\BHPS"
	global workdatadir 		"C:\Users\bpb\Dropbox\Thesis\Work data"					// Check that this matches the path in 0_work_master.do (the file that generates the JEM)
	global dir 				"C:\Users\bpb\Desktop\Work Reference\PhD datasets\BHPS (SN5151)"
	global worksourcedir 	"C:\Users\bpb\Desktop\Work Reference\PhD datasets\Work-related datasets\1. Merged data"	
	/**/ 	}
		/* Old file locations that were done by hand
			LSE
				global dir 		"Z:\PhD datasets\BHPS (SN5151)"
				global dodir "Z:\SYNC\Uni - current\BHPS"
				global sourcedir "Z:\PhD datasets\BHPS (SN5151)\stata8"					// Where the source datasets are kept - but want to keep mine separate otherwise they get lost...
				global workdatadir "Z:\SYNC\Uni - current\Work data"		// Check that this matches the path in 0_work_master.do (the file that generates the JEM)
				global worksourcedir "Z:\PhD datasets\Work-related datasets\1. Merged data"
			ABACUS COMPUTER 
				global dir "S:\BHPS (SN5151)"
				global dodir "$dir\1. do files"
				global sourcedir "$dir\stata8"		// Where the source datasets are kept - but want to keep mine separate otherwise they get lost...
				global workdatadir "S:\Work data"		// Check that this matches the path in 0_work_master.do (the file that generates the JEM)
				global worksourcedir "S:\Work-related datasets\1. Merged data"
				ssc install gllamm, replace
			*/
/* RELATIVE FOLDERS */
cd "$dir"
	global sourcedir 		"${dir}\stata8"					// Where the source datasets are kept - but want to keep mine separate otherwise they get lost...
	global tabdir 			"$dodir\Tables"
	global graphdir 		"$dodir\Graphs"
	global JEMdir 			"$workdatadir\JEM"						// Check that this matches the path in 0_work_master.do (the file that generates the JEM)
global logdir "$dodir\Logs"
	capture log close
	local cmth = month(date(c(current_date), "DMY"))
	local cyr  = year(date(c(current_date), "DMY"))
	log using "$logdir\BHPS-`cyr'-`cmth'.txt", text append
	capture cmdlog close
	cmdlog using "$logdir\cmdlog-BHPS-`cyr'-`cmth'.txt", append
/* PROGRAMS AND OTHER GLOBALS*/
capture program drop time 			// used to time-stamp regression outputs in the log file
	program define time 
		dis "`c(current_time)' on `c(current_date)'"
	end 
do "$workdatadir\catlist.do"							// This needs loading for some of the data preparation and some of the analysis 
global filename "BHPSv2-04"									// This is the name of the main file used: this should be changed for later version numbers and revisions	
global JEMversno "v2-03"									// Check that this matches the version number in 0_work_master.do


// Ending
capture set maxvar 10000
capture set matsize 5000
dis in red _newline(2) "Note that the file locations for creating the JEM were not updated for revisions in 2013" ///
	_newline(2) "Type 'set more off' by hand"
// Adding packages - sometimes have to do this manually (I've removed the 'set mem' function here as unnecesary in Stata 12
pause "Type BREAK to avoid installing packages
	capture net install dm79, from(http://www.stata.com/stb/stb56)		// For SVMAT2 (used in 2_JEM_EB.do)
	capture net install dm88_1.pkg, from(http://www.stata-journal.com/software/sj5-4/) replace								// The RENVARS  command (for renaming variables, used in data creation)
	*	capture net install mfpx, from(http://www.homepages.ucl.ac.uk/~ucakjpr/stata)		// Includes MFP_PLUS
	capture net install mat2txt, from(http://fmwww.bc.edu/RePEc/bocode/m/), replace
	capture ssc install estout, replace
	capture net install estwrite, from(http://fmwww.bc.edu/RePEc/bocode/e)
	capture ssc install gllamm, replace
exit 				



//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////
// Creating the data files
//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////

do "$dodir\1_BHPS_initial.do"													// Merges the waves into a long dataset, currently only with WLD vars
pause off																		// The pause is because the code below the pause is taken from the table above it (but shouldn't change) - it's the modal SIC92 for each SIC80
do "$dodir\1_BHPS_SIC80to92.do"													// Recodes SIC80 into SIC92 using the BHPS dual-coded waves (4, 7 and 11)
pause on
do "$dodir\1_BHPS_occ+SES.do"													// MUST BE DONE AT THIS STAGE - adds the BB bespoke occupational groups, + imports CAMSIS scales: 
/**/																					// uses 1_data_BBsoc90.do, 1_data_BBsoc90.do, soc_label.doi (from $workdatadir) and 
note: TS Working JEM dataset - v2.04, 25/4/13 (first post-PhD changes, for JSP reviewer comments)		// Make sure this matches $filename above
	compress
	save $filename, replace

	
* JEM addition
/* 
use $filename, replace
// These can be removed when the dataset is next created - they're in BHPS_initial.do
capture drop tempsick			// An error in how this was created
	gen tempsick = (jboffy==3) if (jbhas==1 | jboff==1)
	label var tempsick "Temporarily sick from existing job"
clonevar nonemployN = nonemploy
	replace nonemployN = 0 if ltsick==1
	label var nonemployN "Non-emp exc ltsick (for specificity analyses)"
clonevar FnonemployN = Fnonemploy
	replace FnonemployN = 0 if Fltsick==1
	label var FnonemployN "t+1 Non-emp exc ltsick (for specificity analyses)"
tsset _pid wave
gen Fage = F.age
gen F2age = F2.age
gen F2IBreceipt = F2.IBreceipt
gen F2wldB = F2.wldB
replace fulltimeH = . if (jbhrs<0 | jbot<0 | jbhrs>=.)
gen CSnew = (cs==1 & sic92_1A==12 & age<60)
* The new industry subgroups of soc90_BB
merge m:1 soc90_BB sic92_1A using "$worksourcedir\soc90_BBr.dta"
	gen soc90_BBR = cond(soc90_BBr>=., soc90_BB, soc90_BBr)
	label var soc90_BBR "Occupation-industry subgroups - BB vers of SOC90"
	drop _merge soc90_BBr
*/
global JEMv2file 	"$dir\JEMworking_${filename}"					// This is a temporary working file based on $filename, with the JEM ultimately merged into JEM_$filename
	use `"$worksourcedir\1_merged_stage3_$JEMversno.dta"', replace
	do "$workdatadir\2_JEM_fixed.do"								// The main Job Exposure Matrices (JEMs), treating occupations as fixed effects
	compress
	save JEM_${filename}, replace										// Needs to be saved so the EB estimates can be merged in separately
	* Empirical Bayes estimates, plus tidying-up
	use `"$worksourcedir\1_merged_stage3_$JEMversno.dta"', replace
	dis in red "Note that JEM has not been recreated - currently EB version is commented out"
	pause See note
	do "$workdatadir\2_JEM_EB.do"									// The JEMs treating occupations as random effects, then using Empirical Bayes (EB) estimates (used to be 2_JEM_C1 & 2_JEM_D1)
	* Tertiles
	global if1 		"age>=20 & ((age<65 & sex==1) | (age<60 & sex==2)) & region2<=11 & employR==1 & jbsemp==1 & wave<=2006 & ivfio==1 & Fivfio==1 & pidselect>=0 & pidselect<=1"
	do "$dodir\1_BHPS_cutoffs.do"							// The tertiles of D-C must be done using the $if1 subsample, otherwise they're not tertiles...  Also looks at tertile changes 1992-2006
	* Ending
	compress
	note: TS Working JEM dataset - v2.04, (one new var for JSP reviewer, 2013/4)		// Make sure this matches $filename above
save JEM_$filename, replace



//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////
// The results
//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////

// Descriptives 
use JEM_$filename, replace
do "$dodir\2_BHPS_Desc.do"

// WLD analysis
use JEM_$filename, replace
do "$dodir\2_BHPS_WLDresults.do"

// IB receipt analysis
use JEM_$filename, replace
/*
use JEM_BHPSv2-03, replace			// While waiting for RENVARS to install
*/
do "$dodir\2_BHPS_IBresults.do"

// Multiple imputation analyses (cross-sectional)
capture ssc install mim, replace				
	capture ssc install ice, replace				
	net install mi_ice, from(http://www.homepages.ucl.ac.uk/~ucakjpr/stata/)
clear
	clear matrix
	set mem 20000m
use "JEM_$filename", replace
do "$dodir\2_BHPS_ICE.do"


