*********************************************************************************************************************************
/*	PROJECT INFORMATION
	Author: BB	
	Date started: May 2010
	Date completed:
	Other .do files linked to this: see list below
	END OF PROJECT INFORMATION		*/
*********************************************************************************************************************************

// Options and clearing data
set more off, permanently
pause on 
clear all
macro drop _all						// Must do this BEFORE setting the dir globals below!
*version 10							// This is what it was done, but changed to v12 for JSP reviewer comments in April 2013
*set mem 500m
set maxvar 10000
set matsize 5000

// Directories
/* DIRECTORIES FOR MAIN COMPUTER */
capture cd "C:\Users\bpb\Desktop\Work Reference"
if _rc==0	{
	global dir		 		"C:\Users\bpb\Dropbox\Thesis\Work data"					// Check that this matches the path in 0_work_master.do (the file that generates the JEM)
	global dodir 			"$dir"
	global workingdir		"C:\Users\bpb\Desktop\Work Reference\PhD datasets\Work-related datasets\1. Merged data"
	global worksourcedir 	"$workingdir"											// Not quite sure (Apr13) why this features in the code
	/**/ 	}
		/* Old file locations that were done by hand
		/* DIRECTORIES FOR MAIN COMPUTER */
		global dir "Z:\SYNC\Uni - current\Work data"		// Only other directories referred to are subdirectories, mainly Graphs\ for exporting graphs
		global dodir  	"$dir"
		*global workingdir "C:\Documents and Settings\baumberg\Desktop\Working data"		// Where I keep the datafiles - which in this case, I don't sync
		global workingdir 		"Z:\PhD datasets\Work-related datasets\1. Merged data"
		global worksourcedir 	"Z:\PhD datasets\Work-related datasets\1. Merged data"		// I stupidly gave the directories different names in the BHPS & Workdata files - this is the BHPS name
		/* DIRECTORIES FOR ABACUS COMPUTER 
		global dir "S:\Work data"
		global workingdir 		"S:\Work-related datasets\1. Merged data"
		global worksourcedir 	"S:\Work-related datasets\1. Merged data"			 		// I stupidly gave the directories different names in the BHPS & Workdata files - this is the BHPS name
		global dodir "$dir"
		ssc install gllamm, replace
		*/ */
/* RELATIVE FOLDERS */
cd "$workingdir"
	global graphdir	"$dir\Graphs"
	global tabdir	"$dir\Tables"
	global JEMdir	"$dir\JEM"		// For outputting the JEMs too - good to separate this from other tables, as used in a different chapter
global logdir "$dodir\Logs"
	capture log close
	local cmth = month(date(c(current_date), "DMY"))
	local cyr  = year(date(c(current_date), "DMY"))
	log using "$logdir\BHPS-`cyr'-`cmth'.txt", text append
	capture cmdlog close
	cmdlog using "$logdir\cmdlog-BHPS-`cyr'-`cmth'.txt", append
/* PROGRAMS AND OTHER GLOBALS*/
capture program drop time 			// used to time-stamp regression outputs in the log file
	program define time 
		dis "`c(current_time)' on `c(current_date)'"
	end 
global JEMversno "v2-02"				// This is the name of the current version number of the data files: this should be changed for later version numbers and revisions	. 1-18 was superseded by v2 on 4/4/2011 when I started including physical demands

// Loading .do editor 
doedit "$dodir\0_work_master.do"
// Adding packages - sometimes have to do this manually
do "$dir\catlist.do"							// This needs loading for some of the data preparation and some of the analysis 
pause "Type BREAK to avoid installing packages"
	capture net install dm79, from(http://www.stata.com/stb/stb56)		// For SVMAT2 (used in 2_JEM_EB.do)
	capture net install dm88_1.pkg, replace								// The RENVARS  command (for renaming variables, used in data creation)
	*	capture net install mfpx, from(http://www.homepages.ucl.ac.uk/~ucakjpr/stata)		// Includes MFP_PLUS
	capture ssc install estout, replace
	capture net install estwrite, from(http://fmwww.bc.edu/RePEc/bocode/e)
	capture net install sg112_1.pkg, replace		// The BOXTID   command (for checking functional form of covariates)
	capture ssc install collin, replace				// The COLLIN   command (for checking multicollinearity)
	capture ssc install extremes, replace			// The EXTREMES command
	capture net install margeff.pkg, replace		// The MARGEFF  command (in Stata 11 replaced by MARGINS, built-in command)
	* capture ssc install mim, replace				// The MIM      command (for missing data imputation following ICE)
// Exiting
dis in red "USER NOTE: If you want to run this .do file, please remove the 'exit' command on the following line of the .do file"
set more off
exit 								


//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////
// Creating the data files
//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////

pause need to change the version numbers of the created data files - currently I've added Scont, Pscale & Pscale 2 but only in the stage3 files

/////////////////////////////////////////////////////////////////
// Creating the stage 1 data files
do "$dir\1_data_creation.do"								// Goes through the individual raw data files (e.g. EiB), and merges the relevant variables together
do "$dir\1_data_BBsoc.do" 									// NOTE THAT this requires the SUMTAB.DO files.  This creates my own personalised recoding of 4-digit soc00 into smaller groups (see Excel and .do file for details)
note: TS The working file being assembled for analysis - v2.02 (an error in SS97 where hours was excluded, 26/4/11)
	quietly compress
	save "$workingdir\1_merged_stage1_$JEMversno.dta", replace

/////////////////////////////////////////////////////////////////
// Creating the demands and control scales
// *NOTE* that the GLLAMM commands need doing by hand, and are commented out of 1_data_scales (they're just too slow, and should only be re-run if necessary)
use "$workingdir\1_merged_stage1_$JEMversno.dta", replace
do "$dir\1_data_scales.do" 									// Creates demands and control scales 
	dis _newline(3) in red "Cronbach's alpha equivalent for the underlying continuous variables (from Zumbo et al 2007)" ///
		_newline "DEMANDS - ordinal theta = " %4.3f Dordinal_theta 		_newline "CONTROL - ordinal theta = " %4.3f Cordinal_theta
	/* When run 6/8/10 on v1.11 (and also true for v1.16): 	DEMANDS - ordinal theta = 0.705  CONTROL - ordinal theta = 0.878 */
/* READ: The following file has been changed to add two new versions of strain - change vers no when next run through this */ 
do "$dir\1_data_strain.do" 									// Creates the various forms of job strain
* Saving the main data file
note: TS Stage 2: the demands, control and strain scales - v2.02 (change at stage 1), same as 4/4/11	// Remember to change the VERSNO global!
	quietly compress
	save "$workingdir\1_merged_stage2_$JEMversno.dta", replace


/////////////////////////////////////////////////////////////////
// Creating a dataset version with comparable occupational coding from SOC90 and SOC2000
do 	"$dir\1_data_createmap.do" 								// Using .csv input from Excel, this creates the relevant datafiles for the main mapping .do file
* The main proportionally mapped data - and the only one that is used for the JEMs
use "$workingdir\1_merged_stage2_$JEMversno.dta", replace
	keep if order>=53
	do "$dir\1_data_constantocc.do" 							// Expands the data, links to proportional mapping matrices, and gives appropriate weights (see notes)
		do "$dir\2_JEM_SIC80to92.do"								// Recodes SIC80 (EiB) into SIC92
		do "$dir\1_data_BBsoc90.do" 								// Creates the soc90_BB regrouping of soc90_allyr (which is 3-digit) AND creates "$workingdir\soc90_BBr.dta"
		note: TS Stage 3: consistent occ coding for SS01/06 to EiB/WiB/SS97 - v2.02 (now includes the industry-occ sub-splits, soc90_BBR)
		quietly compress
		save "$workingdir\1_merged_stage3_$JEMversno.dta", replace
* Using Mark Williams' LFS job stayers dual-coding
use "$workingdir\1_merged_stage2_$JEMversno.dta", replace
	keep if order>=53
	do "$dir\1_data_constantocc_LFS.do" 							// Expands the data, links to proportional mapping matrices, and gives appropriate weights (see notes)
		do "$dir\2_JEM_SIC80to92.do"								// Recodes SIC80 (EiB) into SIC92
		do "$dir\1_data_BBsoc90.do" 								// Creates the soc90_BB regrouping of soc90_allyr (which is 3-digit)
		note: TS Stage 3: consistent occ coding using Mark Williams' LFS model - v2.02 (change at satge 1, same as v1.18 , 27/11/10)
		quietly compress
		save "$workingdir\1_merged_stage3_LFS_$JEMversno.dta", replace
* I still have a .do file called "1_data_constantocc_rev2.do" - but seems to be identical to "1_data_constantocc.do" (I think previously this used the SOC00 SS01 coding when the main version didn't)

		
		
		
//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////
// Analysis
//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////


// Prep work
do "$dir\catlist.do"											// This loads the program, but does not run it - this is used in 1_results_levels						
use "$workingdir\1_merged_stage2_$JEMversno.dta", replace		
*do "$dir\1_prep_mfp.do"										// Checking functional form of predictors using MFP
do "$dir\1_data_scalechecks.do" 								// Compares the different scales

// Actual tables of results
do "$dir\catlist.do"											// This loads the program, but does not run it - this is used in 1_results_levels						
use "$workingdir\1_merged_stage2_$JEMversno.dta", replace			/* NOTE that the individual .do files often take a file apart and then reload it - so make sure the file is saved before running it) */
	do "$dir\1_results_levels.do" 								// REQUIRES CATLIST TO BE LOADED.  Estimates of levels of demands + control in each occupational group (inc. Empirical Bayes estimates)
	do "$dir\1_results_trends.do"	 							// Trends in the scale variables

use "$workingdir\1_merged_stage3_$JEMversno.dta", replace		
	do "$dir\1_results_soc_allyrs.do"	 						// How far trends in the scale variables are explained by within- vs. between-occupational change (on proportionally mapped data)
use "$workingdir\1_merged_stage3_LFS_$JEMversno.dta", replace		// I think the previous dataset (1_merged_stage2_rev2_$JEMversno.dta), simply because I'm not using Mark Williams version of this now
	do "$dir\1_results_soc_allyrs.do"	 						// How far trends in the scale variables are explained by within- vs. between-occupational change (on proportionally mapped data)

use "$workingdir\1_merged_stage2_$JEMversno.dta", replace		
	do "$dir\1_results_allvartrends.do"							// Trends in each individual question that comparable data exists on
	do "$dir\1_results_sector.do" 								// Trends in demands/control by sector (public vs. private)
	do "$dir\1_results_education.do" 							// Demands/control by educational level


// Creating the JEMs for the BHPS analysis is now done in 0_BHPS_master.do (as these are directly merged into the BHPS file, which needs to be created first)










