/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// BHPS Dataset creation - currently only for basic WLD analyses


/////////////////////////////////////////////////////////////////
// Creating a merged dataset with the relevant data - change the initial local to add more all-wave variables to this

clear

// INDRESP file
local indresp_vars		"wave _pid hid pno hgspn doiy* doim iv1 xrwght xrwtsw1 xrwtuk1 lrwght lrwtuk1 lrwtsw1 sampst ivfio sex age qfedhi fimn fisit race* mlstat mastat nchild region2 tenure opcls2 vote4 lfimpd"       
	local indresp_vars	"`indresp_vars' jbhas jboff jboffy jbsoc jbsoc00 jbsic* jbstat jbsect jbsemp jbterm* jbsize jbhrs jbot jbpen* jbcss? jbmngr jbsat* jbopps j2has jbbgly jblky1 jblky2"	// Job chars
	local indresp_vars	"`indresp_vars' jbsec jbgold jbhgs jbrgsc jbseg hlltw hlltwa hlendw hlsf4? hlsf5? hlsf8 hlstat hlprb? hlghq? hllt* hosp hospch hl2gp "
	local indresp_vars	"`indresp_vars' f117 f125 f134 f116 f158 f118 f119 f120 f123 f126 f127 f128"		 				// Disability bens
	local indresp_vars	"`indresp_vars' paygu jspayg"		// Added April 2013 to deal with reviewer comments	
local count = 1991
foreach w in a b c d e f g h i j k l m n o p q r   {
	use "$sourcedir\\`w'indresp", replace
	ren pid _pid							// This is so that pid is not treated as the id variable in wave p (it is the cross-wave identifier)
	// Generating a wave variable
	gen wave = `count'
	local count = `count' + 1
	renpfix `w'
	// Keeping the variables that appear in this wave
	local this_indresp ""
	foreach checkvar in `indresp_vars'	{
		capture des `checkvar'
		if _rc==0		local this_indresp "`this_indresp' `checkvar'"
		dis "`checkvar'"
		dis "`this_indresp'"
	/* END OF LOOP */					}
	// Creating a tempfile
	keep `this_indresp'
	des
	tempfile D`w'
	save "`D`w''"
/* end of loop */									}
// Adding the tempfiles together and creating a permanent file - based on the last file's datafile, which is already open
foreach w in a b c d e f g h i j k l m n o p q 		{		// This needs to miss off the last file (which is still open)
	append using `D`w''
/* END OF LOOP */										}
save "${filename}_indresp", replace
													
													
// HHSAMP file
local hhsamp_vars		"wave hid psu strata hhorig ivfho_hhsamp"       
local count = 1991
foreach w in a b c d e f g h i j k l m n o p q r   {
	use "$sourcedir\\`w'hhsamp", replace
	// Generating a wave variable
	gen wave = `count'
	local count = `count' + 1
	renpfix `w'
	ren ivfho 	ivfho_hhsamp					// To keep it separate from the XWAVEID/INDRESP versions
	// Keeping the variables that appear in this wave
	local this_hhsamp ""
	foreach checkvar in `hhsamp_vars'	{
		capture des `checkvar'
		if _rc==0		local this_hhsamp "`this_hhsamp' `checkvar'"
		dis "`checkvar'"
		dis "`this_hhsamp'"
	/* END OF LOOP */					}
	// Creating a tempfile
	keep `this_hhsamp'
	des
	tempfile D2`w'
	save "`D2`w''"
/* end of loop */									}
// Adding the tempfiles together and creating a permanent file - based on the last file's datafile, which is already open
foreach w in a b c d e f g h i j k l m n o p q 		{		// This needs to miss off the last file (which is still open)
	append using `D2`w''
/* END OF LOOP */										}
label copy rivfho ivfhoHH
	label values ivfho_hhsamp ivfhoHH
	label define ivfhoHH 1 "demolished/derelict" 2 "business use only" 3 "temp accomm only" 4 "empty at first call" 5 "building not complete" 6 "institut no privt hh" 7 "address not found" ///
		14	"hh composition only" 19 "docs missing or unusable" 20 "refusal to hq" 21 "all refus to int'er" 22 "lang probs no interp" 23 "too old or infirm" 24 "no hh member contact", modify
save "${filename}_hhsamp", replace



// JOBHIST file
local count = 1991
foreach w in a b c d e f g h i j k l m n o p q r   {
	use "$sourcedir\\`w'jobhist", replace
	// Generating a wave variable
	gen wave = `count'
	local count = `count' + 1
	ren pid _pid							// This is so that pid is not treated as the id variable in wave p (it is the cross-wave identifier)
	renpfix `w'
	// The dummies - lj=lost job for reason of...
	gen lj_health = (jhstpy==7)
	gen lj_sacked = (jhstpy==4)
	gen lj_rdndnt = (jhstpy==3)
	gen lj_care   = (jhstpy==10)
	// Date of earliest episode of losing job for health reasons
	gen str datstring1 		= string(jhendm, "%02.0f") + string(jhendy, "%2.0f") if lj_health==1 & jhendm>0
		gen datlostjob 		= date(datstring1, "M19Y")	if jhendy>=10
		replace datlostjob 	= date(datstring1, "M20Y")	if jhendy <10
	gen str datstring2 		= string(jhbgm, "%02.0f") + string(jhbgy, "%2.0f") if lj_health==1 & jhbgm>0
		gen datstrtjob 		= date(datstring2, "M19Y")	if jhbgy>=10
		replace datstrtjob 	= date(datstring2, "M20Y")	if jhbgy <10
	format datlostjob datstrtjob %td
	// Collapsing
	sort _pid jspno
	collapse (first) wave (sum) lj_health lj_sacked lj_rdndnt lj_care (lastnm) datlostjob datstrtjob , by(_pid)
	// Creating a tempfile
	dis "Now saving for wave `count'-1"
	tempfile D9`w'
	save "`D9`w''"
/* end of loop */									}
// Adding the tempfiles together and creating a permanent file - based on the last file's datafile, which is already open
foreach w in a b c d e f g h i j k l m n o p q 		{		// This needs to miss off the last file (which is still open)
	append using `D9`w''
/* END OF LOOP */										}
save "${filename}_jobhist", replace


// XWAVEID file
local xwave_files		"wave _pid hid ivfio_xw ivfho memorig"
* Putting dataset in long form, so can then repeat the code above
use "$sourcedir\xwaveid", replace
ren pid _pid							// This is so that pid is not treated as the id variable in wave p (it is the cross-wave identifier)
reshape long @hid @pno @ivfio @ivfho, i(_pid) j(wave_str) string			// Note the advanced use of RESHAPE - very time-saving
	encode wave_str, gen(wave)
	replace wave = wave+1990
// Need to recode IVFIO into constant codes across waves - for some reason, they have completely different codes at different waves...
capture drop ivfio_xw
recode ivfio (10 30 50 81 83 98=10 "10_refusal") (11 12 31 32 51/53 82=11 "11_other non-contact") (20/24 40/43 60/65=20 "20_child") (54 55 80 = 54 "54_out of scope") if wave>1991, gen(ivfio_xw)
	replace ivfio_xw = ivfio if wave==1991 & (ivfio<=2) 
	replace ivfio_xw = 10 if wave==1991 & (ivfio==3) 
	replace ivfio_xw = 11 if wave==1991 & (ivfio==4 | ivfio==5 | ivfio==6 | ivfio==8) 
	replace ivfio_xw = 20 if wave==1991 & (ivfio==7) 
	label var ivfio_xw "Detailed individual outcome code from XWAVEID"
	label define ivfio_xw -8 "-8_Inapplicable" 1 "1_Full interview" 2 "2_Proxy interview" 3 "3_Phone interview" 9 "9_Lost CAPI" 99 "99_Dead", modify
label define rivfho 13 "HH comp + ques only" 14 "HH composition only" 19 "Docs missing or unus" 40 "Demolished/derelict" 64 "Missing person refus" 96 "W'drawn before field", modify
keep `xwave_files'
save "${filename}_xwaveid", replace

									

// Net income files
local netinc_vars		"wave hid hhnetde hhnetde2 hhneti"       
local count = 1991
foreach w in a b c d e f g h i j k l m n o p 		   {
	use "$sourcedir\BHPS net income files (SN3909)\stata8\\`w'_nethh.dta", replace
	// Generating a wave variable
	gen wave = `count'
	local count = `count' + 1
	renpfix `w'
	// Creating a tempfile
	keep `netinc_vars'
	des
	tempfile D3`w'
	save "`D3`w''"
/* end of loop */										}
// Adding the tempfiles together and creating a permanent file - based on the last file's datafile, which is already open
foreach w in a b c d e f g h i j k l m n o  	 		{		// This needs to miss off the last file (which is still open)
	append using `D3`w''
/* END OF LOOP */										}
save "${filename}_netinc", replace
										
													
													
// Merging INDRESP with HHSAMP, JOBHIST, XWAVEID, and net income files
use "${filename}_indresp", replace
merge 1:1 wave _pid using "${filename}_xwaveid", gen(merge_xwaveid)	
	replace ivfio_xw=9 if ivfho==19 | ivfho==39
merge 1:1 wave _pid using "${filename}_jobhist", gen(merge_jobhist)										
merge m:1 wave hid using "${filename}_hhsamp", gen(merge_hhsamp)	
merge m:1 wave hid using "${filename}_netinc", gen(merge_netinc)	
	numlabel _all, mask(#_) add
drop if ivfio_xw==-8 | ivfio_xw==20 | ivfio_xw==54			// Inapplicable people are not missing, so wouldn't need to be imputed
	order mlstat-merge_netinc, alphabetic last
	compress
	save "${filename}_merged", replace
																
													
				
				
				
				
				
				
				
													
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
// Deriving variables within the merged dataset
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////

/*
use "${filename}_merged", replace
*/
drop if _pid==.

// Missing data codes
mvdecode _all, mv(-9=.m \ -8=.i \ -7=.x \ -2=.r \ -1=.d)
recode jbsoc00 jbsoc (0 = .)


// Work outcomes: IB receipt, l/t sick, , lj_health, employment
* Dealing with mis-coding of JBSTAT at wave 1 (se notes)
clonevar jbstatR = jbstat if wave==1991		// Slightly clumsy way of recoding this, but ensures no errors made
		recode jbstatR (5=6) (6=7) (7=8) (8=5)
		replace jbstat = jbstatR if wave==1991
		drop jbstatR
* IB receipt
gen IBreceipt = (f117==17 | f125==25 | f134==34 | f116==16) if (f117<. | f125<.)
	label var IBreceipt "Receipt of incapacity benefits (IB, IVB, NI sickness benefit (not SSP))"
gen disbens = (IBreceipt==1 | f118==18 | f119==19 | f120==20 | f123==23 | f126==26 | f127==27 | f128==28) if IBreceipt<. & ((sex==1 & age<65)|(sex==2 & age<60))
	label var disbens "Receipt of a disability benefit (inc DLA) among U60/65s"
* The job loss variables
foreach ljvar in lj_health lj_sacked lj_rdndnt lj_care 	{
		replace `ljvar' = 0 if `ljvar'==. & jbstat<. 
		clonevar `ljvar'_ct = `ljvar'
		replace `ljvar' = 1 if `ljvar'>1 & `ljvar'<.
		label var `ljvar' "Any job loss of type `ljvar' from JOBHIST file"
		label var `ljvar'_ct "Num job losses of type `ljvar' from JOBHIST file"
		/* end loop */									}
* Long-term sick
gen ltsick = (jbstat==8) if jbstat<.
label var ltsick "Long-term sickness (recoded from jbstat), dummy"
* Temporary sickness from existing job (used for excluding sample later on)
gen tempsick = (jboffy==3) if (jbhas==1 | jboff==1)
label var tempsick "Temporarily sick from existing job"
* Employed at all
gen employ = (jbhas==1 | jboff==1) if jbhas<. | jboff<.
	label var employ "Employed (recoded from jbhas & jboff), dummy"
clonevar employR = employ										// see OneNote on IBreceipt for details
	replace employR=0 if ltsick==1
	label var employR "Employed (from EMPLOY), exc l/t sick"
recode employ  (0=1 "1_Non-employed") (1=0 "0_Employed"), gen(nonemploy)
	label var nonemploy  "Non-employed (from EMPLOY), dummy"
recode employR (0=1 "1_Non-employed") (1=0 "0_Employed"), gen(nonemployR)
	label var nonemployR "Non-employed (from EMPLOYR), dummy"
clonevar nonemployN = nonemploy
	replace nonemployN = 0 if ltsick==1
	label var nonemployN "Non-emp exc ltsick (for specificity analyses)"
	

// WLD var
recode hlltw (1=1 "1_WLD") (2=0 "0_No WLD"), gen(wldB)
	label var wldB "health limits type or amount of work (recoded hlltw to 0/1)"
	replace wldB = 0 if hlltwa==4 & hlendw==2 & wldB==.m		// These are .m (missing) to hlltw, but give negative answers to the follow-up, so seem not to have a WLD
recode hlendw (1 3=1 "1_Limit type") (2=0 "0_No limitation"), gen(wld_type)
	label var wld_type "health limits type of work (recoded hlendw to 0/1)"
	replace wld_type = 0 if wldB==0
clonevar wld_amt = hlltwa
	label var wld_amt "health limits amount of work (recoded hlltwa, still 4-cat)"
	replace wld_amt = 4 if wldB==0
* The binarised form of wld_amt
recode wld_amt (3/4=0 "0_Just a little/not at all limit amount wrk") (1/2=1 "1_A lot/somewhat limit amount wrk"), gen(wld_amtB)
	label var wld_amtB "Health limits amount of work, binarised version of wld_amt"	
	
	
// SF36 vars
capture drop wld??R
foreach var in 4a 4b 4c 4d 5a 5b 5c 	{
	recode hlsf`var' (1=1 "WLD") (2=0 "No WLD") (else=.), gen(wld`var'R)
	local label`var': variable label hlsf`var'
	label var wld`var'R "`label`var'' from hlsf'`var'"
	drop hlsf`var'
	/*endloop*/							}
* Pain in SF36
clonevar wldpain = hlsf8
	replace wldpain = . if hlsf8<0
	local label8: var label hlsf8
	label var wldpain "`label8' from hlsf8"
	drop hlsf8
tab wldpain, gen(wldpain_)
												/* Count in SF36 - only used in early descriptive analyses so taken out
												egen phys_ct = rownonmiss(wld4?R)
												egen phys_num = rowtotal(wld4?R) if phys_ct==4
												drop phys_ct
												egen mh_ct = rownonmiss(wld5?R)
												egen mh_num = rowtotal(wld5?R) if mh_ct==3
												drop mh_ct
												gen phmhint = physnum * mhnum
												END OF COMMENTED OUT SECTION */

												
// Age group
recode age (0/17=.) (18/24=1 "18-24") (25/29=2 "25-29") (30/34=3 "30-34") (35/39=4 "35-39") (40/44=5 "40-44") (45/49=6 "45-49") (50/54=7 "50/54") ///
	(55/59=8 "55-59") (60/64=9 "60-64") (65/max=10 "65+") (else=.), gen(agegrp)

	
// Health controls
* SRH
recode hlstat (1=1 "1_excellent") (2=2 "2_good") (3=3 "3_fair") (4/5=4 "4_poor/v poor"), gen(srh)
	label var srh "Self-reported hlth over past 12mths (4 cat), recoded from hlstat"
* Correcting LSI error in 2001 wave (see email to the BHPS team, 1/12/2010)
foreach var in hlprbm hlprbn hlprbo	{
	clonevar `var'O = `var'
	/* end loop */					}
replace hlprbm = hlprboO if wave==2001
replace hlprbn = hlprbmO if wave==2001
replace hlprbo = hlprbnO if wave==2001
drop hlprb?O
* Types of LSI
drop hlprb1-hlprb4				// The BHPS team have already recoded these to the main categories hlprba-o
clonevar hlprbmO = hlprbm
	label var hlprbmO "Original hlprbm (other LSI), before recoding to make consistent 2000-2001"
replace hlprbm = 1 if hlprbn==1 | hlprbo==1
* GHQ
recode hlghq2 (0/2=0 "0_No caseness") (3/12=1 "1_GHQ caseness"), gen(ghqB)
	label var ghqB "GHQ caseness (2/3 cut-off on 0-12 hlqhg2 scale)"
	drop hlghq2
* LLSI
recode hllt (2=0 "0_No LLSI") (1=1 "1_LLSI"), gen(llsi)
	label var llsi "LLSI 0/1, recoded from hllt"
* Activity limitations
foreach var in hllta hlltb hlltc hlltd	{
	recode `var' (0=0 "0_no limitation") (1/5=1 "1_limitation"), gen(`var'R)
	replace `var'R = 0 if llsi==0
	replace `var'R = 0 if hllte==5				// See OneNote note on DV - these are otherwise set to 'inapplicable' (.i)
	local hllt_label: var label `var'
	label var `var'R "`hllt_label', recoded to 0/1"
/* end loop */							}
* Other health vars for checking specificity
recode hosp (1=1 "1_Yes") (2=0 "0_No"), gen(hospR)
	replace hospR = 0 if hospch==1
	label var hospR "Hospital inpatient in past year exc childbirth (recoded from HOSP + HOSPCH)"
recode hl2gp (1/3=0 "0_0-5 trips") (4/5=1 "1_6+ trips"), gen(gpR)
	label var gpR "6+ GP visits in past year (recoded from HL2GP)"


	
// Industry
* Removing codes that should not exist, according to the coding frame (see OneNote discussion - about 0.5-0.9% of the responses, mainly 999#)
local siclist "0 6 40 83 111 120 276 281 286 289 290 302 305 395 410 435 480 500 536 555 599 610 611 631 670 836 890 951 1584 2110 2125 2451 2722 2913 3243 3471 3484 3570 3661 3895 4010 4154 4453"
	local siclist "`siclist' 4542 4822 4842 4912 5050 5147 5170 5211 5245 5246 5247 5248 5511 5530 5540 5650 6024 6030 6139 6171 6330 6340 6411 6522 6671 6901 6902 7111 7401 7420 7450 7510 7511 7512"
	local siclist "`siclist' 7720 7770 8010 8021 8379 8510 8511 8514 8531 8600 8611 9116 9261 9271 9311  9395 9410 9420 9490 9511 9512 9797 9830 9990 9998 9999"
clonevar jbsicR = jbsic
foreach sic in `siclist'	{
	replace jbsicR = . if jbsicR==`sic'
	/* end loop */			}
local sic92list "1 410 802 810 853 1526 1743 2421 2424 2437 2514 2560 2724 2941 3021 3113 3284 3301 3341 3343 3421 3652 4012 4248 4630 4754 4812 5187 5190 5217 5252 5333 5420 5450 5531 5532 5533"
	local sic92list "`sic92list' 5542 5555 5655 5847 6111 6112 6121 6160 6211 6324 6331 6525 6526 6610 6611 6620 7070 7142 7486 7487 7540 7551 7700 7811 7902 8011 8024 8031 8032 8033 8036 8150 8220 8232"
	local sic92list "`sic92list' 8350 8395 8432 8480 8515 8611 8632 8951 9310 9320 9330 9420 9510 9511 9611 9660 9911 9990 9998 9999"
clonevar jbsic92R = jbsic92
foreach sic in `sic92list'	{
	replace jbsic92R = . if jbsic92R==`sic'
	/* end loop */			}
* Creating the one-digit SIC dummies from these vars
gen sic80_1 = floor(jbsicR/1000)
	label var sic80_1 "Industry, SIC80 1-digit (recoded from jbsicR)"
recode jbsic92R (100/202=1) (500/502=2) (1000/1450=3) (1500/3720=4) (4000/4100=5) (4500/4550=6) (5000/5274=7) (5500/5552=8) ///
	(6000/6420=9) (6500/6720=10) (7000/7484=11) (7500/7530=12) (8000/8042=13) (8500/8532=14) (9000/9305=15) (9500 9900=.), gen(sic92_1)
* SIC80 labels
label define sic80_1 0 "Agriculture, forestry & fishing", modify
	label define sic80_1 1 "Energy & water supplies", modify
	label define sic80_1 2 "Extraction of minerals & ores other than fuels; manufacture of metals, mineral products & chemicals", modify
	label define sic80_1 3 "Metal goods, engineering & vehicles industries", modify
	label define sic80_1 4 "Other manufacturing industries", modify
	label define sic80_1 5 "Construction", modify
	label define sic80_1 6 "Distribution, hotels & catering (repairs)", modify
	label define sic80_1 7 "Transport & communication", modify
	label define sic80_1 8 "Banking, finance, insurance, business services & leasing", modify
	label define sic80_1 9 "Other services", modify
label values sic80_1 sic80_1
* SIC92 labels
label define sic92_1 1 "A Agriculture, Hunting and Forestry (in sic92_1R, also inc Fishing)", modify
	label define sic92_1 2 "B Fishing", modify
	label define sic92_1 3 "C Mining and Quarrying", modify
	label define sic92_1 4 "D Manufacturing", modify
	label define sic92_1 5 "E Electricity, Gas and Water Supply", modify
	label define sic92_1 6 "F Construction", modify
	label define sic92_1 7 "G Wholesale and Retail Trade: Repair of Motor Vehicles, Motorcycles and Personal Household Goods", modify
	label define sic92_1 8 "H Hotels and Restaurants", modify
	label define sic92_1 9 "I Transport, Storage and Communication", modify
	label define sic92_1 10 "J Financial Intermediation", modify
	label define sic92_1 11 "K Real Estate, Renting and Business Activities", modify
	label define sic92_1 12 "L Public Administration and Defence: Compulsory Social Security", modify
	label define sic92_1 13 "M Education", modify
	label define sic92_1 14 "N Health and Social Work", modify
	label define sic92_1 15 "O Other Community, Social and Personal Service Activities", modify
label values sic92_1 sic92_1
* SIC92 grouped and with SIC80 recoded
clonevar sic92_1R = sic92_1
	recode sic92_1R (2=1)
	

// Other workplace controls
* Sector
tsset _pid wave
	gen Ljbsect = L.jbsect if wave==1992			// See note in OneNote
clonevar jbsectR = jbsect
	replace jbsectR = Ljbsect if jbbgly==1 & wave==1992
	drop Ljbsect
recode jbsectR (1=1 "1_private") (2/5 7=2 "2_public") (6 8=3 "3_nonprofit/other"), gen(sector)
	label var sector "Sector (private/public/nonprofit-other), recoded from jbsectR"
* Contractual status
recode jbterm (1=1 "1_permanent") (2/3=2 "2_temporary"), gen(jbtermR)
	replace jbtermR = jbterm1 if wave>=1999
	label var jbtermR "Permanent vs. temporary job; from jbterm s1-8 and jbterm1 s9-"
recode jbtermR (1=0 "0_Permanent") (2=1 "1_Temporary"), gen(tempjob) 
	label var tempjob "Temporary contract, from JBTERM (s1-8) and JBTERM1 (s9-)"
* CS (civil service) dummy
gen cs = (jbsect==2) if jbsect<.
label var cs "Civil Service, dummy (from JBSECT)"					
* Workplace size
recode jbsize (1/4 10=1 "1_small (<50)") (5/6=2 "2_medium (<200)") (7/9=3 "3_large (200+)") (11=.d), gen(sme)
	label var sme "Workplace size, divided into small (<50), medium (50-<200) and large (200+) enterprises (recoded from jbsize)"
* Hours of work - inc banded; I'm really not expecting linear effects, and this will be highly sensitive to extreme values
gen hours = jbhrs + jbot
	replace hours=. if jbhrs==0
	replace hours=97 if hours>=97 & hours<.			// 97 is labelled '97 or above', so I assumed that this hits a ceiling at this level
	label var hours "Usual hours of work per week inc overtime (jbhrs+jbot)"
recode hours (1/15=1 "1_<16hrs") (16/29=2 "2_Part-time (16-29hrs)") (30/45=3 "3_Full-time(30-45hrs)") (46/max=4 "4_>45hrs"), gen(hoursGRP)
* Member of occupational pension scheme
gen occpen = (jbpenm==1) if jbpenm<. | jbpen==2	| jbpen==.d
	label var occpen "Member of occupational pension scheme (from jbpen and jbpenm)"
tsset _pid wave										// See note in OneNote
	gen Loccpen = L.occpen if wave==1992 		
	clonevar occpenR = occpen
		replace occpenR = Loccpen if jbbgly==1 & wave==1992
	gen LoccpenR = L.occpenR if wave==1993 		
		replace occpenR = LoccpenR if jbbgly==1 & wave==1993
		drop LoccpenR
	gen L2occpenR = L2.occpenR if wave==1993
		replace occpenR = L2occpenR if occpenR==. & wave==1993
		drop L2occpenR
	gen LoccpenR = L.occpenR if wave==1994 		
		replace occpenR = LoccpenR if jbbgly==1 & wave==1994
	gen L2occpenR = L2.occpenR if wave==1994
		replace occpenR = L2occpenR if occpenR==. & wave==1994
	gen L3occpenR = L3.occpenR if wave==1994
		replace occpenR = L3occpenR if occpenR==. & wave==1994
		drop L*occpen*
* Job satisfaction
recode jbsat (0=.i) (1/3=1 "1_Dissatisfied") (4/5=2 "2_Neither sat nor dissat / Q Sat") (6=3 "3_Satisfied") (7=4 "4_Completely satisfied"), gen(jobsat)
	label var jobsat "Job satisfaction (4-level), recoded from jbsat - note that 1991 is slightly incomparable"
recode jbsat4 (0=.i) (1/3=1 "1_Dissatisfied") (4/5=2 "2_Neither sat nor dissat / Q Sat") (6=3 "3_Satisfied") (7=4 "4_Completely satisfied"), gen(secur_sat)
	label var secur_sat "Satisfaction with job security (4-level), recoded from jbsat4 - note that 1991 is slightly incomparable"
recode jbsat2 (0=.i) (1/3=1 "1_Dissatisfied") (4/5=2 "2_Neither sat nor dissat / Q Sat") (6/7=3 "3_(Completely)Satisfied"), gen(pay_sat)
	label var pay_sat "Satisfaction with pay (3-level), recoded from jbsat2 - note that 1991 is slightly incomparable"
	// Waves 1-7 only
recode jbsat3 (0=.i) (1/3=1 "1_Dissatisfied") (4/5=2 "2_Neither sat nor dissat / Q Sat") (6=3 "3_Satisfied") (7=4 "4_Completely satisfied"), gen(boss_sat)
	label var boss_sat "Satisfaction with boss (4-level), recoded from jbsat3 - note that 1991 is slightly incomparable"
recode jbsat5 (0=.i) (1/3=1 "1_Dissatisfied") (4/5=2 "2_Neither sat nor dissat / Q Sat") (6=3 "3_Satisfied") (7=4 "4_Completely satisfied"), gen(init_sat)
	label var init_sat "Satisfaction with use of initiative (4-level), recoded from jbsat5 - note that 1991 is slightly incomparable"
* Opportunities for promotion
tsset _pid wave										// See note in OneNote
	gen Ljbopps = L.jbopps if wave==1992 		
	clonevar jboppsR = jbopps
		replace jboppsR = Ljbopps if jbbgly==1 & wave==1992
	gen LjboppsR = L.jboppsR if wave==1993 		
		replace jboppsR = LjboppsR if jbbgly==1 & wave==1993
		drop LjboppsR
	gen L2jboppsR = L2.jboppsR if wave==1993
		replace jboppsR = L2jboppsR if jboppsR==. & wave==1993
		drop L2jboppsR
	gen LjboppsR = L.jboppsR if wave==1994 		
		replace jboppsR = LjboppsR if jbbgly==1 & wave==1994
	gen L2jboppsR = L2.jboppsR if wave==1994
		replace jboppsR = L2jboppsR if jboppsR==. & wave==1994
	gen L3jboppsR = L3.jboppsR if wave==1994
		replace jboppsR = L3jboppsR if jboppsR==. & wave==1994
		drop L*jbopps*	
* Managerial responsibilities - nothing needs doing to this
* Work ethic (lfimpd)
recode lfimpd (0=.m) (1/4=1 "1_Not important(1-4)") (5/6=2 "2_Q unimportant(5-6)") (7/8=3 "3_Q important(7-8)") (9/10=4 "4_V important(9-10)"), gen(wrkimp)
	label var wrkimp "Importance of working (s8/13/18 only, recoded from LFIMPD)"
	// Copying this across waves
	bysort _pid: egen wrkimp_mn = mean(wrkimp)
	foreach w in 1998 2003 2008	{
		capture drop w`w'
		gen w`w' = wrkimp if wave==`w'
		bysort _pid: egen wrkimp_`w' = mean(w`w')
		drop w`w'
		/**/					}
	*egen wrkimp_patt = group(wrkimp_1998 wrkimp_2003 wrkimp_2008), missing label
	gen 	wrkimp_last = wrkimp_1998 if (wave>=1998 & wave<2003)
	replace wrkimp_last = wrkimp_2003 if (wave>=2003 & wave<2008)
	replace wrkimp_last = wrkimp_2008 if (wave==2008)
	label var wrkimp_last "Importance of working, most recent wave reported (from WRKIMP)"
* Self-identified class (opcls2)
recode opcls2 (0=.m) (1/3=1 "1_working class") (4/7=2 "2_middle/upper class") (8 11 12 96 .d=3 "3_Other/refused"), gen(srclass)
	label var srclass "Self-identified social class (recoded from OPCLS2)"
* Political party (vote4) - decided against using this
		

		
// SES controls
* Education
recode qfedhi (12 13=0 "0_no quals") (9 11=1 "1_Level 1") (7 8=2 "2_Level 2") (6 10=3 "3_Level 3") (3/5=4 "4_Level 4+") (1 2=5 "5_degree+") (else=.), gen(maxqual)
	label var maxqual "highest educational qualification, 5-band recoded from qfedhi"
* Social status (Cambridge scale)
gen status = jbcssf if sex==2
	replace status = jbcssm if sex==1
	label var status "Social status, Cambridge scale (from jbcssf and jbcssm)"
	order status, before(jbcssm)
clonevar mstatus = jbcssm
	replace mstatus = 0 if sex==1
	label var mstatus "Social status for men, Cambridge scale (women==0)"
clonevar fstatus = jbcssf
	replace fstatus = 0 if sex==2
	label var mstatus "Social status for women, Cambridge scale (men==0)"
xtile statusGRP = status, nquant(4)
	label var statusGRP "Categorised social status from STATUS, quartiles"
* NS-SEC
recode jbsec (10 20=1 "1_Higher managers and professionals") (30/60=2 "2_Lower managers and professionals") (70/74=3 "3_Intermediate employees") ///
		(81/92=4 "4_Small employers and own account workers") (100/112=5 "5_Lower supervisors and technicians") (120/127=6 "6_Semi-routine workers") (131/135=7 "7_Routine workers"), gen(nssec)
	label var nssec "NS-SEC class, seven category (recoded from JBSEC)"
recode nssec (1/2 = 1 "1_Managerial & Professional occs") (3/4=2 "2_Intermediate occs") (5/7=3 "3_Routine & manual occs"), gen(nssec_3class)
	label var nssec_3class "NS-SEC class, three category (recoded from JBSEC via NSSEC)"
* Net hhld income
clonevar netinc = hhnetde2
quietly sum netinc, det						// Necessary as logs are not defined for negative numbers
	gen inc_working = netinc + abs(r(min)) + 1
	gen loginc = log(inc_working)
	drop inc_working
	label var loginc "Log version of NETINC (based on hhnetde2)"
* Financial situation
recode fisit (1/2=1 "1_Comfortable/OK") (3=2 "2_Just about getting by") (4/5=3 "3_Difficult/v difficult"), gen(money)
	label var money "Perceived financial situation (3-level), recoded from fisit"

	
// Other controls
* Black and Minority Ethnic status (BEM)
bysort _pid: egen race_allwv  = mean(race)  if wave<=2002
	label values race_allwv arace
	label var race_allwv "Ethnic minority status pre-2003, copied across all waves (from race)"
bysort _pid: egen racel_allwv = mean(racel) if wave>=2003
	label values racel_allwv rracel
	label var racel_allwv "Ethnic minority status post-2003, copied across all waves (from racel)"
gen bem = (race_allwv>=2 & race_allwv<=9) | (racel_allwv>=6 & racel_allwv<=18)	if (race_allwv<. | racel_allwv<.)
	label var bem "Ethnic minority (0/1), derived from race_allwv and racel_allwv"
recode racel_allwv (1/5=1 "1_white") (6/7 14/16=2 "2_black or mixed white/black") (10=3 "3_Indian") (11/12=4 "4_Pakistani/Bangladeshi") (8 9 13 17 18=9 "9_Other inc Chinese, mixed White/Asian, other Asian"), gen(ethnicity)
	replace ethnicity=1 if  race_allwv==1
	replace ethnicity=2 if (race_allwv>=2 & race_allwv<=4)
	replace ethnicity=3 if  race_allwv==5
	replace ethnicity=4 if  race_allwv==6 | race_allwv==7
	replace ethnicity=9 if  race_allwv==8 | race_allwv==9
	label var ethnicity "Ethnicity grouped into five categories, dv from race_allwv & racel_allwv"
* Marital status
recode mlstat (1 6=1 "1_Married") (2/4 7=2 "2_Separated/divorced/widowed") (5=3 "3_Never married"), gen(married)
	label var married "Marital status (3-category), recoded from mlstat"
* Number of children
clonevar nchildR = nchild
	replace nchildR = 3 if nchildR>=3 & nchildR<.
	label define nchildR 0 "0" 1 "1" 2 "2" 3 "3+"
	label values nchildR nchildR
* Region
clonevar _region = region							// Needs this title to match the skills surveys
	replace _region=. if _region<0 | _region>11
* Tenure
recode tenure (1 2=1 "1_Owns home") (3 4=2 "2_Social housing") (5/8=3 "3_Other rented"), gen(housing)
	label var housing "Housing tenure (3-category), recoded from tenure"
	
	
	
// Misc other things 
* Variables recoded to be the same as the Skills Surveys for the various JEMs
clonevar soc00_4 = jbsoc00
clonevar soc90_3 = jbsoc
	gen soc90_1R = floor(soc90_3/100)
gen fulltimeH = ((jbhrs+jbot)>=31)
	replace fulltimeH = 2 if fulltimeH==0
	replace fulltimeH = . if (jbhrs<0 | jbot<0 | jbhrs>=.)
* Benefit reforms
gen dda = (wave>=1997) if wave<.
	label var dda "Disability discrimination act dummy (from 1997 base wave)"
gen IVBreform = (wave>=1995) if wave<.
	label var IVBreform "Change from Invalidity Benefit to Incapacity benefit dummy (from 1995 base wave)"
* Interview codes
label var ivfho "final hhld interview code"
* Creating random numbers for individuals and for observations (to be able to run regressions on sub-samples)
set seed 1982
egen tag = tag(_pid)
	gen tagworking = runiform() if tag==1
	bysort _pid: egen pidselect = max(tagworking)
	list _pid wave pidselect tag tagworking in 1/10, sepby(_pid)
	capture drop tag tagworking
	label var pidselect "Subsample selector (random number between 0/1 on the person level)"
* Creating a unique ID var (for ESTWRITE)
tostring _pid wave, gen(_pidS waveS)
gen str uniqueid = _pidS + waveS
drop _pidS waveS


	
		
// Weights
* For analyses that include the 2007/2008 samples (which therefore exclude net income as a control)
gen wt_working = lrwght if wave==2008
	bysort _pid: egen wt_allwaves = mean(wt_working)
	label var wt_allwaves "Longitudinal weight for original sample 1991-2008 (from LRWGHT in 2008)"
	replace wt_allwaves=. if wt_allwaves==0
	drop wt_working
gen wt_working = lrwtsw1 if wave==2008
	bysort _pid: egen wt_allsamples = mean(wt_working) if wave>=1999
	replace wt_allsamples=. if wt_allsamples==0
	label var wt_allsamples "Longitudinal weight for extension samples 1999-2008 (from LRWGHT in 2008)"
	drop wt_working
* For analyses that exclude the 2007/2008 samples
gen wt_working = lrwght if wave==2006
	bysort _pid: egen wt_allwaves2 = mean(wt_working)
	label var wt_allwaves2 "Longitudinal weight for original sample 1991-2006 (from LRWGHT in 2006)"
	replace wt_allwaves2=. if wave>=2007
	replace wt_allwaves2=. if wt_allwaves2==0
	drop wt_working
gen wt_working = lrwtsw1 if wave==2006
	bysort _pid: egen wt_allsamples2 = mean(wt_working) if wave>=1999
	replace wt_allsamples2=. if wave>=2007
	replace wt_allsamples2=. if wt_allsamples2==0
	label var wt_allsamples2 "Longitudinal weight for extension samples 1999-2006 (from LRWGHT in 2006)"
	drop wt_working
* To create a cross-sectional weight using all data - this is not used in any main analyses, simply for background checks (hence haven't tested/checked as much as other weights)
gen wt_xsect = xrwght if wave<1999
	replace wt_xsect = xrwtsw1 if wave==1999 | wave==2000
	replace wt_xsect = xrwtuk1 if wave>=2001 
	label var wt_xsect "Cross-sectional weight inc Scottish & Welsh samples (from xrwght, xrwtsw1 and xrwtuk1)"

	
	
/////////////////////////////////////////////////////////////////
// Deriving variables from PARTNER's status - see ISER Stata course 2010, part 2, example 8
	// These have to be added after the above so they can use the dvs
	// Note: Don't want to add anything if don't have a partner in the household, so have condition of hgspn>0
/////////////////////////////////////////////////////////////////
gen partnum = cond(pno < hgspn, pno, hgspn) if hgspn > 0		// From BHPS course - this gives a unique (but non-consecutive) identifier to each partnership in the hhld
	label variable partnum "Unique partnership identifier in hhld (non-consecutive)"
bysort hid partnum: egen numinpart = sum(hgspn > 0 & hgspn<.) 
	label variable numinpart "# respondents from partnership (max 2)"
foreach v of varlist sex age wldB wld_type wld_amt wld_amtB jbstat IBreceipt ltsick employ employR nonemployR {
	capture drop sp_`v'
	bysort hid partnum: gen sp_`v' = cond(_n==2, `v'[1], `v'[2], .) if partnum<. & numinpart==2
	replace sp_`v'=0 if numinpart==0
	local val_lab: 	value label `v'
	label val sp_`v' `val_lab'
	local label: 	var label `v'
	label var sp_`v' "Spouse/partner: `label'"
/* END OF LOOP */												}
replace sp_wldB = . if wave==1999 | wave==2004				// For those who have numinpart~=2
	replace sp_wld_amt = . if wave==1999 | wave==2004
	replace sp_wld_type = . if wave==1999 | wave==2004
gen partnered = (hgspn>0 & hgspn<.)
	label var partnered "Has spouse/partner in hhld (whether or not responding), recoded from wHGSPN"
							/* Checks
							sort hid pno
							list hid _pid pno hgspn partnum numinpart age sp_age in 1/1500 if hgspn>0 & partnum>1, sepby(hid)
							END OF CHECKS	*/


/////////////////////////////////////////////////////////////////
// Final data housekeeping

							/* Creating dummy variables - no longer needed after using XI and i. for factor variables
							foreach var in agegrp sex married nchildR _region srh maxqual money housing jobsat jboppsR sic80_1 sic92_1R sector sme wave	{
								tab `var', gen(D`var'_)
								/*end loop*/																											}
							END COMMENTED OUT SECTION	*/
// Tidying
keep if ivfio==1 			// Done at this stage as I want the partner vars to be reflect non-responding partners
order _all, alphabetic 
	order _pid hid pno, first
							*	foreach var in _region agegrp sic80_1 sic92_1R	{
							*		order D`var'_1?, after(D`var'_9)
							*	/*end loop*/									}
numlabel _all, mask(#_) add

// Time series vars
tsset _pid wave
unab wts: wt_*
unab ljs: lj_*
unab lsi: hlprba-hlprbm 
local futurevars "wldB wld_type wld_amt wld_amtB employ employR nonemploy nonemployR nonemployN IBreceipt ltsick `ljs' disbens `wts' xrwght ivfio"
local futurevars "`futurevars' `lsi' ghqB srh hlltaR hlltbR hlltcR hlltdR hlghq1 llsi hospR gpR age agegrp"
foreach var in `futurevars' {
	local varlab: var label `var'
	gen F`var' = F.`var'
		label var F`var' "t+1 `varlab'"
	order ?`var', after(`var')
/*end of loop*/																	}

// 2-lag vars - IBreceipt and age only
local lag2vars "IBreceipt wldB age agegrp"
tsset _pid wave
foreach var in `lag2vars'	{
	gen F2`var' = F2.`var'
	label var F2`var' "t+2 `var'"
	order F2`var', after(F`var')
	/**/					}
