* Labelling soc00_4 and soc90_3
include "$workdatadir\soc_label.doi"												// Labels for SOC00_4 and SOC90_3
	* Getting rid of SOC00 occupations that don't seem to exist
	local probsoc "soc00_4==112 | soc00_4==121 | soc00_4==309 | soc00_4==364 | soc00_4==430 | soc00_4==460 | soc00_4==532 | soc00_4==540 | soc00_4==610 | soc00_4==874 | soc00_4==990 | soc00_4==1391 |"
	local probsoc "`probsoc' soc00_4==1421 | soc00_4==1726 | soc00_4==1751 | soc00_4==1791 | soc00_4==2142 | soc00_4==2202 | soc00_4==2332 | soc00_4==2342 | soc00_4==2393 | soc00_4==2532 | soc00_4==2922 | soc00_4==2933 | "
	local probsoc "`probsoc' soc00_4==3003 | soc00_4==3203 | soc00_4==3463 | soc00_4==3611 | soc00_4==3823 | soc00_4==3913 | soc00_4==4004 | soc00_4==4014 | soc00_4==4104 | soc00_4==4204 | soc00_4==4309 | soc00_4==4414 | "
	local probsoc "`probsoc' soc00_4==4504 | soc00_4==4634 | soc00_4==5045 | soc00_4==5265 | soc00_4==5325 | soc00_4==5405 | soc00_4==6416 | soc00_4==6446 | soc00_4==6526 | soc00_4==6726 | soc00_4==7207 | soc00_4==7209 | "
	local probsoc "`probsoc' soc00_4==7217 | soc00_4==7317 | soc00_4==8629 | soc00_4==8728 | soc00_4==8738 | soc00_4==8748 | soc00_4==8868 | soc00_4==8928 | soc00_4==9319 | soc00_4==9589 | soc00_4==9998 | soc00_4==9999 "
	*dis "`probsoc'"
	*tab soc00_4 wave if `probsoc'
	replace soc00_4=. if `probsoc'
	
* The bespoke occupational categories for SOC90 and SOC00 (both with the _BB suffix)
do "$workdatadir\1_data_BBsoc.do"						// From the WORK DATA analyses - my own recoding of SOC00_4 into 3-digit groups (more detailed than SOC00_3)
clonevar soc90_allyr = soc90_3
	label var soc90_allyr "A copy of soc90_3, NOT a proportionally mapped version - renamed simply so that 1_data_BBsoc90.do works correctly"
do "$workdatadir\1_data_BBsoc90.do"					// From the WORK DATA analyses - my own recoding of SOC90_3 into 3-digit groups (more detailed than SOC90_2)
	drop soc90_allyr

* Importing CAMSIS and Chan-Goldthorpe status scales
save ${filename}_CAMSISmerging, replace
clear
	insheet using "$dodir\CAMSIS91.csv", case names
	merge 1:m soc90_3 using "${filename}_CAMSISmerging", gen(merge_CAMSIS)	// 2 occs do not appear in BHPS (601|813), 27 soc90_3 codes in BHPS do not appear in CAMSIS (unlabelled, so seem to be data errors)
	drop if merge_CAMSIS==1
	drop merge_CAMSIS
	ren CAMSISmale 		camsisM
	ren CAMSISfemale 	camsisF
	label values soc90_3 soc90_3
order camsis*, after(status)
	label var camsisM "CAMSIS social interaction distance scale (based on Census 91), men" 
	label var camsisF "CAMSIS social interaction distance scale (based on Census 91), women" 
gen camsis = camsisM if sex==1
	replace camsis = camsisF if sex==2
	label var camsis  "CAMSIS social interaction distance scale, combining camsisM & camsisF"
* The recoded status scales
clonevar camsisMR = camsisM
	replace camsisMR = 0 if sex==2
clonevar camsisFR = camsisF
	replace camsisFR = 0 if sex==1
clonevar statusMR = jbcssm
	replace statusMR = 0 if sex==2
clonevar statusFR = jbcssf
	replace statusFR = 0 if sex==1
	
	
	
	
* Importing Chan-Goldthorpe status scale
gen soc90_2 = floor(soc90_3/10)
	label var soc90_2 "SOC90 2-digit, based on soc90_3"
gen CGstatus = .
	replace CGstatus = 0.4114 if (soc90_2==10 | soc90_2==13 | soc90_2==15 | soc90_2==-999)
	replace CGstatus = -0.0625 if (soc90_2==11 | soc90_2==14 | soc90_2==16 | soc90_2==-999)
	replace CGstatus = 0.5107 if (soc90_2==12 | soc90_2==-999)
	replace CGstatus = -0.0453 if (soc90_2==17 | soc90_2==-999)
	replace CGstatus = 0.2355 if (soc90_2==19 | soc90_2==-999)
	replace CGstatus = 0.3115 if (soc90_2==20 | soc90_2==21 | soc90_2==-999)
	replace CGstatus = 0.5643 if (soc90_2==22 | soc90_2==24 | soc90_2==25 | soc90_2==26 | soc90_2==27 | soc90_2==29 | soc90_2==-999)
	replace CGstatus = 0.5017 if (soc90_2==23 | soc90_2==-999)
	replace CGstatus = 0.3116 if (soc90_2==30 | soc90_2==31 | soc90_2==32 | soc90_2==33 | soc90_2==39 | soc90_2==-999)
	replace CGstatus = 0.2228 if (soc90_2==34 | soc90_2==37 | soc90_2==-999)
	replace CGstatus = 0.5337 if (soc90_2==35 | soc90_2==36 | soc90_2==38 | soc90_2==-999)
	replace CGstatus = 0.2274 if (soc90_2==40 | soc90_2==-999)
	replace CGstatus = 0.2238 if (soc90_2==41 | soc90_2==-999)
	replace CGstatus = 0.2559 if (soc90_2==42 | soc90_2==-999)
	replace CGstatus = 0.1443 if (soc90_2==43 | soc90_2==-999)
	replace CGstatus = -0.3353 if (soc90_2==44 | soc90_2==49 | soc90_2==-999)
	replace CGstatus = 0.1539 if (soc90_2==45 | soc90_2==46 | soc90_2==-999)
	replace CGstatus = -0.5014 if (soc90_2==50 | soc90_2==52 | soc90_2==-999)
	replace CGstatus = -0.5121 if (soc90_2==51 | soc90_2==53 | soc90_2==54 | soc90_2==-999)
	replace CGstatus = -0.4072 if (soc90_2==55 | soc90_2==56 | soc90_2==57 | soc90_2==58 | soc90_2==59 | soc90_2==-999)
	replace CGstatus = -0.2288 if (soc90_2==60 | soc90_2==61 | soc90_2==-999)
	replace CGstatus = -0.3261 if (soc90_2==62 | soc90_2==-999)
	replace CGstatus = -0.2261 if (soc90_2==63 | soc90_2==66 | soc90_2==67 | soc90_2==69 | soc90_2==-999)
	replace CGstatus = -0.2121 if (soc90_2==64 | soc90_2==-999)
	replace CGstatus = 0.1097 if (soc90_2==65 | soc90_2==-999)
	replace CGstatus = 0.1193 if (soc90_2==70 | soc90_2==71 | soc90_2==-999)
	replace CGstatus = -0.1151 if (soc90_2==72 | soc90_2==73 | soc90_2==79 | soc90_2==-999)
	replace CGstatus = -0.5589 if (soc90_2==80 | soc90_2==81 | soc90_2==82 | soc90_2==83 | soc90_2==84 | soc90_2==85 | soc90_2==86 | soc90_2==89 | soc90_2==-999)
	replace CGstatus = -0.4114 if (soc90_2==87 | soc90_2==88 | soc90_2==-999)
	replace CGstatus = -0.5979 if (soc90_2==90 | soc90_2==91 | soc90_2==92 | soc90_2==93 | soc90_2==99 | soc90_2==-999)
	replace CGstatus = -0.2974 if (soc90_2==94 | soc90_2==95 | soc90_2==-999)
label var CGstatus "Chan-Goldthorpe status scale - derived on Excel sheet"

order CGstatus camsis?R status?R, after(status)
