****************************************************************************************
* Creating a new dataset where SOC2000 data is recoded to SOC90
* First written 6/8/10
*		NOTE: should create a new dataset for each use of this - don't want to expand the ENTIRE
*		dataset about x20, as this will make it slow and unwieldy for other calculations
****************************************************************************************

* This version uses SS01, SS97, WiB and EiB for SOC90, and recodes SS06 to SOC2000
* Note that the following line was added changed when I decided to use the SOC90 supplied in SS01:
replace soc00_4=. if order~=57
/* I also replaced the line
	replace scaledwt=1 if order==53 | order==54 | order==55 | order==56			// order==56 added
*/


//////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////////
// Merging based on sex as well as occupation
//////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////////

// Preparation
gen persid = _n								// uniqueid is only unique within each survey
label var persid "Unique id for each person, prior to expanding data for SOC00->SOC90"

// Expanding the dataset
merge m:1 soc00_4 sex using "$workingdir\2_map_expand_bysex.dta"
	tab soc00_4 sex if _merge==1 , miss
	tab soc00_4 sex if _merge==2 , miss
	drop if _merge==2						// These are the occupations that don't appear in the later Skills Surveys 
	drop _merge
expand num_soc90 							// Note that observations where num_soc90 is missing - i.e. EiB/SS97/WiB - are not deleted; they are kept as single observations
	
// Merging in the weights to the expanded dataset
bysort persid: gen match_id = _n			// This is completely arbitrary - the expanded cases can have SOC90 codes and weights added in any order.  But need to have some var for merge to work
	label var match_id "A running counter of SOC90 codes within persid" 
merge m:1 soc00_4 sex match_id using "$workingdir\2_map_weights_bysex.dta"
	tab soc00_4 order if _merge==1, miss
	tab soc00_4 order if _merge==2, miss
	drop if _merge==2						// As above
	gsort -order persid match_id
	list persid sex order soc00_4 soc90_3 soc90_3I num_soc90 match_id scaledwt if order==57 in 1/25, sepby(persid)
	list persid sex order soc00_4 soc90_3 soc90_3I num_soc90 match_id scaledwt regrp_soc00 if order==57 & abs(regrp_soc00~=soc00_4) in 1/100, sepby(persid) nol
drop num_soc90 soc90_title _merge
	
// Creating the updated weights
capture drop _weight*R
* For the main weights based on the proportional mapping matrix, regrouped into size n>30
replace scaledwt=1 if order==53 | order==54 | order==55 | order==56
foreach w in _weight _weight_2 _weight_eib	{
	gen `w'soc = `w' * scaledwt
	label var `w'soc "`w' combined with SOC2000-SOC90 weighting"
											}
renvars _weight*soc*, subst("_weight" "_w")			// Making weight varnames shorter
											
// Finally
clonevar soc90_allyr = soc90_3
	replace soc90_allyr = soc90_3I if soc90_3==. 	
	label var soc90_allyr "Occupation - SOC90 for all years, including recoded from SOC2000"
	label values soc90_allyr soc90_3I soc90_3	
clonevar soc90_1_allyr = soc90_1		// 1-digit merged occupation
	replace soc90_1_allyr = floor(soc90_allyr/100) if soc90_allyr~=999
	label var soc90_1_allyr "Occupation - SOC90, 1-digit, from soc90_allyrs"
	label values soc90_1_allyr soc90_1
	tab soc90_1_allyr, gen(soc90_1_)	
gen soc90_2R = floor(soc90_allyr/10)
	label var soc90_2R "Occupation - SOC90, 2-digit, from soc90_allyrs"
	label values soc90_2R soc90_2
	
	
	
									//////////////////////////////////////////////////////////////////////////////////////////////
									//////////////////////////////////////////////////////////////////////////////////////////////
									// No longer used
									//////////////////////////////////////////////////////////////////////////////////////////////
									//////////////////////////////////////////////////////////////////////////////////////////////

									/* This was used for lokoing at the number of SOC90 categories within each SOC2000 category in SS01
									use "C:\Documents and Settings\baumberg\Desktop\Working data\1_merged_stage1.dta", replace
									keep if order==56
									collapse (count) order, by(soc00_4 soc90_3)
									gen one = 1
									preserve
										collapse (sum) order (sum) one, by(soc00_4)
										tab one
										bysort one: sum order
									restore
									*/
									
									
									
									