*********************************************************************************************************************************
* 1. The .do files to construct the dataset from start to finish - MUST BE DONE IN THIS ORDER!
*********************************************************************************************************************************

////////////////////////////////////
/* Var notes
	Uniqueid 		Must be a string variable
	Sex				1=Male, 2=Female
	Selfemp1		1=Employee, 2=Self-emp [self-reported answer]
	Sector			1=Private, 2=Public, 3=Nonprofit
	_country		1=England | 2=Scotland | 3=NI | 4=UK | 5=GB
END OF VAR DETAILS */

use "Z:\PhD datasets\Work-related datasets\2006 Skills Survey (SN6004)\stata8\ss06_for_archive.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren bhard			D1
		ren bspeed		D4
		ren btension	D12
		ren bdeadl		D15
		ren beffort		D36
	ren bme1			C1
		gen C2 = 2 if bworkhr1>0 & bworkhr1<.
			replace C2 = 1 if (bworkhr1==5 | bworkhr2==5 | bworkhr3==5 | bworkhr4==5 | bworkhr5==5 | bworkhr6==5 | bworkhr7==5) & bworkhr1>0 & bworkhr1<.
		ren bdecide		C15
		ren emesay		C16_1
		ren emeine		C16_2
		ren bchoice		C23
		ren bme3		C25
		ren bme2		C33
		ren bme4		C49
	ren cstrengt		P6
		ren cstamina	P8
	ren cmefeel			E1
		ren cothfee		E2
		ren cpeople		E5
		ren cteach		E15
		ren cspeech		E16
		ren cpersuad	E17
		ren cselling	E18
		ren ccaring		E22
	mvdecode D* C* P* E*, mv(-1)
	// Other vars
	ren uniqueid 	serial
		tostring serial, gen(uniqueid) format(%8.0f)
	renvars asex aage, presub("a" "")
	numlabel bsoc2000, mask(#_) remove
		ren bsoc2000	soc00_4
		ren b_isco		isco_4
		destring bsic92 bsic03, gen(sic92_4 sic03_4) 
	gen WORK = 1
		ren bfultime	fulltime		// Have also included BHOURS
		recode bhours (-3 -1 999=.) (0=.a ".a_It varies"), gen(hours)
			replace hours = ghours if ghours>0 & ghours<999			// A question on usual hours for pay - see spreadsheet
		ren bemptype	selfemp1
			ren bempsta selfemp2
		ren esector sector
		recode dquals1 (1=0 "0_no quals") (2 5 9 24=1 "1_Level 1") (3 6 10 16 23 =2 "2_Level 2") (4 7 8 11 13 14 15 22 =3 "3_Level 3") (12 17 18 19 = 4 "4_Level 4+") (20 21=5 "5_degree+") (else=.), gen(ed1)
		recode dquals2 (1=0 "0_no quals") (2 5 9 24=1 "1_Level 1") (3 6 10 16 23 =2 "2_Level 2") (4 7 8 11 13 14 15 22 =3 "3_Level 3") (12 17 18 19 = 4 "4_Level 4+") (20 21=5 "5_degree+") (else=.), gen(ed2)
		recode dquals3 (1=0 "0_no quals") (2 5 9 24=1 "1_Level 1") (3 6 10 16 23 =2 "2_Level 2") (4 7 8 11 13 14 15 22 =3 "3_Level 3") (12 17 18 19 = 4 "4_Level 4+") (20 21=5 "5_degree+") (else=.), gen(ed3)
		egen maxqual = rowmax(ed1 ed2 ed3)
		label values maxqual ed1
	gen _survey = "skills2006"
		gen _year  = year(aintdate)
		gen _month = month(aintdate)
		recode region (1/9=1 "1_England") (10=4 "4_Wales")(11/12=2 "2_Scotland") (13=3 "3_NI"), gen(_country)
		recode region (11/12=11 "Scotland"), gen(_region)
			label define region 11 "11_scotland" 12 "", modify
			label values _region region
		ren homettwa	_reg_ttwa91
	ren newwt65uk		_weight
		ren deswtuk		_weight_2
	keep D* C* P* E* uniqueid sex age WORK soc* sic* isco* fulltime hours selfemp* sector _year _month _survey _weight* _country _region _reg_ttwa* maxqual
	save "$workingdir\ss06.dta", replace
use "Z:\PhD datasets\Work-related datasets\2001 Skills survey (SN4972)\stata6\2001skillssurvey.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren bhard			D1
		ren bspeed		D4
		ren btension	D12
		ren bdeadl		D15
		ren beffort		D36
	ren bme1			C1
		gen C2 = 2 if bworkhr1<99
			replace C2 = 1 if (bworkhr1==5 | bworkhr2==5 | bworkhr3==5 | bworkhr4==5 | bworkhr5==5 | bworkhr6==5 | bworkhr7==5) & bworkhr1<99
		ren	blotsay		C12
		ren bdecide		C15
		ren emesay		C16_1
		ren emeine		C16_2
		ren bchoice		C23
		ren bme3		C25
		ren bme2		C33
		ren bme4		C49
	ren cstrengt		P6
		ren cstamina	P8
	ren cpeople			E5
		ren cteach		E15
		ren cspeech		E16
		ren cpersuad	E17
		ren cselling	E18
		ren ccaring		E22
	mvdecode D* C* P* E*, mv(8 9)
	// Other vars
	ren serialno	uniqueid
		renvars asex aage, presub("a" "")
	gen WORK = 1
		destring bsic92, gen(sic92_4) 
			ren bnsic80	sic80_4
		ren b_soc90 	soc90_3			// b_status apparently shows 'reliability' of soc90 code - presumably from soc00 recoding?  But no detail given...
			ren bsoc2000	soc00_4
			ren b_isco		isco
		ren bfultime	fulltime		// Have also included BHOURS
		recode bhours (999=.) (0=.a ".a_It varies"), gen(hours)
			replace hours = ghours if ghours>0 & ghours<999			// A question on usual hours for pay - see spreadsheet
		ren bemptype	selfemp1			
		recode esector (1=1 "1_Private") (2=2 "2_Public") (3=3 "3_Nonprofit") (8/9=.), gen(sector)
		recode dquals1 (0=0 "0_no quals") (1 4 8 23=1 "1_Level 1") (2 5 9 15 22=2 "2_Level 2") (3 6 7 10 12 13 14 21 =3 "3_Level 3") (11 16 17 18 = 4 "4_Level 4+") (19 20=5 "5_degree+")  (else=.), gen(ed1)
		recode dquals2 (0=0 "0_no quals") (1 4 8 23=1 "1_Level 1") (2 5 9 15 22=2 "2_Level 2") (3 6 7 10 12 13 14 21 =3 "3_Level 3") (11 16 17 18 = 4 "4_Level 4+") (19 20=5 "5_degree+")  (else=.), gen(ed2)
		recode dquals3 (0=0 "0_no quals") (1 4 8 23=1 "1_Level 1") (2 5 9 15 22=2 "2_Level 2") (3 6 7 10 12 13 14 21 =3 "3_Level 3") (11 16 17 18 = 4 "4_Level 4+") (19 20=5 "5_degree+")  (else=.), gen(ed3)
		egen maxqual = rowmax(ed1 ed2 ed3)
	gen _survey = "skills2001"
		recode rda (1/9=1) (10=4) (11=2), gen(_country)
		recode rda	(1=8 "8_south east") (2=6 "6_east of england") (3=7 "7_london") (4=9 "9_south west") (5=5 "5_west midlands") (6=4 "4_east midlands") (7=3 "3_yorkshire and the humber")	///
			(8=2 "2_north west") (9=1 "1_north east") (10=10 "10_wales") (11=11 "11_scotland"), gen(_region)
		ren ttwanew		_reg_ttwa91
		ren ttwa		_reg_ttwa81
		gen _yearS = substr(aintdate, 5, 4)
			destring _yearS, gen(_year)
		gen _monthS = substr(aintdate, 3, 2)
			destring _monthS, gen(_month)
	ren newwt			_weight
		ren weight		_weight_2
	keep D* C* P* E* uniqueid sex age WORK soc90_3 soc00_4 sic92_4 sic80_4 fulltime hours selfemp1 sector _year _month _survey _weight* _country _region* _reg_ttwa* maxqual
	save "$workingdir\ss01.dta", replace
use "Z:\PhD datasets\Work-related datasets\1997 Skills survey (SN3993)\stata6\g993.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren b28 			D1
		ren b27			D36
	ren b35a			C1
		gen C2 = (b260==5 | b261==5 | b262==5 | b263==5 | b264==5 | b265==5 | b266==5) if b260<.
			recode C2 (1=1) (0=2)
		ren b30			C23
		ren b35c		C25
		ren b35b		C33
		ren b35d		C49
	ren ja10			P6
		ren ja11		P8
	ren ja2				E5
		ren ja3			E15
		ren ja4			E16
		ren ja5			E17
		ren ja6			E18
		ren ja7			E22
	mvdecode D* C* P* E*, mv(9)
	// Other vars	
	tostring serial, gen(uniqueid) format(%8.0f)
		ren a2 		sex
		ren a3 		age
	gen WORK = 1
		ren b2sic	sic92_2
		ren b3soc	soc90_3
		ren b10		fulltime
		recode b11 (999=.) (0=.a ".a_It varies"), gen(hours)
			replace hours = p2e if p2e>0 & p2e<999			// A question on usual hours for pay - see spreadsheet.  Only seems to have data for those who DIDN'T provide an earlier answer
		ren b4 		selfemp1
		recode b18 (1=1 "1_Private") (2=2 "2_Public") (3=3 "3_Nonprofit") (8/9=.), gen(sector)
		recode p12a00  (1=0 "0_no quals") (2 21=1 "1_Level 1")      (3 5 8 14 20=2 "2_Level 2")       (4 6 7 9 11 12 13 19 =3 "3_Level 3")   (10 15 16 17 = 4 "4_Level 4+") (18=5 "5_degree")   (else=.), gen(ed1)
		recode p12a01  (1=0 "0_no quals") (2 21=1 "1_Level 1")      (3 5 8 14 20=2 "2_Level 2")       (4 6 7 9 11 12 13 19 =3 "3_Level 3")   (10 15 16 17 = 4 "4_Level 4+") (18=5 "5_degree")   (else=.), gen(ed2)
		recode p12a02  (1=0 "0_no quals") (2 21=1 "1_Level 1")      (3 5 8 14 20=2 "2_Level 2")       (4 6 7 9 11 12 13 19 =3 "3_Level 3")   (10 15 16 17 = 4 "4_Level 4+") (18=5 "5_degree")   (else=.), gen(ed3)
		egen maxqual = rowmax(ed1 ed2 ed3)
	gen _survey = "skills1997"
		gen _year = 1997
		gen _month = intmonth
		ren ttwa		_reg_ttwa81
	ren newwt			_weight 
		ren wt1			_weight_2
	gen _country = 6
	keep D* C* P* E* uniqueid sex age WORK soc90_3 sic92_2 selfemp1 fulltime hours sector _year _month _survey _weight* _country _reg_ttwa* maxqual
	save "$workingdir\ss97.dta", replace
use "Z:\PhD datasets\Work-related datasets\2000-1 Working in Britain (SN4641)\stata6\wib.dta", replace
	numlabel _all, mask(#_) add
	drop if uniq_id==.				// For some reason, there are a large number of empty records in this file with no data whatsoever.  These are dropped to conserve space and intelligibility
	// Main vars
	ren i4a_1 			D1
		ren i4a_3		D20
	ren i3_8 			C2_B
			recode C2 (1=1) (0=2)
		ren i1c			C8
		ren h7			C16_1
		ren h7a			C16_2
		ren i1a			C18
		ren i1b			C38
		ren i1d			C39
	ren h6_1			E8
	mvdecode C16_1 C16_2 D1 D20	, mv(5 6)
	mvdecode C16_1				, mv(4)
	mvdecode C8 C18 C38 C39		, mv(3)
	mvdecode E8					, mv(7)
	// Other vars	
	tostring uniq_id, gen(uniqueid) format(%8.0f)
	drop sex
		ren p8 		sex
	gen WORK=1
		recode soc (9999=.), gen(soc90_3)
		rename f1a	sic92_wib
		recode subs8a (1=1 "1_Employee") (2=2 "2_Self-employed") (else=.), gen(selfemp1)
			replace selfemp1=1 if s8b==1				// This is for people who say BOTH to employed/self-emp, who are then asked for MAIN job
			replace selfemp1=2 if s8b==2
		ren ftpt 	fulltime
		ren ushrswk hours
			replace hours=. if hours==-99
		recode f1c (4/5=.), gen(sector)
* Decided 10/8/10 that this was not comparable enough (or important enough) to include
*		recode p2a (6 7=1 "1_Level 1 or none")      (5=2 "2_Level 2")       (3 4=3 "3_Level 3")   (1 2= 4 "4_Level 4+") (else=.), gen(maxqual)
*			replace maxqual=4 if maxqual<4 & p2b==1
*			replace maxqual=2 if maxqual<2 & p2c==1
	gen _survey = "wib00"
		gen _year = 2000
		ren intmo 	_month
		replace _year = 2001 if _month==13
		replace _month = 1 if _month==13
	ren lfswt3			_weight
		ren kish		_weight_2
		ren density		_strata
		ren cluster		_PSU
	gen _country = 6
	keep D* C* E* uniqueid sex age WORK soc90_3 sic92_wib selfemp1 hours fulltime sector _year _month _survey _weight* _strata _PSU _country 
	save "$workingdir\wib.dta", replace
use "Z:\PhD datasets\Work-related datasets\1992 Employment in Britain (SN5368)\stata8\employed.dta", replace		
	// Generating a unique identifier across the EiB datasets - which is remarkably difficult!  This is all because q36 is wrongly coded in the McGovern version...
	capture drop ageproduct
		gen ageproduct = addressn * q114 * q163 * age 
	capture drop pattern
		gen pattern = ""
		foreach j in a b c d e f g h i j k l m n	{
			tostring q6`j', gen(q6`j'S)
			replace pattern = pattern + q6`j'S
			drop q6`j'S
												}
	capture drop test9
		bysort ageproduct postsect pattern dob q139 cursit listbase nhh nworkers issue qver: gen test9 = _N
		tab test9
	gen new_id = _n
	keep new_id age q36
		ren age			age_orig
		ren q36			q36_orig
		sort new_id
	save "Z:\PhD datasets\Work-related datasets\1992 Employment in Britain (SN5368)\stata8\merging.dta", replace
use "Z:\PhD datasets\Work-related datasets\1992 Employment in Britain (SN5368)\stata8\eib2.dta", replace		
// This is the dataset supplied by Pat McGovern in May/10; previously I was using 'employed.dta', but this was missing weight, soc, sic, etc.  Diffs between datasets are documented in the EIB tab of the ssheet
	numlabel _all, mask(#_) add
	// Merging in the data generated above
	capture drop ageproduct
		gen ageproduct = addressn * q114 * q163 * age 
	capture drop pattern
		gen pattern = ""
		foreach j in a b c d e f g h i j k l m n	{
			tostring q6`j', gen(q6`j'S)
			replace pattern = pattern + q6`j'S
			drop q6`j'S
												}
	capture drop test9
		bysort ageproduct postsect pattern dob q139 cursit listbase nhh nworkers issue qver: gen test9 = _N
		tab test9
	gen new_id = _n
		drop test9
		sort new_id
	merge new_id using "Z:\PhD datasets\Work-related datasets\1992 Employment in Britain (SN5368)\stata8\merging.dta"
	// Main vars
	ren q29a			D1
		ren q56c		D4
		ren q29c		D12
		ren q29b		D20
		ren q26			D36
	ren q49ba			C1_B
			recode C1_B (0=4)
		ren q50f		C2_B
			recode C2_B (1=1) (0=2)
		ren udecide2	C8_S
		ren q25b		C12
		ren q25c		C15
		ren q36_orig	C16_1
		ren q37			C16_2
		ren q49bc		C25_B
			recode C25_B (0=4)
		ren q49bb		C33_B
			recode C33_B (0=4)
		ren udecide1	C38_S
		ren udecide3	C39_S
		ren q49bd		C49_B
			recode C49_B (0=4)
	ren gdconts			E8_BS
	// Other vars		
	sort idno age
		gen newid = _n
		tostring newid, gen(uniqueid) format(%04.0f)
	gen WORK=1
		ren soc1		soc90_3
		ren q114 		sic80_3
		recode qver (1=1 "1_Employee") (4=2 "2_Self-employed"), gen(selfemp1)
		recode parttime (0=1) (1=2), gen(fulltime)
		ren hours0		hours_F
		recode q113 (2=1 "1_Private") (1=2 "2_Public"), gen(sector)
		gen maxqual = 0 if q156<. | q156a<.
			replace maxqual=1 if q156a==1
			replace maxqual=2 if q156b==1 | q156d==1 | q156g==1 | q156m==1 | q156s==1
			replace maxqual=3 if q156c==1 | q156e==1 | q156f==1 | q156h==1 | q156j==1  | q156k==1 | q156l==1 | q156r==1 
			replace maxqual=4 if q156i==1 | q156n==1 | q156o==1 | q156p==1 
			replace maxqual=5 if q156q==1	
		gen _year = 1992
		gen _survey = "eib92"
	ren lfswt5			_weight
		ren wt1			_weight_2		// Could try approximating _weight_2  by using nworkers*nhh (and then rescaling to 1)
		ren wt3			_weight_eib		// This is the NR weight that only adjusts for gender - prob the most comparable to the Skills Surveys
		destring postsect, gen(_PSU)
	recode stdreg (1/8 11=1) (9=4) (10=2), gen(_country)
		recode stdreg (1=1 "1_north") (2=3 "3_yorkshire and the humber") (3=2 "2_north west") (4=4 "4_east mids") (5=5 "5_west mids") (6=6 "6_east anglia") (7=8 "8_south east") ///
			(8=9 "9_south west") (9=10 "10_wales") (10=11 "11_scotland") (11=7 "7_london"), gen(_region)
		keep D* C* E* uniqueid sex age WORK soc90_3 sic80_3 selfemp1 fulltime hours* sector _year _survey _PSU _weight* _country _region maxqual
	save "$workingdir\eib.dta", replace
// SCELI
use "Z:\PhD datasets\Work-related datasets\1986 Social change and economic life survey (SN2798)\stata8_se\f798a.dta", replace
	numlabel _all, mask(#_) add
	keep if addtype==1 | addtype==3			// The main sample, ignoring the unemployed boost
	// Main vars
	recode v98e (1=1) (0 2=2) (else=.), gen(C2_C)
	ren v99 	C23
	mvdecode C*, mv(7/8=.)
	// Work history vars
	capture drop lastwave co80_5 hours_B sector
		gen 	lastwave = .
		gen 	wkhis_actcod = .
		gen 	co80_5 = .
		gen 	sector = .
		gen 	hours_B = .
		label values hours_B rhrswk4
	forvalues i = 1/43	{
		replace lastwave = `i'		if rcurev`i' ==1						// The wave in the work history dataset that corresponds to the present
		replace wkhis_actcod = ractcd`i' if rcurev`i' ==1
		replace co80_5 = roug80`i'	if rcurev`i' ==1 & ractcd`i'<=3
		replace hours_B = rhrswk`i' if rcurev`i' ==1 & ractcd`i'<=3
		replace sector  = rpbprv`i' 	if rcurev`i' ==1 & ractcd`i'<=3
						}
		replace co80_5 = round(co80_5*100)
	recode sector (2=1) (1=2) (7/9=.)		// recoded as 1=Private in my main dataset
	mvdecode hours_B, mv(77 88 99)
	// Other vars		
	tostring qno, gen(uniqueid) format(%8.0f)
	recode v1 (1/5=1) (else=2) if v1<., gen(WORK)
		recode v1 (6=1) (else=2) if v1<., gen(govsch)
		recode v1 (4/5=1) (else=2) if v1<., gen(tempsick_B)				// This is for being away from work, but not necessarily temporarily sick - possibly on holiday
		recode v1 (2/5=1 "1_Employee") (1=2 "2_Self-employed") (else=.), gen(selfemp1)
		recode v1 (2 4=1 "1_F/t") (3 5=2 "2_P/t") (else=.), gen(fulltime)
	gen _survey = "SCELI"
		gen _year = 1986
		tostring date, gen(dateS) format(%04.0f)
			gen _month = substr(dateS,3,2)
			destring _month, replace
	gen _weight_2 = eligible/eno  if list==1
			replace _weight_2 = eligible/(eno*househol) if list==2
			sum _weight_2, det
			replace _weight_2 = _weight / r(mean)
		clonevar _PSU = area
	recode area (1 3 =2) (2 4/6 =1), gen(_country)
	keep C* uniqueid sex age WORK govsch tempsick_B co80_5 selfemp1 fulltime hours_B sector _year _month _survey _weight_2 _PSU _country
	save "$workingdir\sceli.dta", replace
// WERS 98 - for merging, note that 409 workplaces had no employee responses, while 1 workplace (25 employees) had no management response
	// Merging in other data
	use serno estwtnr using "Z:\PhD datasets\Work-related datasets\WERS 2004 (SN5294)\stata8\ps9804_pq04v3.dta", clear		// This is for the edited weights - see note in spreadsheet
		sort serno
		save "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\BB_2004panel.dta", replace
	use "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\mq98_sic_final.dta", replace		// Contains only 3 vars - all I need is ASIC_FIN
		sort serno
		save, replace
	use serno astatus zallemps est_wt using "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\mq98fin.dta", replace			// Simply for public vs. private sector
		sort serno
		save "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\BB_mq98fin.dta", replace
	use serno idbrstr2 using "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\sample98.dta", replace		// For the stratification variable (see spreadsheet)
		sort serno
		save "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\BB_sample98.dta", replace
	use "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\seq98.dta", replace
		sort serno
		merge serno using "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\mq98_sic_final.dta"	// One workplace (serno==13068) has no SIC
			drop _merge
			sort serno
		merge serno using "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\BB_mq98fin.dta"
			drop _merge
			sort serno
		merge serno using "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\BB_2004panel.dta"
			drop _merge
			sort serno
		merge serno using "Z:\PhD datasets\Work-related datasets\WERS 1998 (SN3955)\stata8\BB_sample98.dta"
			drop _merge
	// Tidying up
	numlabel _all, mask(#_) add
	drop if serial==.					// 409 workplaces have no respondents - not needed 
	gen seqwtnr=((empwt_nr*(estwtnr/est_wt))*100/1084)			// Syntax taken from WERS2004 documentation - see spreadsheet
	// Main vars
	mvdecode a9b a9c, mv(-9 5 7)
	mvdecode a8a a8b, mv(-9 6 7)
	ren a8a			D1_BS
		ren a8b		D20_BS
	ren a9b			C5_S
		ren a9c		C26_S
	// Other vars	
	tostring serial, gen(uniqueid) format(%8.0f)
		recode d1 (-9=.a ".a_-9 Not answered"), gen(sex)
		recode d2 (-9=.a), gen(agegrp1)
		label values agegrp1 d2
	gen WORK = 1
		gen govsch=2
		recode d9 (min/0 = .), gen(soc90_1)
		replace soc90_1 = d10code if d10code>0 & d10code<10
		ren asic_fin	sic92_5
		// No data on p/t vs. f/t
		recode a3 (min/0=.), gen(hours)
		// No data on self-emp - primarily because self-employed people are not included (not as a separate category, anyway)
		recode astatus (1/2=1 "1_Private") (3=2 "2_Public"), gen(sector)
	gen _survey = "WERS1998"
		gen _year = 1998
	ren seqwtnr			_weight
		ren serno		_PSU
		ren idbrstr2 	_strata
	keep D* C* uniqueid sex agegrp1 WORK govsch soc90_1 sic92_5 hours sector _year _survey _weight _strata _PSU
	save "$workingdir\wers98.dta", replace
// WERS 04	
	// Merging in establishment-level data
	use serno cell_no zallemps asic2003 asic92 asic80 astatus1 using "Z:\PhD datasets\Work-related datasets\WERS 2004 (SN5294)\stata8\xs04_mqv2.dta", replace
		// Stratification variable - code taken from http://www.wers2004.info/pdf/WERS%202004%20Cross-Section%20-%20wpstr04.do
		gen wpstr04=cell_no if cell_no<=17
		replace wpstr04=(cell_no+1) if cell_no>=18
		recode wpstr04 (11/12=13) (17=16) (19/21=22) (25/26=27) (36=35) (37=38) (40=41) (44=43) (59=60) (64=65) (82=83) (107=108)
		// Normal merging for the other vars
		sort serno
		save "Z:\PhD datasets\Work-related datasets\WERS 2004 (SN5294)\stata8\BB_xs04_mqv2.dta", replace
	use "Z:\PhD datasets\Work-related datasets\WERS 2004 (SN5294)\stata8\xs04_seqv2.dta", replace
		sort serno
		merge serno using "Z:\PhD datasets\Work-related datasets\WERS 2004 (SN5294)\stata8\BB_xs04_mqv2.dta"	// One workplace (serno==13068) has no SIC
		drop _merge
		drop if persid==.
	drop if zallemps<10			// This makes it comparable to WERS98, which is the only comparison you can really do with WERS
	numlabel _all, mask(#_) add
	// Main vars
	mvdecode a6a a6b a7b a7c, mv(-9 -8 -6)
	ren a6a			D1_BS
		ren a6b		D20_BS
	ren a7b			C5_S
		ren a7c		C26_S
	// Other vars	
	tostring serno, gen(sernoS) format(%8.0f)
			tostring persid, gen(persidS) format(%02.0f)
			gen uniqueid = sernoS + persidS
		recode e1 (-9=.a ".a_-9 Not answered"), gen(sex)
		recode e2 (-9=.a), gen(agegrp2)
		label values agegrp2 e2
	gen WORK = 1
		gen govsch=2
		recode xsoc2000 (99998=.r ".r_Refusal") (99999=.d ".d_DK"), gen(soc00_4)
		gen sic80_4 = asic80/10
			ren asic2003 	sic03_5
			ren asic92		sic92_5
		// No data on p/t vs. f/t
		recode a3 (min/0=.), gen(hours)
		recode astatus1 (min/0=.) (1/7=1 "1_Private") (8/12=2 "2_Public"), gen(sector)
		// No data on self-emp - primarily because self-employed people are not included (not as a separate category, anyway)
	gen _survey = "WERS2004"
		gen _year = 2004
	ren seqwtnr2	_weight
		ren wpstr04		_strata
		ren serno		_PSU
	keep D* C* uniqueid sex agegrp2 WORK govsch soc00_4 sic80_4 sic92_5 sic03_5 hours sector _year _survey _weight _strata _PSU
	save "$workingdir\wers04.dta", replace
/////////////////////////////////////////////////////
/////////////////////////////////////////////////////
/////////////////////////////////////////////////////
// Health Surveys for England and Scotland
/////////////////////////////////////////////////////
/////////////////////////////////////////////////////
/////////////////////////////////////////////////////
use "Z:\PhD datasets\Work-related datasets\HSE 1993 (SN3316)\stata8\3316.dta", replace
	numlabel _all, mask(#_) add
	keep if schedtyp==2 | schedtyp==3		// Removes proxy responses and NR to the interview
	mvdecode _all, mv(-9 -8 -7)
	// Main vars
	ren workfast		D6_S
		ren worktens	D10_S
		ren worktime	D19_S
	ren worksay			C14_S
		ren workchoi	C29_S
	ren active			P5
	// Other vars 
	sort labno persno age
		gen count = _n
		tostring count, gen(uniqueid) format(%8.0f)
	ren worklast			WORK
		ren work			WORK_B
		ren soc				soc90_3
		ren ind				sic80_3
		ren thirtyhr		fulltime
		ren employee		selfemp1
	gen _survey = "HSE1993"
		ren yintb			_year					// intb variables refer to the individual interview (inta to the household interview)
		replace _year = _year+1900 if _year<.
		ren mintb		_month
	gen _weight_2 = 1 				// Unweighted version accounts for selection weights by design - see spreadsheet notes
		ren area		_PSU
		// Couldn't find a household identifier, but this isn't necessary due to the structure of the sampling (I think, assuming similar to HSE94)
	recode psychsc (1=1 "1_S/c accepted") (2=2 "2_s/c accepted but assistance given") (3=3 "3_s/c accepted but interviewer administered, no-one else present") ///
		(4=4 "4_s/c accpeted but interviewer administered, others present") (5=5 "5_s/c refused") (else=.), gen(_sc_HSE)
	gen _country=1
	keep C* D* P* uniqueid sex age WORK* soc90_3 sic80_3 fulltime selfemp1 _year _month _survey _weight_2 _PSU _country _sc*
	save "$workingdir\hse93.dta", replace
use "Z:\PhD datasets\Work-related datasets\HSE 1994 (SN3640)\stata8\hse94ai2nd.dta", replace
	* For some reason NUMLABEL doesn't work in this dataset
	// Main vars
	ren workfast		D6_S
		ren worktens	D10_S
		ren worktime	D19_S
	ren worksay			C14_S
		ren workchoi	C29_S
	ren phywrk			P1
		ren active		P5
		ren liftwrk		P12
	mvdecode D* C* P*, mv(9)
	// Other vars
	tostring pserial, gen(uniqueid) format(%10.0f)
	ren worklast 		WORK
		ren work		WORK_B
		mvdecode WORK*, mv(9)
		ren soc			soc90_3
		ren sic			sic80_2
		ren thirtyhr	fulltime
		ren employee	selfemp1
	ren yintb		_year
		replace _year = _year+1900 if _year<.
		ren mintb	_month
	gen _survey = "HSE1994"	
	gen _weight_2 = 1 				// Unweighted version accounts for selection weights by design - see spreadsheet notes
		ren area	_PSU
		ren hhold	_PSU2				// This is a clustering var as ALL households at an address were sampled (to remove the need for selection weights)
	recode psychsc (1=1 "1_S/c accepted") (2=2 "2_s/c accepted but assistance given") (3=3 "3_s/c accepted but interviewer administered, no-one else present") ///
		(4=4 "4_s/c accpeted but interviewer administered, others present") (5=5 "5_s/c refused") (else=.), gen(_sc_HSE)
	gen _country=1
	keep P* C* D* uniqueid sex age WORK* soc90_3 sic80_2 fulltime selfemp1 _year _month _survey _weight_2 _sc* _PSU _PSU2 _country 
		mvdecode _all, mv(-7 -1)
		mvdecode P1 P5 fulltime selfemp1, mv(9)
	save "$workingdir\hse94.dta", replace
use "Z:\PhD datasets\Work-related datasets\HSE 1997 (SN3979)\stata8\hse97ai.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren active			P5
		ren liftwrk		P12
	// Other vars
	tostring pserial, gen(uniqueid) format(%10.0f)
	recode activ (min/0=.) (2=1) (1 3/9=2), gen(WORK)
		ren work		WORK_B
		ren soc			soc90_3
		ren sic			sic92_2
		ren ftptime		fulltime
		ren employee	selfemp1
	gen _survey = "HSE1997"	
		ren yintb		_year 
		ren mintb		_month
	gen _weight_2 = 1 				// Unweighted version accounts for selection weights by design - see spreadsheet notes
		ren area		_PSU
		ren hserial		_PSU2
	gen _country=1
	keep P* uniqueid sex age WORK* soc90_3 sic92_2 fulltime selfemp1 _year _month _survey _weight_2 _PSU _PSU2 _country
	mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\hse97.dta", replace	
use "Z:\PhD datasets\Work-related datasets\HSE 1998 (SN4150)\stata8\hse98ai.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren active			P5
		ren liftwrk		P12
	// Other vars
	tostring pserial, gen(uniqueid) format(%10.0f)
	recode activb (min/0=.) (2=1) (1 3/11=2), gen(WORK)
		recode activb (min/0=.) (3=1) (1/2 4/11=2), gen(govsch)
		ren work		WORK_B
		ren soc			soc90_3
		ren sic			sic92_2
		ren ftptime		fulltime
		ren employe		selfemp1
	gen _survey = "HSE1998"	
		ren yintb		 _year
		ren mintb	_month
	gen _weight_2 = 1 				// Unweighted version accounts for selection weights by design - see spreadsheet notes
		ren area	_PSU
		ren hserial	_PSU2
	gen _country = 1				// No need for GOR, DHANO etc.
	keep P* uniqueid sex age WORK* govsch soc90_3 sic92_2 fulltime selfemp1 _year _month _survey _weight* _PSU _PSU2  _country
	mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\hse98.dta", replace	
use "Z:\PhD datasets\Work-related datasets\HSE 1999 (SN4365)\stata8\HSE99gp3.dta", replace	
	// Main vars
	ren active		P5
	// Other vars
	tostring pserial, gen(uniqueid) format(%10.0f)
	recode activb (min/0=.) (2=1) (1 3/11=2), gen(WORK)
		recode activb (min/0=.) (3=1) (1/2 4/11=2), gen(govsch)
		ren work		WORK_B
		ren soc			soc90_3
		ren sic			sic92_2
		ren ftptime		fulltime
		ren employe		selfemp1
	gen _survey = "HSE1999"	
		ren yintb		 _year
		ren mintb	_month
	gen _weight_2 = 1 				// Unweighted version accounts for selection weights by design - see spreadsheet notes
		ren area	_PSU
		ren hserial	_PSU2
	gen _country = 1				// No need for GOR, DHANO etc.
	keep P* uniqueid sex age WORK* govsch soc90_3 sic92_2 fulltime selfemp1 _year _month _survey _weight_2 _PSU _PSU2 _country
		mvdecode _all, mv(-9 -8 -1)
		numlabel _all, mask(#_) add
	save "$workingdir\hse99.dta", replace	
use "Z:\PhD datasets\Work-related datasets\HSE 2003 (SN5098)\stata8\hse03ai.dta", replace
	// Main vars
	ren active		P5
	// Other vars
	tostring pserial, gen(uniqueid) format(%10.0f)
	recode activb (min/0=.) (2=1) (1 3/11=2), gen(WORK)
		recode activb (min/0=.) (3=1) (1/2 4/11=2), gen(govsch)
		ren work		WORK_B
		ren soc90		soc90_3
			ren soc2000	soc00_4
		ren sic92		sic92_2
		ren ftptime		fulltime
		ren employe		selfemp1
	gen _survey = "HSE2003"	
		gen _year = 2003				// yintb has been removed from the dataset for confidentiality (crazily) - hence can't see if was 2003 or 2004
		ren mintb	_month
	ren int_wt		_weight
		gen _weight_2 = 1 				// Unweighted version accounts for selection weights by design - see spreadsheet notes
		ren area	_PSU
		ren hserial	_PSU2
		ren cluster	_strata
	gen _country = 1				// No need for GOR, SHA etc.
	keep P* uniqueid sex age WORK* govsch soc00_4 soc90_3 sic92_2 fulltime selfemp1 _year _month _survey _weight* _PSU _PSU2 _strata _country
		mvdecode _all, mv(-9 -8 -1)
		numlabel _all, mask(#_) add
	save "$workingdir\hse03.dta", replace	
use "Z:\PhD datasets\Work-related datasets\HSE 2004 (SN5439)\stata8\hse04gpa.dta", replace
	// Main vars
	ren active		P5
	// Other vars
	tostring pserial, gen(uniqueid) format(%10.0f)
	recode activb (min/0=.) (2=1) (1 3/95=2), gen(WORK)
		recode activb (min/0=.) (3=1) (1/2 4/95=2), gen(govsch)
		ren work		WORK_B
		ren soc90		soc90_3_R
			ren soc2000	soc00_3
		ren sic92		sic92_2
		ren ftptime		fulltime
		ren employe		selfemp1
	gen _survey = "HSE2004"	
		gen _year = 2004				// yintb has been removed from the dataset for confidentiality (crazily) - hence can't see if was 2003 or 2004
		ren mintb	_month
	ren wt_int		_weight
		gen _weight_2 = 1 				// Unweighted version accounts for selection weights by design - see spreadsheet notes
		ren area	_PSU
		ren hserial	_PSU2
		ren cluster	_strata
	gen _country = 1				// No need for GOR, SHA etc.
	keep P* uniqueid sex age WORK* govsch soc00* soc90* sic92_2 fulltime selfemp1 _year _month _survey _weight* _PSU _PSU2 _strata _country
		numlabel _all, mask(#_) add
		mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\hse04.dta", replace		
use "Z:\PhD datasets\Work-related datasets\HSE 2008 (SN6397)\stata8_se\hse08ai.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren active		P5
	// Other vars
	tostring pserial, gen(uniqueid) format(%10.0f)
	recode activb (min/0=.) (2=1) (1 3/95=2), gen(WORK)
		recode activb (min/0=.) (3=1) (1/2 4/95=2), gen(govsch)
		ren work		WORK_B
		ren soc2000b	soc00_2
		ren sic2003b	sic03_1
		ren ftptime		fulltime
		ren employe		selfemp1
	gen _survey = "HSE2008"	
		gen _year = 2008				// yintb has been removed from the dataset for confidentiality (crazily) - hence can't see if was 2003 or 2004
		ren mintb	_month
	ren wt_int		_weight
		gen _weight_2 = 1 				// Unweighted version accounts for selection weights by design - see spreadsheet notes
		ren psu		_PSU
		ren hserial	_PSU2
		ren cluster	_strata
	gen _country = 1				// No need for GOR, SHA etc.
	keep P* uniqueid sex age WORK* govsch soc00* sic* fulltime selfemp1 _year _month _survey _weight* _PSU _PSU2 _strata _country
		mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\hse08.dta", replace	
use "Z:\PhD datasets\Work-related datasets\Scottish Health Survey 2003 (SN5318)\stata8\shs03i.dta", replace	
	numlabel _all, mask(#_) add
	// Main vars
	ren	demand			P1
		ren active		P5
		ren liftwrk		P12
	// Other vars
	tostring pserial, gen(uniqueid) format(%10.0f)
	recode nactiv (min/0=.) (2=1) (1 3/97=2), gen(WORK)
		recode nactiv (min/0=.) (3=1) (1/2 4/97=2), gen(govsch)
		ren work		WORK_B
		ren soc2000		soc00_4
			ren soc90	soc90_3_R
		ren sic92		sic92_2
			ren sic92maj	sic92_1
		ren ftptime		fulltime
		ren employe		selfemp1
	gen _survey = "SHS2003"	
		gen _year = 2003				// yintb has been removed from the dataset for confidentiality (crazily) - hence can't see if was 2003 or 2004
		ren mintb		_month
	ren int_wt			_weight				// No design weight is available (and can't do =1 as unequal selection by areas)
		ren hhserial	_PSU
	gen _country=2
	keep P* uniqueid sex age WORK* govsch soc00* sic92_? fulltime selfemp1 _year _month _survey _weight _country _PSU
		mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\shs03.dta", replace	
use "Z:\PhD datasets\Work-related datasets\Scottish Health Survey 1998-9 (SN4379)\stata8\shs98i.dta", replace	
	// Main vars
	ren	demand		P1
	ren active		P5
		ren liftwrk		P12
	// Other vars
	tostring archsn, gen(uniqueid) format(%10.0f)
	recode activ (min/0=.) (2=1) (1 3/9=2), gen(WORK)
		ren work		WORK_B
		ren soc			soc90_3
		ren sic			sic92_2
			ren sicmaj	sic92_1
		ren ftptime		fulltime
		ren employe		selfemp1
	gen _survey = "SHS1998"	
		gen _year = 1998 // yintb has been removed from the dataset for confidentiality (crazily) - hence can't see year
	ren weighta		_weight
/*	I made an attempt to create design weights here, but the areas were selected with unequal probabilities in all of the SHS surveys, so it's prob best to ignore this
		gen _weight_2 = nofad * nofhh if nofhh>0
			sum _weight_2, det
			replace _weight_2 = _weight_2 / r(mean)
*/		ren archpt	_PSU			// This is slightly uncertain but it appears to be right (it is exactly double the number of PSUs mentioned in the UG though)
	gen _country=2
	keep P* uniqueid sex age WORK* soc90* sic92_* fulltime selfemp1 _year _survey _weight* _PSU _country
		mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\shs98.dta", replace	
use "Z:\PhD datasets\Work-related datasets\Scottish Health Survey 1995 (SN3807)\stata8\shs95i.dta", replace	
	numlabel _all, mask(#_) add
	// Main vars
	ren	demand			P1
		ren liftcarr	P12
	// Other vars
	tostring serialx, gen(uniqueid) format(%10.0f)
		ren respsex		sex
		ren respage		age
	recode activ (min/0=.) (2=1) (1 3/97=2), gen(WORK)
		recode activ (min/0=.) (3=1) (1 2 4/97=2), gen(govsch)
		ren soc			soc90_3
		ren sic			sic92_2
		ren ftptime		fulltime
		ren employe		selfemp1
	gen _survey = "SHS1995"	
		ren intyear 	_year 
		replace _year=. if _year==9950
		ren intmon 	_month
			replace _month=. if _month>12
	ren weighta		_weight
		ren areax 	_PSU			
	gen _country=2
	keep P* uniqueid sex age WORK* govsch soc90* sic* fulltime selfemp1 _year _month _survey _weight _PSU _country
		mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\shs95.dta", replace	
/////////////////////////////////////////////////////
/////////////////////////////////////////////////////
// ONS Omnibus surveys
/////////////////////////////////////////////////////
/////////////////////////////////////////////////////
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus 1992-4 Apr (SN3087)\stata8\a920441.dta", replace	
	numlabel _all, mask(#_) add
	// Main vars
	ren	m41_2		P5
	// Other vars
	gen count = _n
			tostring count, gen(uniqueid) format(%10.0f)
		ren q112		sex
		ren q113		age
	ren q117		WORK
		ren m41_1	WORK_B
		ren q123		soc90_3
		// Unclear what coding scheme q124 (industry) uses, so ignored
		recode q118 (1=1) (2/3=2), gen(fulltime)
		ren q125		selfemp1
	gen _survey = "omni92-4"	
		gen _year = 1992
		gen _month = 4
	ren wta			_weight_2
	recode regionx (1/5 = 7) (6=2), gen(_country)
	keep P* uniqueid sex age WORK* soc* fulltime selfemp1 _year _month _survey _weight_2 _country
		mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\omni92-4.dta", replace		
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus 1992-5 May (SN3088)\stata8\a920541.dta", replace	
	numlabel _all, mask(#_) add
	// Main vars
	ren	m41_2		P5
	// Other vars
	gen count = _n
			tostring count, gen(uniqueid) format(%10.0f)
		ren q112		sex
		ren q113		age
	ren q117		WORK
		ren m41_1	WORK_B
		ren q123		soc90_3
		// Unclear what coding scheme q124 (industry) uses, so ignored
		recode q118 (1=1) (2/3=2), gen(fulltime)
		ren q125		selfemp1
	gen _survey = "omni92-5"	
		gen _year = 1992
		gen _month = 5
	ren wta			_weight_2
	recode regionx (1/5 = 7) (6=2), gen(_country)
	keep P* uniqueid sex age WORK* soc* fulltime selfemp1 _year _month _survey _weight_2 _country 
		mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\omni92-5.dta", replace			
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus 1996-4 Apr (SN3904)\stata8\c9604142.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren	m142_9		C10
	// Other vars
	tostring serial, gen(uniqueid) format(%14.0f)
		ren respsex 	sex
		ren respage 	age
	ren paidwork 	WORK
		replace WORK=1 if away==1
		recode away (1=1) (else=2) if WORK<., gen(tempsick_B)
		ren soccode		soc90_3
		// Unclear what coding scheme INDCODE (industry) uses, so ignored - doesn't seem to be either SIC80 or SIC92
		recode fullpart (1=1) (2/3=2), gen(fulltime)
		ren stat		selfemp1
	gen _survey = "omni96-4"	
		gen _year = 1996
		gen _month = 4
	ren wta			_weight_2
		ren area	_PSU			// This is guesswork - I have no idea what this var refers to, but it plausibly refers to the PSUs
	recode regionx (1/5 = 7) (6=2), gen(_country)
	keep C* uniqueid sex age WORK tempsick_B soc* fulltime selfemp1 _year _month _survey _weight _PSU _country
		mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\omni96-4.dta", replace	
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus 1996-5 May (SN3905)\stata8\a9605142.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren	m142_9		C10_B
	// Other vars
	tostring serial, gen(uniqueid) format(%14.0f)
		ren respsex 	sex
		ren respage 	age
	ren paidwork 	WORK
		replace WORK=1 if away==1
		recode away (1=1) (else=2) if WORK<., gen(tempsick_B)
		ren soccode		soc90_3
		// Unclear what coding scheme INDCODE (industry) uses, so ignored - doesn't seem to be either SIC80 or SIC92
		recode fullpart (1=1) (2/3=2), gen(fulltime)
		ren stat		selfemp1
	gen _survey = "omni96-5"	
		gen _year = 1996
		gen _month = 5
	ren wta			_weight_2
	recode regionx (1/5 = 7) (6=2), gen(_country)
	keep C* uniqueid sex age WORK tempsick_B soc* fulltime selfemp1 _year _month _survey _weight _country
		mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\omni96-5.dta", replace	
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus 1996-7 Jul (SN3907)\stata8\a9607142.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren	m142_9		C10_B
	// Other vars
	tostring serial, gen(uniqueid) format(%14.0f)
		ren respsex 	sex
		ren respage 	age
	ren paidwork 	WORK
		replace WORK=1 if away==1
		recode away (1=1) (else=2) if WORK<., gen(tempsick_B)
		ren soccode		soc90_3
		// Unclear what coding scheme INDCODE (industry) uses, so ignored - doesn't seem to be either SIC80 or SIC92
		recode fullpart (1=1) (2/3=2), gen(fulltime)
		ren stat		selfemp1
	gen _survey = "omni96-7"	
		gen _year = 1996
		gen _month = 7
	ren wta			_weight_2
	recode regionx (1/5 = 7) (6=2), gen(_country)
	keep C* uniqueid sex age WORK tempsick_B soc* fulltime selfemp1 _year _month _survey _weight _country
		mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\omni96-7.dta", replace	
/////////////////////////////////////////////////////
// Psychosocial Working Conditions Surveys
/////////////////////////////////////////////////////
// This is for merging in the occupational data which is otherwise unavailable 
	use "Z:\PhD datasets\Work-related datasets\ONS Omnibus - Psychosocial Working Conditions Survey 2004-2008\Psychosocial Ben Baumberg Version.dta", replace
		// April 2004
		preserve
			keep if sdate==2
			#delimit ;			// For renaming vars
				ren coQ2 m346_1 ; ren deQ16 m346_12 ; ren deQ18 m346_2 ; ren deQ6 m346_3 ; ren deQ20 m346_4 ; ren msQ8 m346_5 ; ren deQ9 m346_6 ; ren coQ10 m346_7 ; ren coQ19 m346_8 ; ren deQ12 m346_9 ;ren deQ3 m346_10 ; ren coQ15 m346_11 ; ren psQ7 m346_13 ; ren deQ22 m346_14 ; ren msQ23 m346_15 ; ren roQ11 m346_16 ; ren reQ21 m346_17 ; ren coQ25 m346_18 ; ren psQ24 m346_19 ; ren psQ27 m346_20 ; ren msQ29 m346_21 ; ren msQ33 m346_22; ren coQ30 m346_23; ren psQ31 m346_24; ren msQ35 m346_25; ren chQ28 m346_26; ren reQ34 m346_27; 
			#delimit cr;
			forvalues i = 1/27	{		// Create "m346_1 m346_2 etc." in a local
				local z "`z' m346_`i'"
								}
			capture drop pattern patt_count
				egen pattern = group(`z' age), label
				bysort pattern: gen patt_countHSE = _N
				tab patt_countHSE
				drop if patt_countHSE>1
			keep idno pattern soc 
			sort pattern
			save "$workingdir\hse-pwcs04-4.dta", replace
		restore
		// March 2004 2005
		#delimit ;			// For renaming vars
			ren roQ1 m346_1; ren roQ13 m346_2; ren roQ4 m346_3; ren reQ14 m346_4; ren roQ11 m346_5; ren roQ17 m346_6; ren reQ5 m346_7; ren reQ21 m346_8; ren deQ22 m346_9; ren coQ15 m346_10; ren chQ28 m346_11; ren reQ34 m346_12; ren chQ26 m346_13; ren chQ32 m346_14; ren msQ35 m346_15; 
			#delimit cr;
		preserve		// March 2004
			keep if sdate==1
			local z ""
			forvalues i = 1/15	{		// Create "m346_1 m346_2 etc." in a local
				local z "`z' m346_`i'"
								}
			capture drop pattern patt_count
				egen pattern = group(`z' age), label
				bysort pattern: gen patt_countHSE = _N
				tab patt_countHSE
				drop if patt_countHSE>1
			keep idno pattern soc 
			sort pattern
			save "$workingdir\hse-pwcs04-3.dta", replace
		restore
		preserve		// March 2005
			keep if sdate==3
			local z ""
			forvalues i = 1/15	{		// Create "m346_1 m346_2 etc." in a local
				local z "`z' m346_`i'"
								}
			capture drop pattern patt_count
				egen pattern = group(`z' age), label
				bysort pattern: gen patt_countHSE = _N
				tab patt_countHSE
				drop if patt_countHSE>1
			keep idno pattern soc 
			sort pattern
			save "$workingdir\hse-pwcs05-3.dta", replace
		restore
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus - Psychosocial Working Conditions Survey 2004-2008\ONS Omnibus Apr 2004 - Psychosocial Working Conditions Survey (SN5285)\stata8\c0404346.dta", replace
	numlabel _all, mask(#_) add
	// Merging
	local z ""
	forvalues i = 1/27	{		// Create "m346_1 m346_2 etc." in a local
		local z "`z' m346_`i'"
						}
	capture drop pattern patt_count
		egen pattern = group(`z' respage), label
		bysort pattern: gen patt_count = _N
		tab patt_count
	sort pattern
		merge pattern using "$workingdir\hse-pwcs04-4.dta"
		drop if _merge==2
		replace soc=. if patt_count>1
	// Main vars
	ren m346_14		D24
		ren m346_4	D8
		ren m346_6	D11
	ren m346_7		C6
		ren m346_11	C30
		ren m346_8	C36
		ren m346_18	C24
	ren m346_22		E4
	// Other vars
	tostring serial, gen(uniqueid) format(%14.0f)
		ren respsex 	sex
		ren respage 	age
	ren wrking 	WORK
			replace WORK=1 if jbaway==1
		ren soc			soc00_4				// This is what the merge above achieved - a bit faffy really...
		ren ftptwk		fulltime
		ren stat		selfemp1
	gen _survey = "pwcs04-4"	
		gen _year = 2004
		gen _month = 4
	ren wta			_weight_2
		gen _area = substr(uniqueid, -7, 5)		// See Spreadsheet note
		destring _area, gen(_PSU)
	recode regionx (1/5=1) (6=4) (7=2), gen(_country)
	keep C* D* E* uniqueid sex age WORK soc* fulltime selfemp1 _year _month _survey _weight* _PSU _country
	save "$workingdir\pwcs04-4.dta", replace	
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus - Psychosocial Working Conditions Survey 2004-2008\ONS Omnibus Apr 2006 - Psychosocial Working Conditions Survey (SN5997)\stata8\f0604346.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	mvdecode m346_14 m346_4 m346_6 m346_7 m346_11 m346_8 m346_18 m346_22, mv(9)
	ren m346_14		D24
		ren m346_4	D8
		ren m346_6	D11
	ren m346_7		C6
		ren m346_11	C30
		ren m346_8	C36
		ren m346_18	C24
	ren m346_22		E4
// Other vars
	tostring serial, gen(uniqueid) format(%09.0f)
		ren respsex 	sex
		ren respage 	age
	ren wrking 	WORK
			replace WORK=1 if jbaway==1
		ren xsoc2000	soc00_4
			// No SIC
		ren ftptwk		fulltime
		ren stat		selfemp1
	gen _survey = "pwcs06-4"	
		gen _year = 2006
		gen _month = 4
	ren wta			_weight_2
		ren indwgt	_weight
		gen _area = substr(uniqueid, 1, 5)		// See Spreadsheet note
		destring _area, gen(_PSU)
	recode gora (1/9=1) (10=4) (11=2), gen(_country)
	keep C* D* E* uniqueid sex age WORK soc* fulltime selfemp1 _year _month _survey _weight* _PSU _country
	save "$workingdir\pwcs06-4.dta", replace	
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus - Psychosocial Working Conditions Survey 2004-2008\ONS Omnibus Apr 2007 - Psychosocial Working Conditions Survey (SN6149)\stata8\f0704346b.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	mvdecode m346_14 m346_4 m346_6 m346_7 m346_11 m346_8 m346_18 m346_22, mv(8 9)
	ren m346_14		D24
		ren m346_4	D8
		ren m346_6	D11
	ren m346_7		C6
		ren m346_11	C30
		ren m346_8	C36
		ren m346_18	C24
	ren m346_22		E4
	// Other vars
	tostring serial, gen(uniqueid) format(%09.0f)
		ren respsex 	sex
		ren respage 	age
	ren wrking 	WORK
			replace WORK=1 if jbaway==1
		ren xsoc2000	soc00_4
			// No SIC
		ren ftptwk		fulltime
		ren stat		selfemp1
			mvdecode selfemp1, mv(8 9)
	gen _survey = "pwcs07-4"	
		gen _year = 2007
		gen _month = 4
	ren wta			_weight_2
		ren indwgt	_weight
		gen _area = substr(uniqueid, 1, 5)		// See Spreadsheet note
		destring _area, gen(_PSU)
		// No PSU was supplied or derive-able
	recode gora (1/9=1) (10=4) (11=2), gen(_country)
	keep C* D* E* uniqueid sex age WORK soc* fulltime selfemp1 _year _month _survey _weight* _PSU _country
	save "$workingdir\pwcs07-4.dta", replace	
// 2008 data from the datafile that the guy kindly sent on (but will lack key variables...)
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus - Psychosocial Working Conditions Survey 2004-2008\Psychosocial Ben Baumberg Version.dta", replace
	numlabel _all, mask(#_) add
	keep if sdate==10
	// Main vars
	ren deQ22 		D24
		ren deQ20 	D8
		ren deQ9 	D11
	ren coQ10 		C6
		ren coQ15 	C30
		ren coQ19 	C36
		ren coQ25 	C24
	ren msQ33		E4
	mvdecode C* D* E*, mv(8 9)
	// Other vars
	tostring idno, gen(uniqueid) format(%09.0f)
		ren respsex 	sex			// For some reason, all observations have missing data in 2008 - obviously a very preliminary version of the dataset...
		// Age is correctly named
	gen WORK = 1 if D24<. // No WORK var, so I've improvised
		ren soc		soc00_4
			ren sic	sic92_1
		// No fulltime, selfemp1
	gen _survey = "pwcs08-4"	
		gen _year = 2008
		gen _month = 4
	ren wta			_weight_2
		gen _area = substr(uniqueid, 1, 5)		// See Spreadsheet note
		destring _area, gen(_PSU)
		// No PSU was supplied or derive-able
	recode regiona (1/9=1) (10=4) (11=2), gen(_country)
	keep C* D* E* uniqueid sex age WORK soc* sic* _year _month _survey _weight* _PSU _country
	save "$workingdir\pwcs08-4.dta", replace	
// The following PWCS datasets have the other bank of questions, that includes less on demands and control	
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus - Psychosocial Working Conditions Survey 2004-2008\ONS Omnibus Mar 2004 - Psychosocial Working Conditions Survey (SN5284)\stata8\c0403346.dta", replace
	numlabel _all, mask(#_) add
	// Merging 
	local z ""
	forvalues i = 1/15	{		// Create "m346_1 m346_2 etc." in a local
		local z "`z' m346_`i'"
						}
	capture drop pattern patt_count
		egen pattern = group(`z' respage), label
		bysort pattern: gen patt_count = _N
		tab patt_count
	sort pattern
		merge pattern using "$workingdir\hse-pwcs04-3.dta"
		drop if _merge==2
		replace soc=. if patt_count>1
	// Main vars
	ren m346_9		D24
	ren m346_10		C30
	// Other vars - 2004031102710
	tostring serial, gen(uniqueid) format(%014.0f)
		ren respsex 	sex
		ren respage 	age
	ren wrking 	WORK
			replace WORK=1 if jbaway==1
		ren soc			soc00_4				// This is what the merge above achieved - a bit faffy really...
		ren ftptwk		fulltime
		ren stat		selfemp1
	gen _survey = "pwcs04-3"	
		gen _year = 2004
		gen _month = 3
	ren wta			_weight_2
		gen _area = substr(uniqueid, -7, 5)		// See Spreadsheet note
		destring _area, gen(_PSU)
	recode regionx (1/5=1) (6=4) (7=2), gen(_country)
	keep C* D* uniqueid sex age WORK soc* fulltime selfemp1 _year _month _survey _weight* _PSU _country
	save "$workingdir\pwcs04-3.dta", replace	
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus - Psychosocial Working Conditions Survey 2004-2008\ONS Omnibus Mar 2005 - Psychosocial Working Conditions Survey (SN5577)\stata8\f0503346.dta", replace
	numlabel _all, mask(#_) add
	// Merging
	local z ""
	forvalues i = 1/15	{		// Create "m346_1 m346_2 etc." in a local
		local z "`z' m346_`i'"
						}
	capture drop pattern patt_count
		egen pattern = group(`z' respage), label
		bysort pattern: gen patt_count = _N
		tab patt_count
	sort pattern
		merge pattern using "$workingdir\hse-pwcs05-3.dta"
		drop if _merge==2
		replace soc=. if patt_count>1
	// Main vars
	ren m346_9		D24
	ren m346_10		C30
	mvdecode D* C*, mv(8 9)
	// Other vars
	tostring serial, gen(uniqueid) format(%14.0f)
		ren respsex 	sex
		ren respage 	age
	ren wrking 	WORK
			replace WORK=1 if jbaway==1
		ren soc		soc00_4
		// No SIC
		ren ftptwk		fulltime
		ren stat		selfemp1
	gen _survey = "pwcs05-3"	
		gen _year = 2005
		gen _month = 3
	ren wta			_weight_2
		gen _area = substr(uniqueid, -7, 5)		// See Spreadsheet note for 2004
		destring _area, gen(_PSU)
	recode regionx (1/5=1) (6=4) (7=2), gen(_country)
	keep C* D* uniqueid sex age WORK soc* fulltime selfemp1 _year _month _survey _weight_2 _PSU _country
	save "$workingdir\pwcs05-3.dta", replace
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus - Psychosocial Working Conditions Survey 2004-2008\ONS Omnibus Mar 2006 - Psychosocial Working Conditions Survey (SN5817)\stata8\f0603346.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren m346_9		D24
	ren m346_10		C30
	mvdecode D* C*, mv(8 9)
	// Other vars
	tostring serial, gen(uniqueid) format(%09.0f)
		ren respsex 	sex
		ren respage 	age
	ren wrking 	WORK
			replace WORK=1 if jbaway==1
		ren xsoc2000	soc00_4
			// No SIC
		ren ftptwk		fulltime
		ren stat		selfemp1
	gen _survey = "pwcs06-3"	
		gen _year = 2006
		gen _month = 3
	ren indwgt	_weight
		sum numadult, det
			gen _weight_2 = numadult / r(mean)
		gen _area = substr(uniqueid, 1, 4)		// See Spreadsheet note
			destring _area, gen(_PSU)
	recode gora (1/9=1) (10=4) (11=2), gen(_country)
	keep C* D* uniqueid sex age WORK soc* fulltime selfemp1 _year _month _survey _weight* _PSU _country
	save "$workingdir\pwcs06-3.dta", replace	
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus - Psychosocial Working Conditions Survey 2004-2008\ONS Omnibus Mar 2007 - Psychosocial Working Conditions Survey (SN6148)\stata8\f0703m346a.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren m346_9		D24
	ren m346_10		C30
	// Other vars
	tostring serial, gen(uniqueid) format(%09.0f)
		ren respsex 	sex
		ren respage 	age
	ren wrking 	WORK
			replace WORK=1 if jbaway==1
		ren xsoc2000	soc00_4
			// No SIC
		ren ftptwk		fulltime
		ren stat		selfemp1
			mvdecode selfemp1, mv(8 9)
	gen _survey = "pwcs07-3"	
		gen _year = 2007
		gen _month = 3
	ren wta			_weight_2
		ren indwgt	_weight
		gen _area = substr(uniqueid, 1, 5)		// See Spreadsheet note
		destring _area, gen(_PSU)
		// No PSU was supplied or derive-able
	recode gora (1/9=1) (10=4) (11=2), gen(_country)
	keep C* D* uniqueid sex age WORK soc* fulltime selfemp1 _year _month _survey _weight* _PSU _country
	save "$workingdir\pwcs07-3.dta", replace
use "Z:\PhD datasets\Work-related datasets\ONS Omnibus - Psychosocial Working Conditions Survey 2004-2008\ONS Omnibus Apr 2005 - Psychosocial Working Conditions Survey (SN5704)\stata8\f0504346.dta", replace 
	numlabel _all, mask(#_) add
	// Main vars
	ren m346_9		D24
	ren m346_10		C30
	mvdecode D* C*, mv(9)
	// Other vars
	tostring serial, gen(uniqueid) format(%14.0f)
		ren respsex 	sex
		ren respage 	age
	ren wrking 	WORK
			replace WORK=1 if jbaway==1
		ren xsoc2000	soc00_4
		// No SIC
		ren ftptwk		fulltime
		ren stat		selfemp1
	gen _survey = "pwcs05-4"	
		gen _year = 2005
		gen _month = 4
	ren wta			_weight_2
		ren indwgt	_weight
		gen _area = substr(uniqueid, -7, 5)		// See Spreadsheet note for 2004
		destring _area, gen(_PSU)
	recode regiona (1/9=1) (10=4) (11=2), gen(_country)
	keep C* D* uniqueid sex age WORK soc* fulltime selfemp1 _year _month _survey _weight _weight_2 _PSU _country
	save "$workingdir\pwcs05-4.dta", replace
/////////////////////////////////////////////////
/////////////////////////////////////////////////
// EWCS
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
use "Z:\PhD datasets\Work-related datasets\EWCS 2005 (SN5639)\stata8\ewcs2005.dta", replace
	numlabel _all, mask(#_) add
	keep if countid==25			// Keeping the UK data only
	// Main vars
	ren q20b_a		D4_B
		ren q20b_b	D15_B
		ren q25f	D21
	ren q24c		C7
		ren q24a	C42
	ren q25m		E3
		ren q11j	E6
	mvdecode C* D* E*, mv(8 9)
	// Other vars
	tostring id, gen(uniqueid) format(%04.0f)
	*	ren hh2a	 	sex
		capture drop age
			ren hh2b 		age
			replace age=. if age==999	
	gen WORK=1			// No var for WORK really
		recode isco (99=.), gen(isco_1)
			label values isco_1 isco 
			ren q4 		nace_2
		ren q8a			hours
			mvdecode hours, mv(888 999)
		recode q3a (3=1) (1/2=2) (else=.), gen(selfemp1)
		recode q5 (1=1) (2=2) (3/5=3) (else=.), gen(sector)
	gen _survey = "ewcs2005"	
		gen _year = 2005
		ren p1_2	_month
	ren w4			_weight
		ren w1		_weight_2
		gen numadults = 1
			forvalues i = 2/10	{
				replace numadults = numadults + 1 if (hh3_`i'b>=15 & hh3_`i'b<100)
								}
			sum numadults, det
			gen _weight_3 = numadults / r(mean)
		ren p9		_PSU
	recode nuts2 (25001/25030=1) (25031/25032=4) (25033/25036=2) (25037=3), gen(_country)
	ren q1a			uknational		// This is because the 1991 survey excluded non-nationals of the country (see EWCS 1991 SCREEN in the spreadsheet).  Q was "Q1A Are you a citizen of (country where the survey is being carried out)?"
		mvdecode uknational, mv(8 9)
	keep C* D* E* uniqueid sex age WORK isco_1 nace_2 hours selfemp1 sector _year _month _survey _weight* _PSU _country uknational
	save "$workingdir\ewcs05.dta", replace
use "Z:\PhD datasets\Work-related datasets\EWCS 2000 (SN5286)\stata8\ewcs2000.dta", replace
	numlabel _all, mask(#_) add
	keep if countid==25			// Keeping the UK data only
	// Main vars
	ren q20b_a		D4_B
		ren q20b_b	D15_B
		ren q2605	D21_B			// This was q25f in the version that was recoded to 2005 names, but this is sufficiently different that the EWCS team haven't recoded it to this var (unlike for E6, which is slightly differently worded) - so this is the original var
		replace D21_B = . if D21_B==3
	ren q24c		C7
		ren q24a	C42
	ren q11j		E6
	mvdecode C* D* E*, mv(8 9)
	// Other vars
	tostring id, gen(uniqueid) format(%06.0f)
		ren hh2a	 	sex
		capture drop age
			ren hh2b 		age
	gen WORK=1			// No var for WORK really
		recode isco (99=.), gen(isco_1)
			label values isco_1 isco 
			ren q4 		nace_2
		ren q8a			hours
			mvdecode hours, mv(999)
		recode q3a (3=1) (1/2=2) (else=.), gen(selfemp1)
		recode q5 (1=1) (2=2) (3/5=3) (else=.), gen(sector)
	gen _survey = "ewcs2000"	
		gen _year = 2000
		ren p1_2	_month
	ren w4			_weight
		ren w1		_weight_2			// This is the same as EF13BR, which is the number of workers in the hhld (except that this is rescaled)
		gen _weight_3 = (ef12r-(ef13r-1)) 
			sum _weight_3, det
			replace _weight_3 = _weight_3 / r(mean)
		// PSU is missing
	ren q1a			uknational				// This is because the 1991 survey excluded non-nationals of the country (see EWCS 1991 SCREEN in the spreadsheet)
		//	Q.1 What is your nationality? Please tell me the country (or countries) that apply. (MULTIPLE ANSWERS POSSIBLE) 12 United Kingdom (Great Britain, Northern Ireland) | 17 DK [Dont know throughout questionnaire].  It then says 'close interview', which seems to be ONLY for those that DK their nationality - which is no-one (given that people from non-EU countries were included in the survey)
	recode m7_gb (1/7=1) (8=4) (9=2), gen(_country)
	keep C* D* E* uniqueid sex age WORK isco_1 nace_2 hours selfemp1 sector _year _month _survey _weight* _country uknational
	save "$workingdir\ewcs00.dta", replace
use "Z:\PhD datasets\Work-related datasets\EWCS 1995 (SN5604)\stata8\ewcs1995.dta", replace
	numlabel _all, mask(#_) add
	keep if countid==25			// Keeping the UK data only
	// Main vars
	ren q20b_a		D4_B
		ren q20b_b	D15_B
		ren q20e	D21_B			// This was q25f in the version that was recoded to 2005 names, but this is sufficiently different that the EWCS team haven't recoded it to this var (unlike for E6, which is slightly differently worded) - so this is the original var
		replace D21_B = . if D21_B==3
	ren q24c		C7
		ren q24a	C42
	mvdecode C* D*, mv(8)
	// Other vars
	tostring id, gen(uniqueid) format(%06.0f)
		ren hh2a	 	sex
		capture drop age
			ren hh2b 		age
	gen WORK=1			// No var for WORK really
	recode isco (99=.), gen(isco_1)
		label values isco_1 isco 
		ren q4 		nace_2
	ren q8a			hours
	recode q3a (3=1) (1/2=2) (else=.), gen(selfemp1)
	recode q5 (1=1) (2=2) (3/5=3) (else=.), gen(sector)		// No 3/5 in this
	gen _year = 1995
		ren p1_2	_month
	gen _survey = "ewcs1995"	
	ren w4			_weight
		gen _weight_3 = (d12-d13) if d13<10
			replace _weight_3 = d12 if d13==10
			sum _weight_3, det
			replace _weight_3 = _weight_3 / r(mean)
		// PSU is missing
	ren q1a			uknational				// This is because the 1991 survey excluded non-nationals of the country (see EWCS 1991 SCREEN in the spreadsheet).  Text "Q.3 What is your nationality? 12 (q312) British"
	recode p7_uk (1/28=1) (29/30=4) (31/34=2), gen(_country)
	keep C* D* uniqueid sex age WORK isco_1 nace_2 hours selfemp1 sector _year _month _survey _weight* _country uknational
	save "$workingdir\ewcs95.dta", replace
use "Z:\PhD datasets\Work-related datasets\EWCS 1991 (SN5603)\stata8\ewcs1991.dta", replace
	numlabel _all, mask(#_) add
	keep if countid==25			// Keeping the UK data only
	// Main vars
	ren q20b_a		D4_B
		ren q20b_b	D15_B
	ren q24c		C7
	mvdecode C* D*, mv(8)
	// Other vars
	tostring id, gen(uniqueid) format(%05.0f)
		ren hh2a	 	sex
		capture drop age
			ren hh2b 		age
	gen WORK=1			// No var for WORK really
		// No ISCO or NACE
		ren q8a			hours
		recode d17r (5/12=1) (1/4=2) (else=.), gen(selfemp1)
		recode q5 (1=1) (2=2) (3/5=3) (else=.), gen(sector)		// No 3/5 in this
	gen _survey = "ewcs1991"	
		gen _year = 1991
		ren p1_2	_month
	ren w4			_weight
		ren w1		_weight_2		// In this dataset, the design weight is simply set to a constant '1', which I don't think is correct, but is an approximation given that its based on the Electoral Register...
		gen _weight_3 = 1 			
		/* I did try deriving _weight_3 using the number of people in the hlld as above (d14 and d15, using same syntax as 1995), but I think GB in EWCS91 used the Electoral Register, in which case the apprxomiation doesn't hold
		ren d14		_weight_3
		gen _weight_3 = (d14-d15) if d15<10
			replace _weight_3 = d14 if d15==10
			replace _weight_3 = 1 if _weight_3==0
			sum _weight_3, det
			replace _weight_3 = _weight_3 / r(mean)
		*/	
		// PSU is missing
	gen uknational = 1				// This is because the 1991 survey excluded non-nationals of the country (see EWCS 1991 SCREEN in the spreadsheet)
	recode p7_90 (1/28=1) (31/34=2) (29/30=4), gen(_country)			// p7_90 labels are only available from the GESIS online version of the data
	keep C* D* uniqueid sex age WORK hours selfemp1 sector _year _month _survey _weight* _country uknational		// To interpret p7_90, see Methodology (codebook) PDFp224
	save "$workingdir\ewcs91.dta", replace
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
// European surveys, inc. EB, ESS
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
use "Z:\PhD datasets\Work-related datasets\EB56.1 - 2001\ZA3626_F1.dta" , replace
	numlabel _all, mask(#_) add
	keep if v8==9 | v8==10		// Gets rid of non-UK / NI sample
	// Main vars
	ren v194 		D1_B
		ren v195	D20_B
	ren v185		C12_B
		ren v186	C15_B
		gen C16_1 = 2 if v217<.
			replace C16_1 = 1 if v151>=2 & v151<=4
			recode v151 (2=1) (3=2) (4=3) (else=.), gen(C16_2_B)	
	// Other vars 
	tostring v5, gen(uniqueid) format(%8.0f)
	ren v431		sex
		ren v432		age
	recode v145 (5/18=1) (1/4=2) (else=.), gen(WORK_C)
		// No SOC
		ren v165		nace_1
		recode v172 (2=1 "1_Full-time") (1=2 "2_Part-time"), gen(fulltime)
		ren v167		hours
		recode v174 (1=1 "1_Private") (2=2 "2_Public"), gen(sector)
		recode v163 (1/2 = 2 "2_Self-employed") (3/8=1 "1_Employee"), gen(selfemp1)
	gen _survey = "eb56.1 01"
		gen _year = 2001
		recode v459 (1/13=9) (14/33=10), gen(_month) 
	ren v7 		_weight
	recode v502 (2/3 5/6=1) (1=2) (7=3) (4=4) (else=.), gen(_country)
	keep D* C* uniqueid sex age WORK* nace_1 fulltime hours sector selfemp1 _year _month _survey _weight _country 
	save "$workingdir\eb56-1.dta", replace
use "Z:\PhD datasets\Work-related datasets\EB44.3 - 1996\ZA2830_F1.dta", replace
	numlabel _all, mask(#_) add
	keep if v8==9 | v8==10		// Gets rid of non-UK / NI sample
	// Main vars
	ren v123 		D1_B
		ren v124	D20_B
	recode v161 (0=2) (1=1), gen(C2_B)
		ren v117	C12_B
		ren v118	C15_B
		gen C16_1 = 2 if v151<.
			replace C16_1 = 1 if v151>=2 & v151<=4
		recode v151 (2=1) (3=2) (4=3) (else=.), gen(C16_2_B)
	// Other vars
	tostring v5, gen(uniqueid) format(%8.0f)
	ren v512	sex
		ren v513	age
	recode v67 (1/3=1) (4/12=2) (else=.), gen(WORK_C)
		ren v80		isco_2
		ren v87		nace_1
		recode v67 (2=1 "1_Full-time") (3=2 "2_Part-time") (else=.), gen(fulltime)
		ren v134	hours
		recode v106 (1=1 "1_Private") (2=2 "2_Public"), gen(sector)
		recode v67 (1=2 "2_Self-employed") (2/3=1 "1_Employee") (else=.), gen(selfemp1)
	gen _survey = "eb44.3 96"
		gen _year = 1996
		recode v531 (1/3=2) (4/34=3) (35/42=4), gen(_month) 
	ren v7 		_weight
	recode v538 (2/3 5/6=1) (1=2) (7=3) (4=4) (else=.), gen(_country)			// See p524 of the codebook for v537, and p532 for this var
	keep D* C* uniqueid sex age WORK* isco_2 nace_1 fulltime hours sector selfemp1 _year _month _survey _weight _country 
	save "$workingdir\eb44-3.dta", replace
//
// European Social Surveys
//
use "Z:\PhD datasets\Work-related datasets\ESS 2002\ess1_gb_sddf - sampling data.dta", replace		// This is the data file that contains the sampling details
	sort idno
	save "Z:\PhD datasets\Work-related datasets\ESS 2002\sampling.dta", replace
	// Main data file
	use "Z:\PhD datasets\Work-related datasets\ESS 2002\ess1gb - main country file.dta", replace
	// Note that I haven't used the NI boost sample of a further 716 people - this is niress1 - NI boost sample.dta
		sort idno
		merge idno using "Z:\PhD datasets\Work-related datasets\ESS 2002\sampling.dta"
	numlabel _all, mask(#_) add
	// Main vars
	ren wkdcorg		C46
	// Other vars
	tostring idno, gen(uniqueid) format(%8.0f)
		ren gndr	sex
		gen age = inwyr - yrbrn
	gen WORK = 2 if pdwrk<.
			replace WORK = 1 if (pdwrk==1 | crpdwk==1)
		recode empl (1/2=1) (3=2) (else=.), gen(WORK_C)
		ren iscoco	isco_4
		ren	nacer	nace_2
		// No data on p/t vs. f/t
		ren wkhtot hours
		// No data on SECTOR
		recode emplrel (1=1 "1_Employee") (2=2 "2_Self-emp") (3=3 "3_Family bus") (else=.), gen(selfemp3)		// EMPL is a more convenient question on self-employment, but it is not repeated in later ESS modules
	gen _survey = "ESS02"
		ren inwyr 	_year 
		ren inwmm	_month
	ren dweight 	_weight_2
		ren psu		_PSU
		encode stratify if stratify~="NA", gen(_strata)
	recode regiongb (1/9=1) (10=4) (11=2) (12=3), gen(_country)
	keep C* uniqueid sex age WORK* isco_4 nace_2 hours selfemp3 _year _month _survey _weight* _PSU* _strata _country 
	save "$workingdir\ess02.dta", replace
use "Z:\PhD datasets\Work-related datasets\ESS 2004\copy_of_ess2_gb_sddf.dta", replace			// This is the data file that contains the sampling details
	sort idno
	save "Z:\PhD datasets\Work-related datasets\ESS 2004\sampling.dta", replace
	// Main data file
	use "Z:\PhD datasets\Work-related datasets\ESS 2004\ess2gb.dta", replace
		sort idno
		merge idno using "Z:\PhD datasets\Work-related datasets\ESS 2004\sampling.dta"
	numlabel _all, mask(#_) add
	// Main vars
	ren wrkhrd 		D1_B
		ren nevdnjb	D20_B
	ren wkdcorga	C46
	// Other vars
	tostring idno, gen(uniqueid) format(%8.0f)
		ren gndr	sex
		gen age = inwyr - yrbrn
	gen WORK = 2 if pdwrk<.
			replace WORK = 1 if (pdwrk==1 | crpdwk==1)
		ren iscoco	isco_4
		ren	nacer	nace_2
		// No data on p/t vs. f/t
		ren wkhtot hours
		// No data on SECTOR
		recode emplrel (1=1 "1_Employee") (2=2 "2_Self-emp") (3=3 "3_Family bus") (else=.), gen(selfemp3)
	gen _survey = "ESS04"
		ren inwyr 	_year 
		ren inwmm	_month
	ren dweight 	_weight_2
		ren psu		_PSU			// The 2nd PSU of SAMPPOIN doesn't add anything - it's identical to psu.  As is STRATIFY
		encode stratify if stratify~="NA", gen(_strata)
	recode regiongb (1/9=1) (10=4) (11=2) (12=3), gen(_country)
	keep D* C* uniqueid sex age WORK isco_4 nace_2 hours selfemp3 _year _month _survey _weight* _PSU* _strata _country 
	save "$workingdir\ess04.dta", replace
use "Z:\PhD datasets\Work-related datasets\ESS 2006\ess3gb.dta", replace		// The Sampling Data does not appear to have been included, for some unknown reason...
	numlabel _all, mask(#_) add
	// Main vars
	ren wkdcorga	C46
	// Other vars
	tostring idno, gen(uniqueid) format(%8.0f)
	ren gndr	sex
		capture drop age			// There is a good variable called 'age', but to be consistent with other years I'm doing it this way
		gen age = inwyys - yrbrn
	gen WORK = 2 if pdwrk<.
			replace WORK = 1 if (pdwrk==1 | crpdwk==1)
		ren iscoco	isco_4
		ren	nacer	nace_2
		// No data on p/t vs. f/t
		ren wkhtot hours
		// No data on SECTOR
		recode emplrel (1=1 "1_Employee") (2=2 "2_Self-emp") (3=3 "3_Family bus") (else=.), gen(selfemp3)
	ren inwyys 	_year 
		ren inwmme	_month
	gen _survey = "ESS06"
	ren dweight 	_weight_2
		tostring idno, gen(idnoS) format(%05.0f)
			gen _PSU = substr(idnoS, 1, 3)			// A guess, but it works for ESS2004 and seems highly plausible here
			destring _PSU, replace
			replace _PSU = . if _PSU==0
	recode regiongb (1/9=1) (10=4) (11=2) (12=3), gen(_country)
	keep C* uniqueid sex age WORK isco_4 nace_2 hours selfemp3 _year _month _survey _weight* _PSU* _country 
	save "$workingdir\ess06.dta", replace
use "Z:\PhD datasets\Work-related datasets\ESS 2008\ess4gb.dta", replace		// The Sampling Data does not appear to have been included, for some unknown reason...
	numlabel _all, mask(#_) add
	// Main vars
	ren wkdcorga	C46
	// Other vars
	tostring idno, gen(uniqueid) format(%8.0f)
	ren gndr	sex
		capture drop age			// There is a good variable called 'age', but to be consistent with other years I'm doing it this way
		gen age = inwyys - yrbrn
	gen WORK = 2 if pdwrk<.
			replace WORK = 1 if (pdwrk==1 | crpdwk==1)
		ren iscoco	isco_4
		ren	nacer	nace_2
		// No data on p/t vs. f/t
		ren wkhtot hours
		// No data on SECTOR
		recode emplrel (1=1 "1_Employee") (2=2 "2_Self-emp") (3=3 "3_Family bus") (else=.), gen(selfemp3)
	ren inwyys 	_year 
		ren inwmme	_month
	gen _survey = "ESS08"
	ren dweight 	_weight_2
		tostring idno, gen(idnoS) format(%06.0f)
			gen _PSU = substr(idnoS, 1, 4)			// A guess, but it works for ESS2004 and seems highly plausible here
			destring _PSU, replace
			replace _PSU = . if _PSU==0
	recode regiongb (1/9=1) (10=4) (11=2) (12=3), gen(_country)
	keep C* uniqueid sex age WORK isco_4 nace_2 hours selfemp3 _year _month _survey _weight* _PSU* _country 
	save "$workingdir\ess08.dta", replace
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
// British Social Attitudes
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
use "Z:\PhD datasets\Work-related datasets\BSA 1985 (SN2096)\stata8\bsa85.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren jobtasks		C38
		recode sayjob (1=1) (2=2) (8=3) (else=.), gen(C16_1)
		recode muchsay (1=1) (2=2) (3=3) (else=.), gen(C16_2)
		mvdecode C*, mv(0 8)
	// Other vars
	tostring serial, gen(uniqueid) format(%04.0f)
	ren rsex			sex
		ren rage		age
	recode reconact (3=1) (else=2) if reconact<99, gen(WORK) 
		recode reconact (2=1) (else=2) if reconact<99, gen(govsch) 
		gen co80_5 = rocccode*100 if rocccode>0
		ren rindclas	sic80_2
		ren remploye	selfemp1
			replace selfemp1=. if selfemp1==0
		recode rsector (1=1) (2/5=2) (6=3) (else=.), gen(sector)
		recode ejbhours (0 98/99=.), gen(hours)
		recode ejbhrcat (0=.), gen(hours_D)
	gen _year = 1985
		gen _month = 2
		gen _survey = "BSA1985"
	ren wtfactor 		_weight_2
		/*gen numadults = 1
		forvalues i = 2/10	{
			replace numadults = numadults + 1 if p`i'age>17 & p`i'age<99
							}
		sum numadults, det 
		gen _weight_3 = numadults *(_N / r(sum))		
		*/ren area 		_PSU
	recode region (1=2) (4=4) (2/3 5/6=1), gen(_country)	
	keep C* uniqueid sex age WORK govsch co80* sic80* hours* selfemp1 sector _year _month _survey _weight* _PSU _country 
		mvdecode age, mv(99 -9)
	save "$workingdir\bsa85.dta", replace
use "Z:\PhD datasets\Work-related datasets\BSA 1987 (SN2567)\stata8\bsa87.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	recode sayjob (1=1) (2=2) (8=3) (else=.), gen(C16_1)
		recode muchsay (1=1) (2=2) (3=3) (else=.), gen(C16_2)
	// Other vars
	tostring serial, gen(uniqueid) format(%04.0f)
	ren rsex			sex
		ren rage		age
	recode reconact (3=1) (else=2) if reconact<99, gen(WORK) 
		recode reconact (2=1) (else=2) if reconact<99, gen(govsch) 
		gen co80_5 = rocccode*100 if rocccode>0
		ren rindclas	sic80_2
			replace sic80_2=. if sic80_2==-9
		ren remploye	selfemp1
		recode rsector (1=1) (2/5=2) (6=3) (else=.), gen(sector)
		recode ejbhours (0 98/99=.), gen(hours)
		recode ejbhrcat (8/9=.), gen(hours_D)
	gen _year = 1987
		tostring dateint, gen(dateS) format(%06.0f)
			gen _month = substr(dateS, 3, 2)
			destring _month, replace
		gen _survey = "BSA1987"
	ren wtfactor 		_weight_2
		/*gen numadults = 1
		forvalues i = 2/10	{
			replace numadults = numadults + 1 if p`i'age>17 & p`i'age<99
							}
		sum numadults, det 
		gen _weight_3 = numadults *(_N / r(sum))		
		*/ren area 		_PSU
	recode region (1=2) (4=4) (2/3 5/6=1), gen(_country)	
	keep C* uniqueid sex age WORK govsch co80* sic80* hours* selfemp1 sector _year _month _survey _weight* _PSU _country 
		mvdecode age, mv(99)
	save "$workingdir\bsa87.dta", replace
use "Z:\PhD datasets\Work-related datasets\BSA 1989 (SN2723)\stata8\2723.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	recode sayjob (1=1) (2=2) (8=3) (else=.), gen(C16_1)
		recode muchsay (1=1) (2=2) (3=3) (else=.), gen(C16_2)
		ren wrkiplan 	C21_S
		ren wrkphysc	P4_S
	mvdecode C21 P4, mv(9)
	// Other vars
	tostring serial, gen(uniqueid) format(%06.0f)
	ren rsex			sex
		ren rage		age
	recode reconact (3=1) (else=2) if reconact<99, gen(WORK) 
			recode hrsworkd (1/2=1 "1_Works s/c") (3=2 "2_No work s/c") (else=.), gen(WORK_CS)
		recode reconact (2=1) (else=2) if reconact<99, gen(govsch) 
		gen co80_5 = rocccode*100 if rocccode>0
		ren rindclas	sic80_2
			replace sic80_2=. if sic80_2==-9
		ren remploye	selfemp1
		recode rsector (1=1) (2/5=2) (6=3) (else=.), gen(sector)
		recode ejbhours (0 98/99=.), gen(hours)
		recode ejbhrcat (8/9=.), gen(hours_D)
		ren hrsworkd	hours_E
	gen _year = 1989
		gen _month = dateintm if dateintm<99
		gen _survey = "BSA1989"
		recode selfcomp (51=1) (61=2), gen(_sc_complete)
		ren version		_sc_ver
	ren wtfactor 		_weight_2
		/*gen numadults = 1
		forvalues i = 2/10	{
			replace numadults = numadults + 1 if p`i'age>17 & p`i'age<99
							}
		sum numadults, det 
		gen _weight_3 = numadults *(_N / r(sum))		
		*/ren area 		_PSU
	recode region (1=2) (4=4) (2/3 5/6=1), gen(_country)	
	keep C* P* uniqueid sex age WORK* govsch co80* sic80* hours* selfemp1 sector _year _month _survey _weight* _PSU _country _sc*
		mvdecode age, mv(99)
	save "$workingdir\bsa89.dta", replace
use "Z:\PhD datasets\Work-related datasets\BSA 1991 (SN2952)\stata8\f952.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	recode sayjob (1=1) (2=2) (8=3) (else=.), gen(C16_1)
		recode muchsay (1=1) (2=2) (3=3) (else=.), gen(C16_2)
		recode pwwkplan (-2 9 = .), gen(C21_S)
	// Other vars
	tostring serial, gen(uniqueid) format(%05.0f)
	ren rsex			sex
		ren rage		age
	recode reconact (3=1) (else=2) if reconact<99, gen(WORK) 
			recode paidjob (1=1 "1_Paid job s/c") (2=2 "2_No job s/c") (else=.), gen(WORK_DS)
		recode reconact (2=1) (else=2) if reconact<99, gen(govsch) 
		ren rsoc	soc90_3
			replace soc90_3 = . if soc90_3==0
		ren rindclas	sic80_2
			replace sic80_2=. if sic80_2==-9
		ren remploye	selfemp1
		recode rsector (1=1) (2/5=2) (6=3) (else=.), gen(sector)
		recode esrjbtim (1=1) (2=2) (else=.), gen(fulltime)
		recode ejbhours (99=.), gen(hours)
		recode ejbhrcat (8/9=.), gen(hours_D)
	gen _year = 1991
		gen _month = dateintm if dateintm<99
		gen _survey = "BSA1991"
	ren wtfactor 		_weight_2
		gen _samp_frame = 1 if nelector<.	
			replace _samp_frame=2 if nelector==. 
			label define samp 1 "1_Electoral Register" 2 "2_PAF"
			label values _samp_frame samp
		recode selfcomp (51=1) (61=2), gen(_sc_complete)
		/*gen numadults = 1
		forvalues i = 2/12	{
			replace numadults = numadults + 1 if p`i'age>17 & p`i'age<99
							}
		sum numadults, det 
		gen _weight_3 = numadults *(_N / r(sum))		
		gen _weight_4 = ndwellng * neligibl
			quietly sum _weight_4, det
			replace _weight_4 = _weight_4 * r(N) / r(sum)		
		*/ren area 		_PSU
	recode region (1=2) (4=4) (2/3 5/6=1), gen(_country)	
		keep C* uniqueid sex age WORK* govsch soc90* sic80* hours* selfemp1 sector _year _month _survey _weight* _PSU _country _sc* _samp_frame
		mvdecode age, mv(99 -1)
	save "$workingdir\bsa91.dta", replace
use "Z:\PhD datasets\Work-related datasets\BSA 1993 (SN3439)\stata8\bsa93.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	recode sayjob (1=1) (2=2) (8=3) (else=.), gen(C16_1)
		recode muchsay (1=1) (2=2) (3=3) (else=.), gen(C16_2)
	// Other vars
	tostring serial, gen(uniqueid) format(%05.0f)
	ren rsex			sex
		ren rage		age
	recode reconact (3=1) (else=2) if reconact<99, gen(WORK) 
		recode reconact (2=1) (else=2) if reconact<99, gen(govsch) 
		ren rsoc	soc90_3
			replace soc90_3 = . if soc90_3>=997
		ren rsic sic80_2
			replace sic80_2=. if sic80_2==-9
		recode remploye	(8 9=.), gen(selfemp1)
		capture drop sector
			recode rsector (1=1) (2/5=2) (6=3) (else=.), gen(sector)
		recode esrjbtim (1=1) (2=2) (else=.), gen(fulltime)
		recode ejbhours (98 99=.), gen(hours)
		recode ejbhrcat (8/9=.), gen(hours_D)
	gen _year = 1993
		gen _month = dateintm if dateintm<9 & dateintm>0
		gen _survey = "BSA1993"
		recode choice (9=.), gen(_capi_v_papi)
	ren wtfactor 		_weight_2
		/*gen numadults = 1
		forvalues i = 2/9	{
			replace numadults = numadults + 1 if p`i'age>17 & p`i'age<99
							}
		sum numadults, det 
		gen _weight_3 = numadults *(_N / r(sum))		
		gen _weight_4 = dwelling * persno if dwelling<98 & persno<98
			quietly sum _weight_4, det
			replace _weight_4 = _weight_4 * r(N) / r(sum)		
		*/ren spoint		_PSU
	recode region (1=2) (4=4) (2/3 5/6=1), gen(_country)	
		keep C* uniqueid sex age WORK* govsch soc90_3 sic80* hours* fulltime selfemp1 sector _year _month _survey _weight* _PSU _country _capi_v_papi
		mvdecode age, mv(98 99)
	save "$workingdir\bsa93.dta", replace
use "Z:\PhD datasets\Work-related datasets\BSA 1995 (SN3764)\stata8\bsa95.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	recode pwwkplan (1=1 "1_Most work") (2=2 "2_Parts of work") (3=3 "3_Job not allow plan") (else=.), gen(C21_S)
	// Other vars
	tostring serial, gen(uniqueid) format(%05.0f)
	ren rsex			sex
		ren rage		age
	recode reconact (3=1) (else=2) if reconact<99, gen(WORK) 
			recode paidjob (1=1 "1_Working") (2=2 "2_Not working") (else=.), gen(WORK_DS) 
		recode reconact (2=1) (else=2) if reconact<99, gen(govsch) 
		ren rsoc	soc90_3
			replace soc90_3 = . if soc90_3>=997
		ren rindclas sic80_2
			replace sic80_2=. if sic80_2<0
			ren rsic92	sic92_2
			replace sic92_2=. if sic92_2<0
		recode remploye	(8 9=.), gen(selfemp1)
		// Sector is not included for some reason
		recode esrjbtim (1=1) (2=2) (else=.), gen(fulltime)
		recode ejbhours (98 99=.), gen(hours)
		recode ejbhrcat (8/9=.), gen(hours_D)
	gen _year = 1995
		tostring dateint, gen(dateintS) format(%08.0f)
			gen _month = substr(dateintS, 3, 2)
			replace _month="" if _month=="99"
			destring _month, replace
	gen _survey = "BSA1995"
	ren wtfactor 		_weight_2
		recode selfcomp (51=1) (61=2), gen(_sc_complete)
		ren version		_sc_ver
		/*gen numadults = 1
		forvalues i = 2/12	{
			replace numadults = numadults + 1 if p`i'age>17 & p`i'age<99
							}
		sum numadults, det 
		gen _weight_3 = numadults *(_N / r(sum))		
		gen _weight_4 = (duno * numadult)/moi
			quietly sum _weight_4, det
			replace _weight_4 = _weight_4 * r(N) / r(sum)		
		*/ren spoint		_PSU
	recode region (1=2) (4=4) (2/3 5/6=1), gen(_country)	
		keep C* uniqueid sex age WORK* govsch soc90_3 sic80_2 sic92_2 hours* fulltime selfemp1 _year _month _survey _weight* _PSU _country _sc*
		mvdecode age, mv(98 99)
	save "$workingdir\bsa95.dta", replace
use "Z:\PhD datasets\Work-related datasets\BSA 1996 (SN3921)\stata8\g921au.dta", replace		// There's also g921bu.dta
	numlabel _all, mask(#_) add
	// Main vars
	recode sayjob (1=1) (2=2) (8=3) (else=.), gen(C16_1)
		recode muchsay (1=1) (2=2) (3=3) (else=.), gen(C16_2)
	// Other vars
	tostring serial, gen(uniqueid) format(%05.0f)
	ren rsex			sex
		ren rage		age
	recode reconact (3=1) (else=2) if reconact<99, gen(WORK) 
		recode reconact (2=1) (else=2) if reconact<99, gen(govsch) 
		ren rsoc	soc90_3
			replace soc90_3 = . if soc90_3>=997
		ren rsic92	sic92_2
			replace sic92_2=. if sic92_2<0
		recode remploye	(8 9=.), gen(selfemp1)
		capture drop sector
			recode rocsect (1=1) (2/5=2) (6=3) (else=.), gen(sector)
		recode wkjbtim (1=1) (2=2) (else=.), gen(fulltime)
		recode wkjbhrsi (96 98 99=.), gen(hours)
	gen _year = 1996
		recode dateintm (99=.), gen(_month)
		gen _survey = "BSA1996"
	ren wtfactor 		_weight_2
		recode selfcomp (51=1) (61=2), gen(_sc_complete)
		ren version		_sc_ver
		/*gen numadults = 1
		forvalues i = 2/12	{
			replace numadults = numadults + 1 if p`i'age>17 & p`i'age<99
							}
		sum numadults, det 
		gen _weight_3 = numadults *(_N / r(sum))		
		gen _weight_4 = (duno * numad17)/moi
			quietly sum _weight_4, det
			replace _weight_4 = _weight_4 * r(N) / r(sum)		
		*/ren spoint		_PSU
		ren stridx		_strata
	recode region (1=2) (4=4) (2/3 5/6=1), gen(_country)	
		keep C* uniqueid sex age WORK* govsch soc90_3 sic92_2 hours* fulltime selfemp1 sector _year _month _survey _weight* _PSU _strata _country _sc*
		mvdecode age, mv(98 99)
	save "$workingdir\bsa96.dta", replace
use "Z:\PhD datasets\Work-related datasets\BSA 1997 (SN4072)\stata6\bsa97a.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren wrkphysc		P4_S
	mvdecode P4, mv(-2 -1 8 9)
	// Other vars
	tostring serial, gen(uniqueid) format(%05.0f)
	ren rsex			sex
		ren rage		age
	recode reconact (3=1) (else=2) if reconact<99, gen(WORK) 
			recode worknow (1=1) (2=2) (else=.), gen(WORK_DS)
		recode reconact (2=1) (else=2) if reconact<99, gen(govsch) 
		ren rsoc	soc90_3
			replace soc90_3 = . if soc90_3>=997
		ren rsic92	sic92_2
			replace sic92_2=. if sic92_2<0
		recode remploye	(-1=.), gen(selfemp1)
		capture drop sector
			recode rocsect (1=1) (2/3=2) (4=3) (else=.), gen(sector)
		recode wkjbtim (1=1) (2=2) (else=.), gen(fulltime)
		recode wkjbhrsi (-1 96 98 =.), gen(hours)
	gen _year = 1997
		tostring iintdate, gen(dateintS) format(%08.0f)
			gen _month = substr(dateintS, 3, 2)
			destring _month, replace
		gen _survey = "BSA1997"
	ren wtfactor 		_weight_2
		recode selfcomp (51=1) (61=2), gen(_sc_complete)
		/*gen numadults = 1
		forvalues i = 2/9	{
			replace numadults = numadults + 1 if p`i'age>17 & p`i'age<99
							}
		sum numadults, det 
		gen _weight_3 = numadults *(_N / r(sum))		
		gen _weight_4 = (duno * persno)/moi
			quietly sum _weight_4, det
			replace _weight_4 = _weight_4 * r(N) / r(sum)		
		*/ren spoint		_PSU
	recode region (1=2) (4=4) (2/3 5/6=1), gen(_country)	
		keep P* uniqueid sex age WORK* govsch soc90_3 sic92_2 hours* fulltime selfemp1 sector _year _month _survey _weight* _PSU _country _sc*
	save "$workingdir\bsa97.dta", replace
use "Z:\PhD datasets\Work-related datasets\BSA 2005 (SN5618)\stata8\bsa05.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	recode sayjob (1=1) (2=2) (8=3) (else=.), gen(C16_1)
		recode muchsay (1=1) (2=2) (3=3) (else=.), gen(C16_2)
	recode wrkphysc	(min/0 9=.), gen(P4_S)
	// Other vars
	tostring serial, gen(uniqueid) format(%05.0f)
	ren rsex			sex
		ren rage		age
	recode reconact (3=1) (1 2 4/11=2) (else=.), gen(WORK) 
			recode worknow (1=1) (2=2) (else=.), gen(WORK_DS)
		recode reconact (2=1) (1 3/11=2) (else=.), gen(govsch)
		ren rsoc2000	soc00_4
			replace soc00_4 = . if soc00_4==-1
		ren rsoc		soc90_3
			replace soc90_3 = . if soc90_3>=997
		ren rsic2003	sic03_2
			replace sic03_2=. if sic03_2<0
		recode remploye	(-1 8 9=.), gen(selfemp1)
		capture drop sector
			recode rocsect2 (1=1) (2/3=2) (4=3) (else=.), gen(sector)
		recode wkjbtim (1=1) (2=2) (else=.), gen(fulltime)
		recode wkjbhrsi (-1 96 98 99 =.), gen(hours)
	gen _survey = "BSA2005"
		gen _year = 2005
		gen _month = substr(intdate, 3, 2)
		tostring qdate, gen(qdateS) format(%04.0f)
			gen _month_S = substr(qdateS, 3, 2)
			replace _month_S ="" if _month_S=="99"
			destring _month _month_S, replace
		gen _year_S = 2005
			replace _year_S = 2006 if _month_S==1
		recode selfcomp (51=2 "2_s/c not completed") (61=1 "1_s/c completed"), gen(_sc_complete)
		ren abcdver		_sc_ver
	ren wtfactor 		_weight
		ren oldwt		_weight_2
		gen numadults = 1
		/*forvalues i = 2/8	{
			replace numadults = numadults + 1 if p`i'age>17 & p`i'age<99
							}
		sum numadults, det 
		gen _weight_3 = numadults *(_N / r(sum))		
		gen _weight_4 = (duno * persno)/moi
			quietly sum _weight_4, det
			replace _weight_4 = _weight_4 * r(N) / r(sum)		
		*/ren spoint		_PSU
		ren strata		_strata
	recode region (1=2) (4=4) (2/3 5/6=1), gen(_country)	
		keep C* P* uniqueid sex age WORK* govsch soc90_3 soc00_4 sic03_2 hours* fulltime selfemp1 sector _year _month _survey _weight* _PSU _strata _country _sc*
		mvdecode age, mv(98 99)
	save "$workingdir\bsa05.dta", replace
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
// World Values Surveys
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
use "Z:\PhD datasets\Work-related datasets\European Values Survey 1981\ZA4438_F1.dta", replace
	numlabel _all, mask(#_) add
	keep if country==8102 | country==8116
	drop if age<25
	// Main vars
	ren v235			C13
	// Other vars
	tostring respno, gen(uniqueid) format(%04.0f)
	ren v567			sex
	// Age is already named 'age'
	recode v560 (1/3=1) (4/7=2) (else=.), gen(WORK) 
		// No SOC/ISCO
		// No SIC/NACE
		recode v560 (1/2=1) (3=2) (else=.), gen(selfemp1)
		// No sector
		recode v560 (1=1) (2=2) (else=.), gen(fulltime)
		// No hours
	ren year 		 	_year 
		gen _survey = "WVS81"
	ren weight			_weight
	recode country (8102=6) (8116=3), gen(_country)	
		keep C* uniqueid sex age WORK fulltime selfemp1 _year _survey _weight* _country 
	save "$workingdir\wvs81.dta", replace
use "Z:\PhD datasets\Work-related datasets\European Values Survey 1990\ZA4460_F1.dta", replace
	numlabel _all, mask(#_) add
	keep if country==02 | country==16
	drop if q719b<25			// To maintain comparability with EVS81 (see ssheet note)
	// Main vars
	ren q268			C13
	// Other vars
	tostring id_cocas, gen(uniqueid) format(%09.0f)
	ren q716			sex
		ren q719b		age
	recode q724 (1/3=1) (4/8=2) (else=.), gen(WORK) 
		// No SOC/ISCO
		// No SIC/NACE
		recode q724 (1/2=1) (3=2) (else=.), gen(selfemp1)
		// No sector
		recode q724 (1=1) (2=2) (else=.), gen(fulltime)
		// No hours
	ren year 		 	_year 
		gen _survey = "WVS90"
	ren weight			_weight
	recode q743 (2001/2009 2100/2102=1) (2010=4) (2011=2) (else=.), gen(_country)	
		replace _country=3 if country==16
		keep C* uniqueid sex age WORK fulltime selfemp1 _year _survey _weight* _country 
	save "$workingdir\wvs90.dta", replace
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
// Misc datasets
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
use "Z:\PhD datasets\Work-related datasets\Fair Treatement at Work Survey 2008 (SN6382)\stata8\ftws_2008_dataset_for_archive.dta", replace
	numlabel _all, mask(#_) add
	keep if emptype==1			// Current workers only, not former-employees
	// Main vars
	ren b14 		D8_S
		ren b16		D11_S
		ren b9		D24_BS
	ren b17			C6_S
		ren b28		C24_S
		ren b10		C30_S
		ren b18		C36_S
	ren b31			E4_S
	mvdecode C* D* E*, mv(-99.99 6 7)
	// Other vars
	tostring respid, gen(uniqueid) format(%06.0f)
		ren q8_2	 	sex
		ren q8_1an	 	age
	recode qa (1/4 14=1) (else=2) if qa<17, gen(WORK)
		recode qa (11=1) (else=2) if qa<17, gen(govsch)
		recode qa (14=1) (else=2) if qa<17, gen(tempsick)
		// No SOC
		ren sic			sic07_2
		recode orgtyp (1=1) (2=2) (3=3) (4=.), gen(sector)
		ren workstat	fulltime
		recode qa (1/2=1) (3/4=2) (else=.), gen(selfemp1)
	gen _survey = "fairtreat08"	
		tostring intdate, gen(date) format(%8.0f)
		gen _year = substr(date, 1, 4)
		gen _month = substr(date, 5, 2)
		destring _year _month, replace
	ren wts			_weight
	recode gor (1/9=1) (10=4) (11=2), gen(_country)
	keep C* D* uniqueid sex age WORK govsch tempsick sic07* sector fulltime selfemp1 _year _month _survey _weight* _country
	mvdecode _all, mv(-99.99)
	save "$workingdir\fairtreat08.dta", replace
use "Z:\PhD datasets\Work-related datasets\1984 Social Class in Modern Britain (SN2718)\stata6\f718.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	recode auton56b	(1=5 "respondent decides") (5=1 "someone else decides"), gen(C8)
		ren auton56e	C10
		ren auton55a	C18
		ren auton56a	C38
		ren auton56g	C39
	recode C* (1=1) (5=2) (else=.)
	// DV to indicate filtering
	recode ecact36a (1/3 5=1) (4 6/10=2) (else=.), gen(WORK)
		recode ecact36a (5=1) (else=2) if ecact36a>0, gen(tempsick_B)
		recode ecact38a (1=1) (5=2) (else=.), gen(govsch)
		gen director = (diorg42h>=1 & diorg42h<=3) 
			label var director "Director or equiv - exc. from my questions"
	// Other vars
	tostring case, gen(uniqueid) format(%04.0f)
	ren sex122a		sex
		ren ager124	age
	ren occup39a	co80_5
		ren sic40c		sic80_2
		recode ecact36a (1=1) (2/3=2) (else=.), gen(fulltime)
		ren hours43a	hours
		recode tyemp39e (1/2=1) (3=2) (else=.), gen(selfemp1)
		recode tyorg41 (7=1) (1/5=2) (6=3) (else=.), gen(sector)
	gen _weight_2 = 1
		/* Syntax for generating approximations of design weights from household size (number of adults) - this was discarded as it uses frame from Electoral Register, which makes this invalid
		#delimit ;
		ren age0124 age10124; ren awkward2 age11124; ren awkward4 age12124; ren awkward6 age13124; ren awkward8 age14124;
		#delimit cr
		capture drop age2-age14 numwrkage
		gen numwrkage = 1
		forvalues i = 2/14	{
				gen age`i' = (age`i'124<=62 & age`i'124>=16)
				replace numwrkage = numwrkage + age`i'
							}
		sum numwrkage, det
		gen _weight_2 = numwrkage *(_N / r(sum))	*/
	gen _survey = "scmb84"	
		gen _year = 1984
	keep C* uniqueid sex age WORK tempsick_B govsch director sic80_2 co80* sector fulltime hours selfemp1 _year _survey _weight* 
	mvdecode _all, mv(-3 -1)
	save "$workingdir\scmb84.dta", replace
use "Z:\PhD datasets\Work-related datasets\Psychiatric Morbidity Survey 2007 (SN6379)\stata8\apms07arch.dta", replace
	numlabel _all, mask(#_) add
	// Main vars
	ren eri1				D14
	recode jcq1 (1=4) (2=3) (3=2) (4=1), gen(C29_B)
		ren jcq2			C37
	// Other vars
	tostring pserial, gen(uniqueid) format(%08.0f)
	ren ressex 	sex
		ren resage 	age
	recode work (min/0=.), gen(WORK)
		recode schemeet (-1=.) if work> -9, gen(govsch)
		ren soc2000b		soc00_2
		ren sic2003b		sic03_1
		ren stat			selfemp1
		ren ftptwk			fulltime
		ren ptwkhour		hours
		// No vars for sector
	gen _survey = "psymorb07"	
		gen _year = 2007
	ren wt_ints1		_weight
		sum numadult, det			// This matches the info in the hhld grid - nothing else that can be done with this
			gen _weight_2 = numadult *(_N / r(sum))
		ren area			_PSU
		ren cluster			_strata
	gen _country=1  // no need to look at gor06 as this is restricted to England
	keep C* D* uniqueid sex age WORK sic03_1 soc00_2 fulltime hours selfemp1 _year _survey _weight* _PSU _strata _country 
	mvdecode _all, mv(-9 -8 -1)
	save "$workingdir\psymorb07.dta", replace
	
	
	
	
	
	
	
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
// Merging
/////////////////////////////////////////////////
/////////////////////////////////////////////////
/////////////////////////////////////////////////
use "$workingdir\ss06.dta", replace			// The best-labelled file, hence makes sense to merge others into this
local order = 57							// This creates a variable called 'order' that contains the survey code, ordered by the list below - this proved more useful than using ENCODE, as I could choose the order
	gen order = `order'
	label var order "Survey, ordered by BB 10-6-10"
	label define order 57 "57_ss06"
	label values order order
global files ""
	global files "ss01 ss97 wib eib sceli scmb84 wers04 wers98 hse08 hse04 hse03 hse99 hse98 hse97 hse94 hse93 shs95 shs98 shs03 fairtreat08 psymorb07 pwcs08-4 pwcs07-4 pwcs07-3 pwcs06-4 pwcs06-3 pwcs05-4 "
	global files "$files pwcs05-3 pwcs04-4 pwcs04-3 omni96-7 omni96-5  omni96-4 omni92-5 omni92-4 ewcs91 ewcs95 ewcs00 ewcs05 eb44-3 eb56-1 ess08 ess06 ess04 ess02 bsa05 bsa97 bsa96 bsa95 bsa93 "
	global files "$files bsa91 bsa89 bsa87 bsa85 wvs90 wvs81 "
foreach file in $files	{
	dis "`file'"
	append using "$workingdir\\`file'.dta"
	local order = `order' - 1
		replace order = `order' if order==.
		label define order `order' "`order'_`file'", modify
						}
drop _survey

// Misc tidying up 
drop if (age<18 | age>=65) & (age<.)
	drop _weight_3											// This is an attempt to create a comparable EWCS weight, but I didn't think it was robust enough to use
	drop director											// SCMB84 has slighlty different screening from other surveys, but decided this was rare enough to ignore
	drop tempsick*											// Again as a check for screening, but decided this was rare enough to ignore
recode C8 (2=0)
	recode agegrp2 (1/2=1 "1.<20") (3/4=2 "2.20-29") (5=4 "4.30-39") (6=5 "5.40-49") (7=6 "6.50-59") (8/9=7 "7.60+"), gen(agegrp)
	replace agegrp=agegrp1 if order==49
label define hours_D 1 "1_10-15hrs" 2 "2_16-23hrs" 3 "3_24-29hrs" 4 "4_30+hrs"
	label values hours_D hours_D
	label define _country 5 "5_UK" 6 "6_GB" 7 "7_England&Wales", modify
gen hoursTRIM = hours
	quietly sum hoursTRIM, det
	replace hoursTRIM=r(p1)  if hoursTRIM<r(p1)  & hoursTRIM<.
	replace hoursTRIM=r(p99) if hoursTRIM>r(p99) & hoursTRIM<.
	label var hoursTRIM "the var hours, trimmed at 1% and 99% percentiles"
recode hours (0/15.99=1) (16/30.99=2) (31/40.99=3) (41/199=4), gen(hoursGRP)	// Hours grouped to enable comparability of SS01/SS06 with EiB
	label values hoursGRP hours0
	replace hoursGRP=hours_F if order==53
	recode hoursGRP (1/2=2 "2_0-30hrs") (3/4=1 "1_31+hrs"), gen(fulltimeHRS)
	label var fulltimeHRS "Full-time vs. part-time, based on reported usual hrs of work inc overtime"
* Creating the combined control variables for the question that Green treats as comparable from EiB
clonevar C1_combined = C1
	replace C1_combined = C1_B if order==53
clonevar C25_combined = C25
	replace C25_combined = C25_B if order==53
clonevar C33_combined = C33
	replace C33_combined = C33_B if order==53
clonevar C49_combined = C49
	replace C49_combined = C49_B if order==53
* Replacing the inconsistent question for sector (the following questions DO NOT have a category for 'nonprofits')
clonevar sector_B = sector if order==16 | order==17 | order==20 | order==21 | order==49 | order==50 | order==52 | order==53
	replace sector = . if sector_B<.
	order sector_B, after(sector)


// Weights
replace _weight_eib = _weight if _weight_eib==.				// For comparing to the EIB's non-response weight (two NR weights are available - one only gender-adjusted (like skills surveys), one adjusted for other things too (like WiB).  This is the age-adjusted weight 
* Comparable gender-balanced weight for WiB - see OneNote
global extraif "age>=20 & age<=60 & WORK==1 & _country~=3"
* Weighted data - my target sex distn
svyset [pweight=_weight]
	svy: proportion sex if order==56 & $extraif
	matrix working_mnsex = e(b)
	scalar ss01_m = working_mnsex[1,1]
	scalar ss01_f = working_mnsex[1,2]
* Design weights only - the existing sex distn
svyset [pweight=_weight_2]
	*svy: proportion sex if order==56
	svy: proportion sex if order==54 & $extraif
	matrix working_wibsex = e(b)
	scalar wib_m = working_wibsex[1,1]
	scalar wib_f = working_wibsex[1,2]
* Rescaling the design weights to match the target sex distn
replace _weight_eib = _weight_2 * (ss01_m/wib_m) if sex==1 & order==54
replace _weight_eib = _weight_2 * (ss01_f/wib_f) if sex==2 & order==54
* Checking results
*svyset [pweight=testwt]
*	svy: proportion sex if order==56 & $extraif
*	svy: proportion sex if order==54 & $extraif 
		
	
	
// Occupation data
replace soc90_3 = . if soc90_3<100 | soc90_3>=997			// None of these codes provide any information (only EiB has codes <100; only SS97 has codes 997/998; 999 is always a misc code)
replace soc00_4 = . if soc00_4==9999						// Don't want to class this as soc00_1==9 (which would mean elementary occs!)
	// soc00_1
	gen soc00_1R = floor(soc00_4/1000)
	replace soc00_1R = floor(soc00_3/100) if soc00_1R==.
	replace soc00_1R = floor(soc00_2/10 ) if soc00_1R==.
	// soc00_2
	clonevar soc00_2R = soc00_2
	replace soc00_2R = floor(soc00_4/100) if soc00_2R==.
	replace soc00_2R = floor(soc00_3/10 ) if soc00_2R==.
	// soc00_3
	clonevar soc00_3R = soc00_3
	replace soc00_3R = floor(soc00_4/10) if soc00_3R==.
recode co80_5 (0=.) (1/999=1) (1000/1999=2) (2000/2999=3) (3000/3999=4) (4000/4999=5) (5000/5999=6) (6000/6999=7) (7000/7999=8) (8000/8999=9) (9000/9999=10) (10000/10999=11) ///
	(11000/11999=12) (12000/12999=13) (13000/13999=14) (14000/14999=15) (15000/15999=16) (16000/16999=17) (else=.), gen(co80_1R)
include "$dir\soc_label.doi"							// This creates labels for all of the occupational variables, and corrects the existing labels - but doesn't change underlying data
capture tab soc00_1R, gen(soc00_1R_)					

	
// Industry data
replace sic92_1=. if sic92_1<0
include "$dir\sic_wib.doi"
	// sic92_1
	recode sic92_4 sic92_2 (1/2.99=1) (5/5.99=2) (10/14.99=3) (15/37.99=4) (40/41.99=5) (45/45.99=6) (50/52.99=7) (55/55.99=8) (60/64.99=9) (65/67.99=10) (70/74.99=11) (75/75.99=12) (80/80.99=13)	///
		(85/89.99=14) (90/93.99=15) (99=16) (95=17) (else=.), gen(sic92_4to1 sic92_2to1)		// note that I felt that code 89 was probably meant to be an unspecific health and social work code
	clonevar sic92_1R = sic92_1
		replace sic92_1R = sic92_4to1 if sic92_1R==.
		replace sic92_1R = sic92_2to1 if sic92_1R==.
		label var sic92_1R "Industry - SIC1992, 1-digit recoded from all SIC1992 vars"
	label values sic92_1R sicmaj
	label define sicmaj 17 "private households with employed persons", modify
	numlabel sicmaj, add mask(#_)
	replace sic92_1R=. if sic92_1R>=16											// These categories are very small, so I'm setting them to missing
	replace sic92_1R=1 if sic92_1R==2
		label define sicmaj 1 "1_fishing MANUALLY COMBINED with agriculture, hunting and forestry", modify
	drop sic92_?to1
	order sic92_1R, after(sic92_1)

	

// Ordering	
aorder
order uniqueid order


// Labelling the variables
label var C1 "C1_How much influence do you personally have on how hard you work?"
label var C1_B "C1_B_How much influence do you personally have on how hard you work?"
label var C2 "C2_...important in determining how hard you work...? Your own discretion"
label var C2_B "C2_B_...important in determining how hard you work...? Your own discretion"
label var C2_C "C2_C_...important in determining how hard you work...? Your own discretion"
label var C5_S "C5_S_...how much influence do you have about...the pace at which you work?"
label var C6 "C6_I have a say in my own work speed"
label var C6_S "C6_S_I have a say in my own work speed"
label var C7 "C7_Are you able, or not, to choose or change Your speed or rate of work?"
label var C8 "C8_Does someone else decide how much work you do or how fast you work...?"
label var C8_S "C8_S_Does someone else decide how much work you do or how fast you work...?"
label var C10 "C10_Can you considerbly slow down your pace of work for a day when you want to?"
label var C10_B "C10_B_Can you cnsdrbly slow down yr pace of work for a day when you want to?"
label var C12 "C12_I have a lot of say over what happens in my job"
label var C12_B "C12_B_I have a lot of say over what happens in my job"
label var C13 "C13_How free are you to make decisions in your job?"
label var C14_S "C14_S_Do you have a good deal of say in decisions about work?"
label var C15 "C15_My job allows me to take part in making decisions that affect my work"
label var C15_B "C15_B_My job allows me to take part in making decisions that affect my work"
label var C16_1 "C16_1_[Would] you personally have any say in the decision about the change...?"
label var C16_2 "C16_2_How much say...do you think that you personally would have?"
label var C16_2_B "C16_2_B_How much say...do you think that you personally would have?"
label var C18 "C18_...a job which allows you to design and plan important aspects...?"
label var C21_S "C21_S_My job allows me to design or plan most of my daily work"
label var C23 "C23_How much choice do you have over the way in which you do your job?"
label var C24 "C24_I have some say over the way I work"
label var C24_S "C24_S_I have some say over the way I work"
label var C25 "C25_How much influence do you...have on deciding how you are to do the task?"
label var C25_B "C25_B_How much influence do you...have on deciding how you are to do the task?"
label var C26_S "C26_S_In general, how much influence do you have about...how you do your work"
label var C29_B "C29_B_Do you have a choice in deciding HOW you do your work?"
label var C29_S "C29_S_Do you have a choice in deciding HOW you do your work?"
label var C30 "C30_I have a choice in deciding how I do my work"
label var C30_S "C30_S_I have a choice in deciding how I do my work"
label var C33 "C33_How much influence do you...have on deciding what tasks you are to do?"
label var C33_B "C33_B_How much influence do you...have on deciding what tasks you are to do?"
label var C36 "C36_I have a choice in deciding what I do at work"
label var C36_S "C36_S_I have a choice in deciding what I do at work"
label var C37 "C37_Do you have a choice in deciding WHAT you do at work?"
label var C38 "C38_Do you decide the specific tasks that you carry out from day to day...?"
label var C38_S "C38_S_Do you decide the specific tasks that you carry out from day to day...?"
label var C39 "C39_Can you decide...to introduce a new task...that you will do...?"
label var C39_S "C39_S_Can you decide...to introduce a new task...that you will do...?"
label var C42 "C42_Are you able, or not, to choose or change your order of tasks "
label var C46 "C46_...does management allow you to decide how your daily work is organised?"
label var C49 "C49_How much influence do you...have on deciding the quality standards...?"
label var C49_B "C49_B_How much influence do you...have on deciding the quality standards...?"
label var D1 "D1_My job requires that I work very hard"
label var D1_B "D1_B_My job requires that I work very hard"
label var D1_BS "D1_BS_My job requires that I work very hard"
label var D4 "D4_How often does your work involve working at very high speed?"
label var D4_B "D4_B_How often does your work involve working at very high speed?"
label var D6_S "D6_S_Do you have to work very fast?"
label var D8 "D8_I have to work very fast at work"
label var D8_S "D8_S_I have to work very fast at work"
label var D10_S "D10_S_Do you have to work very intensively?"
label var D11 "D11_I have to work very intensively at work"
label var D11_S "D11_S_I have to work very intensively at work"
label var D12 "D12_I work under a great deal of tension"
label var D14 "D14_I have constant time pressure due to a heavy workload"
label var D15 "D15_How often does your work involve working to tight deadlines?"
label var D15_B "D15_B_How often does your work involve working to tight deadlines?"
label var D19_S "D19_S_Do you have enough time to do everything?"
label var D20 "D20_I never seem to have enough time to get everything done on my job"
label var D20_B "D20_B_I never seem to have enough time to get everything done on my job"
label var D20_BS "D20_BS_I never seem to have enough time to get everything done on my job"
label var D21 "D21_You have enough time to get the job done"
label var D21_B "D21_B_You have enough time to get the job done"
label var D24 "D24_I have unrealistic time pressures at work"
label var D24_BS "D24_BS_I have unrealistic time pressures at work"
label var D36 "D36_How much effort do you put into your job beyond what is required?"
label var E1 "E1_In your job, how important is managing your own feelings?"
label var E2 "E2_In your job, how important is handling the feelings of other people?"
label var E3 "E3_You find your job emotionally demanding"
label var E4 "E4_I am supported through emotionally demanding work"
label var E5 "E5_In your job, how important is dealing with people?"
label var E6 "E6_...job involve dealing directly with people who are not employees..."
label var E8 "E8_...how important is good contacts with clients or customers"
label var E8_BS "E8_BS_...how important is good contacts with clients or customers"
label var E15 "E15_In your job, how important is instructing, training or teaching people...?"
label var E16 "E16_In your job, how important is making speeches or presentations?"
label var E17 "E17_In your job, how important is persuading or influencing others?"
label var E18 "E18_In your job, how important is selling a product or service?"
label var E22 "E22_In your job, how important is counselling, advising or caring...?"
label var P1 "P1_...in terms of physical effort your work is very demanding...?"
label var P4_S "P4_S_How often do you have to do hard physical work?"
label var P5 "P5_...would you say that you are (very---not at all) physically active?"
label var P6 "P6_In your job, how important is physical strength...?"
label var P8 "P8_In your job, how important is physical stamina...?"
label var P12 "P12_Do you usually have to lift or carry things at work which you find heavy?"
label var WORK "Work status based on past week"
label var WORK_B "Work status based on past 4wks/mth"
label var WORK_C "Work status based on current situation"
label var WORK_CS "Work status based on current situation"
label var WORK_DS "Work status - BSA wording"
label var _PSU "Primary Sampling Unit"
label var _PSU2 "Secondary Sampling Unit"
label var _capi_v_papi "CAPI vs PAPI mode (BSA)"
label var _country "Country within UK"
label var _month "Month of interview, 2-digit"
label var _region "Region within UK"
label var _samp_frame "Sampling frame (BSA) - electoral register vs PAF"
label var _sc_HSE "Details of self-completion (HSE) - whether interviewer administered"
label var _sc_complete "Details of self-completion (BSA) - whether completed"
label var _sc_ver "Details of self-completion (BSA) - s/c questionnaire version"
label var _strata "Strata used in sampling"
label var _reg_ttwa81 "Region - TTWA from 1981 Census (SS97/01)"
label var _reg_ttwa91 "Region - TTWA from 1991 Census (SS01/06)"
label var _weight "Non-response weight"
label var _weight_2 "Design weight"
label var _weight_eib "EiB weight for comparing to SS rather than WiB (gender-adjusted only)"
label var _year "Year of interview, 4-digit"
label var age "Age"
label var agegrp "Age group recoded to be comparable across WERS"
label var agegrp1 "Age group for WERS98"
label var agegrp2 "Age group for WERS04"
label var co80_5 "Occupation - CO80, 5-digit"
label var fulltime "Working time - full-time vs part-time"
label var govsch "Working status - whether on a government training scheme"
label var hours "Hours of work per week"
label var hours_B "Hours of work per week, grouped (SCELI)"
label var hours_D "Hours of work per week, grouped (BSA)"
label var hours_E "Hours of work per week, grouped (BSA self-completion)"
label var hours_F "Hours of work per week, grouped (EiB)"
label var isco_1 "Occupation - ISCO, 1-digit"
label var isco_2 "Occupation - ISCO, 2-digit"
label var isco_4 "Occupation - ISCO, 4-digit"
label var maxqual "Highest qualification, grouped"
label var nace_1 "Industry - NACE, 1-digit"
label var nace_2 "Industry - NACE, 2-digit"
label var order "Survey"
label var sector "Sector - public vs private vs nonprofit"
label var sector_B "Sector - public vs private"
label var selfemp1 "Emp type - self-employed vs employee"
label var selfemp2 "Emp type - self-employed vs employee based on additional questions"
label var selfemp3 "Emp type - self-employed vs employee vs family business"
label var sex "Sex"
label var sic03_1 "Industry - SIC2003, 1-digit"
label var sic03_2 "Industry - SIC2003, 2-digit"
label var sic03_4 "Industry - SIC2003, 4-digit"
label var sic03_5 "Industry - SIC2003, 5-digit"
label var sic07_2 "Industry - SIC2007, 2-digit"
label var sic80_2 "Industry - SIC1980, 2-digit"
label var sic80_3 "Industry - SIC1980, 3-digit"
label var sic80_4 "Industry - SIC1980, 4-digit"
label var sic92_1 "Industry - SIC1992, 1-digit"
label var sic92_2 "Industry - SIC1992, 2-digit"
label var sic92_4 "Industry - SIC1992, 4-digit"
label var sic92_5 "Industry - SIC1992, 5-digit"
label var soc00_2 "Occupation - SOC2000, 2-digit"
label var soc00_3 "Occupation - SOC2000, 3-digit"
label var soc00_4 "Occupation - SOC2000, 4-digit"
label var soc90_1 "Occupation - SOC90, 1-digit"
label var soc90_3 "Occupation - SOC90, 3-digit"
label var soc90_3_R "Occupation - SOC90 recoded from SOC2000, 3-digit"
label var uknational "UK national - necessary for EWCS comparability"
label var soc00_1R "Occupation - SOC2000, 1-digit derived from higher detail levels"
label var soc00_2R "Occupation - SOC2000, 2-digit derived from higher detail levels"
label var soc00_3R "Occupation - SOC2000, 2-digit derived from higher detail levels"
label var co80_1R "Occupation - CO80, 1-digit derived from higher detail levels"
label var C1_combined "How much influence do you personally have on how hard you work?"
label var C25_combined "How much influence do you...have on deciding how you...do the task?"
label var C33_combined "How much influence do you...have on deciding what tasks you are to do?"
label var C49_combined "How much influence do you...have on deciding the quality standards...?"
