// The descriptive statistics for the chapter on job trends, created Jul 2010

/*
// Using D1 for these examples - it's ordinal (which is a problem), and it features in more datasets than any other
eststo clear
local var "C1"
	global extraif "`var'<. & age<=60 & WORK==1 & _country~=3"
	include "$dir\reweight.doi"
svyset [pweight=_weight_eibR]
// Final notes
dis in red "Note to user: TYPE set more off"
*/





////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
// Comparing different methods of getting the main scales for SS01/SS06
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

pause off			// Set this to ON if you want to see the PCA results (or can simply check the log)
tab1 D1 D4 D12 D15 C1 C2 C15 C16_1 C23 C25 C33 C49 if order==57 | order==56
// Generating globals for the groups of vars
global Dgroup "D1 D4 D12 D15"
global Cgroup "C1 C15 C23 C25 C33 C49"
// Generating a variable that corresponds to the levels of each variable
	// Check that these variables match up to the lists above!
gen Dgroup = 10^3*D1 + 10^2*D4 + 10^1*D12 + 10^0*D15
	label var Dgroup "Pattern of responses for the variables in global Dgroup"
gen Cgroup = 10^5*C1 + 10^4*C15 + 10^3*C23 + 10^2*C25 + 10^1*C33 + 10^0*C49
	label var Cgroup "Pattern of responses for the variables in global Cgroup"


********************************************************	
* PCA: Francis Green's approach
********************************************************	
capture drop ?pca1
*pca D1 D4 D15			// Green's scale in the 2010 paper (in 'The Long Work Hours Culture' book)
pca $Dgroup, means
	pca $Dgroup, components(1) 
	predict Dpca*, score
		label var Dpca1 "Demands: PCA score"
	pause Demands PCA; press q to continue
pca $Cgroup, means
	pca $Cgroup, components(1) 
	predict Cpca*, score
		label var Cpca1 "Control: PCA score"
	pause Control PCA; press q to continue


********************************************************	
* FACTOR-NORMAL: assuming these vars are continuous
********************************************************	
factor $Dgroup 
	// I don't want to rotate the factor loadings because I don't want to discriminate between sets of variables - but if I wanted to, I could use: rotate, promax horst || estat common
	factor $Dgroup, factors(1) 
	predict Dfactor*, regression
		label var Dfactor1 "Demands: factor scores, regression scoring"
	predict Dfactor_bt, bartlett
		label var Dfactor_bt "Demands: factor scores, Bartlett scoring"
factor $Cgroup 
	// I don't want to rotate the factor loadings because I don't want to discriminate between sets of variables - but if I wanted to, I could use: rotate, promax horst || estat common
	factor $Cgroup, factors(1) 
	predict Cfactor*, regression
		label var Cfactor1 "Control: factor scores, regression scoring"
	predict Cfactor_bt, bartlett
		label var Cfactor_bt "Control: factor scores, Bartlett scoring"

	
********************************************************	
* FACTOR-POLYCHORIC: using polychoric correlations
********************************************************	
/* Commented out as not essential in current run-through

net install polychoric.pkg, from(http://web.missouri.edu/~kolenikovs/stata/)
polychoric $Dgroup
	local n = r(N)
	factormat r(R), n(`n')		// The problem with using FACTORMAT is that its very hard to generate predicted scale scores (also unsure if factor analysis rather than PCA is a good idea - http://faculty.chass.ncsu.edu/garson/PA765/factor.htm) 
// Creating the scales 
	// This produces the variables __tt... for each var: I'm not quite sure what this provide...
polychoricpca $Dgroup, score(Dpolypca) nscore(1)
	label var Dpolypca1 "Demands: polychoric PCA score"
	// Computing the Cronbach's alpha equivalent for internal consistency; See Quant&Stata notes for details - this comes from Zumbo et al 2007
	matrix working_Dpolypca1 = r(eigenvalues)		
		scalar eigen_Dpolypca1 = working_Dpolypca1[1,1]
		scalar numvars_Dpolypca1 = colsof(working_Dpolypca1)
		scalar Dordinal_theta =  (numvars_Dpolypca1/(numvars_Dpolypca1 - 1) )  * ( 1 - (1/eigen_Dpolypca1) ) 	
		dis _newline(3) in red "Cronbach's alpha equivalent for the underlying continuous variables (from Zumbo et al 2007)" _newline "DEMANDS - ordinal theta = " %4.3f Dordinal_theta
		pause Polychoric PCA: Demands
polychoricpca $Cgroup, score(Cpolypca) nscore(1)
	label var Cpolypca1 "Control: polychoric PCA score"
	// Computing the Cronbach's alpha equivalent for internal consistency; See Quant&Stata notes for details - this comes from Zumbo et al 2007
	matrix working_Cpolypca1 = r(eigenvalues)
		scalar eigen_Cpolypca1 = working_Cpolypca1[1,1]
		scalar numvars_Cpolypca1 = colsof(working_Cpolypca1)
		scalar Cordinal_theta =  (numvars_Cpolypca1/(numvars_Cpolypca1 - 1) )  * ( 1 - (1/eigen_Cpolypca1) ) 	
		dis _newline(3) in red "Cronbach's alpha equivalent for the underlying continuous variables (from Zumbo et al 2007)" _newline "CONTROL - ordinal theta = " %4.3f Cordinal_theta
		pause Polychoric PCA: Control
drop __tt*

*/


********************************************************	
* GLLAMM: one-factor 1PL & 2PL IRT models
/*	Note that running GLLAMM requires substantially reshaping the data
		and then taking the matrix output back into the original datafile.
		This is why this is done in a separate .do file	*/
********************************************************	
/*
save "$workingdir\2_pre_gllammIRT.dta", replace
	*use "$workingdir\2_pre_gllammIRT.dta", replace
	do "$dir\gllammIRT_demands.do"					// Running the models is q slow: 1hr
	use "$workingdir\2_pre_gllammIRT.dta", replace
	do "$dir\gllammIRT_control.do"					// This is even slower as more vars in the scale: 1hr10mins just for the 1PL
// This is not added to the data until after the GLLAMM models for the different scales below - otherwise produces error messages		
*/		
	
		
		

		
		
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////
// Different scales for different years, using GLLAMM
//	NOTE: this will be very slow as the #cases will rise in additional surveys
////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

// Generating globals for the groups of vars
global Cgroup2 "C1 C23 C25 C33 C49"													// For SS01/SS06 + SS97 (deleted C15)
*global Cgroup3 "C1_combined C15 C25_combined C33_combined C49_combined"			// NOT USED: For SS01/SS06 + EiB92 (deleted C23)
global Cgroup4 "C1_combined C25_combined C33_combined C49_combined"					// For SS01/SS06 + SS97 + EiB92 (deleted C15 and C23)
global Dgroup3 "D1 D4 D12"															// For SS01/SS06 + EiB92 (deleted D15) - same years as Cgroup3
global Pgroup  "P6 P8"																// For SS97/01/06 - slight problem with only two measures
* Other Dgroups not necessary - D1 is the only comparable variable

// Generating a variable that corresponds to the levels of each variable (a pattern variable)
capture drop p?group?
foreach group in Cgroup2 Cgroup4 Dgroup3 Pgroup	{	
	local i = wordcount("$`group'")
	dis "`i'"
	gen p`group' = 0
	label var p`group' "Pattern of responses for the variables in global `group'"
	foreach var in $`group'									{
		local i = `i' - 1
		dis "This is 10^i*var: 10^`i' * `var'"
		replace p`group' = p`group' + (10^`i' * `var')
															}
													}
* To check, type: sum $Cgroup2 if pCgroup2==11112


/* Running GLLAMM 
save "$workingdir\2_pre_gllammIRT2.dta", replace
use "$workingdir\2_pre_gllammIRT2.dta", replace
	do "$dir\gllammIRT_demands_scale3.do"					// For Dgroup3.  Note that the 1PL model here doesn't seem to work (see the ICC, also low r to 2PL) so don't use it
use "$workingdir\2_pre_gllammIRT2.dta", replace
	do "$dir\gllammIRT_control_scale2.do"					// For Cgroup2
use "$workingdir\2_pre_gllammIRT2.dta", replace
	do "$dir\gllammIRT_control_scale4.do"					// For Cgroup4
use "$workingdir\2_pre_gllammIRT2.dta", replace
	do "$dir\gllammIRT_physical1.do"						// For Pgroup
use "$workingdir\2_pre_gllammIRT2.dta", replace
	*/ /* The results */
	include "$dir\IRTresults.doi"			// This generates the scale variables from the IRT models (via Excel sheets that must be changed by hand)
		label var Dglam1PL "Demands: 1-parameter IRT model using GLLAMM"
		label var Dglam2PL "Demands: 2-parameter IRT model using GLLAMM"
		label var Cglam1PL "Control: 1-parameter IRT model using GLLAMM"
		label var Cglam2PL "Control: 2-parameter IRT model using GLLAMM"
		label var C2glam2PL "Control: +SS97 comparison (ignored C15), 2-parameter IRT model using GLLAMM"
		label var C4glam2PL "Control: +SS97+EiB comparison (ignored C15 and C23), 2-parameter IRT model using GLLAMM"
		label var D3glam2PL "Demands: +EiB comparison (ignored D15), 2-parameter IRT model using GLLAMM"
* Reverse scale direction so that high Cscale = high control, high Dscale = high demands
gen Cscale = -Cglam2PL
	label var Cscale "Control: scale based on 2PL GLLAMM model"
	gen Cscale2 = -C2glam2PL
	label var Cscale2 "Control: scale +SS97 comparison (ignored C15), based on 2PL GLLAMM model"
	gen Cscale4 = -C4glam2PL
	label var Cscale4 "Control: scale +SS97+EiB comparison (ignored C15 and C23), based on 2PL GLLAMM model"
gen Dscale = -Dglam2PL
	label var Dscale "Demands: scale based on 2PL GLLAMM model"
	gen Dscale3 = -D3glam2PL
	label var Dscale3 "Demands: scale +EiB comparison (ignored D15), based on 2PL GLLAMM model"
gen Pscale = -Pglam2PL  
	order Pscale, after(Pglam2PL)
	label var Pscale "Physical demands: scale based on 2PL GLLAMM model"
	order Dpca1-Dscale3, alphabetic last
order Dgroup-Dscale3, alphabetic last




//////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////
// Make the scales interpretable with mean 0 SD 1 
//		Note that the Cscale is not very normal
//////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////

// For the SS01/SS06 SOC2000 sample
global extraif "Cscale<.  & Dscale<.  & age>=20 & age<=60 & WORK==1 & _country~=3 & soc00_BB<." 		
	include "$dir\reweight.doi"			
	svyset [pweight=_weight_eibR]	
svy: mean Cscale Dscale Pscale
estat sd
matrix means = e(b)
matrix sds = r(sd)
replace Cscale = (Cscale-means[1,1])/(sds[1,1])
replace Dscale = (Dscale-means[1,2])/(sds[1,2])
replace Pscale = (Pscale-means[1,3])/(sds[1,3])
svy: mean Cscale Dscale Pscale
estat sd
	
	
// For the EiB/SS01/SS06 SOC2000 sample
global extraif "Cscale4<. & Dscale3<. & age>=20 & age<=60 & WORK==1 & _country~=3 & (soc90_3<. | soc00_4<.)" 		
	include "$dir\reweight.doi"			
	svyset [pweight=_weight_eibR]	
gen Pscale2 = Pscale
	order Pscale2, after(Pscale)
	label var Pscale2 "Physicality scale, centred on 1992-2006 subsample"
svy: mean Cscale4 Dscale3 Pscale2
estat sd
matrix means = e(b)
matrix sds = r(sd)
replace Cscale4 = (Cscale4-means[1,1])/(sds[1,1])
replace Dscale3 = (Dscale3-means[1,2])/(sds[1,2])
replace Pscale2 = (Pscale2-means[1,3])/(sds[1,3])
svy: mean Cscale4 Dscale3 Pscale2
estat sd	
* The continuous version of strain
foreach Svar in Cscale4 Dscale3 {
	sum `Svar'
	gen temp_`Svar' = `Svar'+ (-r(min) + 1)
	/**/						}
gen Scont = temp_Dscale/temp_Cscale4
*tabstat Cscale4 Dscale3 Scont Pscale2, by(soc90_1_allyr)		// This is an OK check on later versions, but soc90_1_allyr hasn't been created yet!
drop temp*


