** Creating the job strain variable from the demands and control scales; first written 5/8/10

// Preparation
global extraif "Cscale<. & Dscale<. & age<=60 & WORK==1 & _country~=3"
	include "$dir\reweight.doi"							// Can't SVYSET the data as no SURVEY commands get MEDIANS - have to use _pctile with weights (see http://www.stata.com/statalist/archive/2007-03/msg00295.html)
	// Check for missingness
*misschk C1 C15 C23 C25 C33 C49 Cscale if order==56 | order==57
*misschk D1 D4 D12 D15 Dscale if order==56 | order==57


// StrainGrn: copying Francis Green (demands>1SD above mean, control<= median for A1; 	D1==strongly agree & control<=median for A2)
quietly _pctile Cscale [pweight=_weight_eibR], nquantiles(2)
	scalar Cmedian = r(r1)
gen strainGrn1 = (Cscale<=Cmedian & Dscale>1) if Cscale<. & Dscale<.
	label var strainGrn1 "Strain: Green's method 1"
gen strainGrn2 = (Cscale<=Cmedian & D1==1) 	if Cscale<. & D1<.
	label var strainGrn2 "Strain: Green's method 2"

// StrainT: worst tertile for both demands and control
_pctile Cscale [pweight=_weight_eibR], nquantiles(3)
	scalar Clowtertile  = r(r1)
_pctile Dscale [pweight=_weight_eibR], nquantiles(3)
	scalar Dhightertile = r(r2)
gen strainT = (Cscale<=Clowtertile & Dscale>=Dhightertile) if Cscale<. & Dscale<.
	label var strainT "Strain: worst tertiles"

// StrainT2: tertile-based 'active' and 'high-strain' jobs, with everything else left in the middle
_pctile Cscale [pweight=_weight_eibR], nquantiles(3)
	scalar Clowtertile   = r(r1)
	scalar Chightertile  = r(r2)
_pctile Dscale [pweight=_weight_eibR], nquantiles(3)
	scalar  Dlowtertile  = r(r1)
	scalar Dhightertile  = r(r2)
gen strainT2 = (Cscale<=Clowtertile & Dscale>=Dhightertile) if Cscale<. & Dscale<.
	replace strainT2 = 2 if (Cscale>=Chightertile & Dscale>=Dhightertile) & strainT2<.
	label var strainT2 "Strain: tertiles for active and high-strain"	
	label define strainT2 1 "1_HighStr" 2 "2_Active"
	label values strainT2 strainT2

// Strain4: 4-way median split for highstrain/lowstrain/active/passive
	// NOTE that highstrain is defined as less than (but not equal to) median control, and more than (but not equal to) median demands
quietly _pctile Cscale [pweight=_weight_eibR], nquantiles(2)
	scalar Cmedian = r(r1)
quietly _pctile Dscale [pweight=_weight_eibR], nquantiles(2)
	scalar Dmedian = r(r1)
gen strain4 = 0 if Cscale<. & Dscale<.
	replace strain4 = 1 if (Cscale<Cmedian & Dscale>Dmedian) 		& strain4<.
	replace strain4 = 2 if (Cscale>=Cmedian & Dscale<=Dmedian) 		& strain4<.
	replace strain4 = 3 if (Cscale<Cmedian & Dscale<=Dmedian) 		& strain4<.
	replace strain4 = 4 if (Cscale>=Cmedian & Dscale>Dmedian) 		& strain4<.
label define strain4 1 "1_histrain" 2 "2_lostrain" 3 "3_passive" 4 "4_active"
	label values strain4 strain4
	label var strain4 "Strain: 4-way median split for histrain/lostrain/passive/active"
	capture tab strain4, gen(strain4_)

	
// Strain C: continuous interaction of demands and control
gen strainC = -Cscale * Dscale
	label var strainC "Strain: continuous"

	
	
****************************************************************************
* Also doing this for the EiB92 scale (the only one that uses more than D1)
****************************************************************************
global extraif "Cscale4<. & Dscale3<. & age<=60 & WORK==1 & _country~=3"
	include "$dir\reweight.doi"							// Can't SVYSET the data as no SURVEY commands get MEDIANS - have to use _pctile with weights (see http://www.stata.com/statalist/archive/2007-03/msg00295.html)
quietly _pctile Cscale4 [pweight=_weight_eibR], nquantiles(2)
	scalar Cmedian4 = r(r1)
quietly _pctile Dscale3 [pweight=_weight_eibR], nquantiles(2)
	scalar Dmedian3 = r(r1)
gen strain4_eib = 0 if Cscale4<. & Dscale3<.
	replace strain4_eib = 1 if (Cscale4<Cmedian4  & Dscale3>Dmedian3) 		& strain4_eib<.
	replace strain4_eib = 2 if (Cscale4>=Cmedian4 & Dscale3<=Dmedian3) 		& strain4_eib<.
	replace strain4_eib = 3 if (Cscale4<Cmedian4  & Dscale3<=Dmedian3) 		& strain4_eib<.
	replace strain4_eib = 4 if (Cscale4>=Cmedian4 & Dscale3>Dmedian3) 		& strain4_eib<.
	label values strain4_eib strain4
	label var strain4_eib "Strain: 4-way median split for EiB92 to SS01/SS06 comparison"


****************************************************************************
* For the 1997 comparable strain version (based on Green, using D1)
****************************************************************************
global extraif "Cscale4<. & D1<. & age<=60 & WORK==1 & _country~=3"
	include "$dir\reweight.doi"							// Can't SVYSET the data as no SURVEY commands get MEDIANS - have to use _pctile with weights (see http://www.stata.com/statalist/archive/2007-03/msg00295.html)
quietly _pctile Cscale4 [pweight=_weight_eibR], nquantiles(2)
	scalar Cmedian_eib = r(r1)
gen strainGrn_eib = 0 if Cscale4<. & D1<.
	replace strainGrn_eib = 1 if (Cscale4< Cmedian_eib & D1==1) 		& strainGrn_eib<.
	replace strainGrn_eib = 2 if (Cscale4>=Cmedian_eib & D1~=1) 		& strainGrn_eib<.
	replace strainGrn_eib = 3 if (Cscale4< Cmedian_eib & D1~=1) 		& strainGrn_eib<.
	replace strainGrn_eib = 4 if (Cscale4>=Cmedian_eib & D1==1)			& strainGrn_eib<.
label values strainGrn_eib strain4
	label var strainGrn_eib "Strain: based on Cscale4 and D1"

	


/*	Quick checks to make sure these work OK:
sum *strain*
bysort strainGrn1: sum Cscale Dscale
bysort strainT: sum Cscale Dscale
bysort strain4: sum Cscale Dscale
bysort strain4_eib: sum Cscale4 Dscale3
svy: proportion strainGrn? strainT strain4
svy: mean strainC
tab2 strain4 strainGrn? strainT, firstonly
*/


