/////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////
// Determining the best functional form for the scale predictors
/////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////

/* Variables available as covariates:
	_year OR order | age | fulltime | selfemp1		SS06/SS01/SS97/WiB/EiB
	maxqual											SS06/SS01/SS97/   /EiB
	sic92_1R | sector								SS06/SS01/SS97/WiB/	
	hours											SS06/SS01/    /WiB/
	_region											SS06/SS01/    /   /EiB
LIST1 for all SS + EiB: 	order | age | fulltime | selfemp1 |maxqual
LIST2 for SS01/SS06: 		order | age | fulltime | selfemp1 |maxqual | sic92_1R | sector | hours | _region
	end of variable lists*/	

global extraif "Cscale<. & age<=60 & WORK==1 & _country~=3"
global extraif "$extraif & missing(order, fulltime, selfemp1, sex, maxqual, sic92_1R, sector, _region, Cscale, hours, age)==0"
include "$dir\reweight.doi"			// use reweight_SOCallyrs.doi if looking across the expanded dataset; reweight.doi otherwise
net install mfpx, from(http://www.homepages.ucl.ac.uk/~ucakjpr/stata)			// Installs the MFP_PLUS command used below (the others are for possible future use) - see also MFPI and MFPBOOT from same source
*	NOTE: MFP_PLUS does allow you to use MFP with XTREG, but not XTMIXED.  This is a problem, as Empirical Bayes estimates are only available for XTMIXED.  


// The MFP commands: if specifying the variables in factor form, then would be i.order i.fulltime i.selfemp1 i.sex i.maxqual i.sic92_1R i.sector i._region
estimates clear
eststo mfp: xi: mfp_plus, alpha(0.05) select(0.05): reg Cscale i.order i.fulltime i.selfemp1 i.sex (i.maxqual) (i.sic92_1R) (i.sector) (i._region) (i.soc00_BB) ///
	age hoursTRIM [pweight=_weight_eibR] if $extraif
	fracplot age, m(i) ciopts(color(gs8))
		graph save "$graphdir\Cmfp_age", replace
	fracplot hoursTRIM, m(i) ciopts(color(gs8))
		graph save "$graphdir\Cmfp_hours", replace
	matrix delme = e(b)
	local colvars: colnames delme
	dis "`colvars'"									// Then copy the text into the command below, missing out the '_cons' at the end
	exit
	local xvars "			fulltimeB employeeB maxqual2 maxqual3 maxqual4 maxqual5 maxqual6 sic92_1R2 sic92_1R3 sic92_1R4 sic92_1R5 sic92_1R6 sic92_1R7 sic92_1R8 sic92_1R9 sic92_1R10 sic92_1R11 sic92_1R12 "
	local xvars "`xvars'	sic92_1R13 sic92_1R14 sector2 sector3"
	local xvars "`xvars'	socBB_2 socBB_3 socBB_4 socBB_5 socBB_6 socBB_7 socBB_8 socBB_9 socBB_10 socBB_11 socBB_12 socBB_13 socBB_14 socBB_15"
	local xvars "`xvars' 	socBB_16 socBB_17 socBB_18 socBB_19 socBB_20 socBB_21 socBB_22 socBB_23 socBB_24 socBB_25 socBB_26 socBB_27 socBB_28 socBB_29 socBB_30 socBB_31 socBB_32 socBB_33 socBB_34 "
	local xvars "`xvars' 	socBB_35 socBB_36 socBB_37 socBB_38 socBB_39 socBB_40 socBB_41 socBB_42 socBB_43 socBB_44 socBB_45 socBB_46 socBB_47 socBB_48 socBB_49 socBB_50 socBB_51 socBB_52 socBB_53 "
	local xvars "`xvars' 	socBB_54 socBB_55 socBB_56 socBB_57 socBB_58 socBB_59 socBB_60 socBB_61 socBB_62 socBB_63 socBB_64 socBB_65 socBB_66 socBB_67 socBB_68 socBB_69 socBB_70 socBB_71 socBB_72 "
	local xvars "`xvars' 	socBB_73 socBB_74 socBB_75 socBB_76 socBB_77 socBB_78 socBB_79 socBB_80 socBB_81 socBB_82 socBB_83 socBB_84 socBB_85 socBB_86 socBB_87 socBB_88 socBB_89 socBB_90 socBB_91 "
	local xvars "`xvars' 	socBB_92 socBB_93 socBB_94 socBB_95 socBB_96 socBB_97 socBB_98 socBB_99 socBB_100 socBB_101 socBB_102 socBB_103 socBB_104 socBB_105 socBB_106 socBB_107 socBB_108 socBB_109 "
	local xvars "`xvars' 	socBB_110 socBB_111 socBB_112 socBB_113 socBB_114 socBB_115 socBB_116 socBB_117 socBB_118 "
quietly eststo occonly: reg Cscale socBB_2-socBB_118 																	[pweight=_weight_eibR] if $extraif		// Only using occ categories
quietly eststo linear:  reg Cscale age hours `xvars' 																	[pweight=_weight_eibR] if $extraif		// Linear age and hours
quietly eststo mfp_rep: reg Cscale Iage__* Ihour__* `xvars' 															[pweight=_weight_eibR] if $extraif		// Replication of the MFP command
quietly eststo allvars: reg Cscale Iage__* Ihour__* `xvars' order5 male _region1-_region6 _region8-_region11  			[pweight=_weight_eibR] if $extraif		// MFP + the vars it dropped
esttab occonly linear mfp mfp_rep allvars using "$tabdir\Cmfp", not order(*age* *hour*) r2 keep(*age* *hour* *maxqual* fulltimeB male *region*) scalars("df_m # Covariates") mtitles ///
	fixed replace addnotes("Cscale, done on $S_DATE" "Varlist from MFP is `xvars'")


// And the same again for demands - just need to change Cscale to Dscale, and Cmfp to Dmfp
estimates clear
eststo mfp: xi: mfp_plus, alpha(0.05) select(0.05): reg Dscale i.order i.fulltime i.selfemp1 i.sex (i.maxqual) (i.sic92_1R) (i.sector) (i._region) (i.soc00_BB) ///
	age hoursTRIM [pweight=_weight_eibR] if $extraif
	fracplot age, m(i) ciopts(color(gs8))
		graph save "$graphdir\Dmfp_age", replace
	fracplot hoursTRIM, m(i) ciopts(color(gs8))
		graph save "$graphdir\Dmfp_hours", replace
	matrix delme = e(b)
	local colvars: colnames delme
	dis "`colvars'"									// Then copy the text into the command below, missing out the '_cons' at the end
	dis in red "Now copy the text above into the local xvars below, AND change the additional variables added in reg3" 
	exit
	local xvars "			order5 fulltimeB male maxqual2 maxqual3 maxqual4 maxqual5 maxqual6 sic92_1R2 sic92_1R3 sic92_1R4 sic92_1R5 sic92_1R6 sic92_1R7 sic92_1R8 sic92_1R9 sic92_1R10 sic92_1R11 sic92_1R12 "
	local xvars "`xvars' 	sic92_1R13 sic92_1R14 sector2 sector3 _region1 _region2 _region3 _region4 _region5 _region6 _region8 _region9 _region10 _region11 "
	local xvars "`xvars'	socBB_2 socBB_3 socBB_4 socBB_5 socBB_6 socBB_7 socBB_8 socBB_9 socBB_10 socBB_11 socBB_12 socBB_13 socBB_14 socBB_15"
	local xvars "`xvars' 	socBB_16 socBB_17 socBB_18 socBB_19 socBB_20 socBB_21 socBB_22 socBB_23 socBB_24 socBB_25 socBB_26 socBB_27 socBB_28 socBB_29 socBB_30 socBB_31 socBB_32 socBB_33 socBB_34 "
	local xvars "`xvars' 	socBB_35 socBB_36 socBB_37 socBB_38 socBB_39 socBB_40 socBB_41 socBB_42 socBB_43 socBB_44 socBB_45 socBB_46 socBB_47 socBB_48 socBB_49 socBB_50 socBB_51 socBB_52 socBB_53 "
	local xvars "`xvars' 	socBB_54 socBB_55 socBB_56 socBB_57 socBB_58 socBB_59 socBB_60 socBB_61 socBB_62 socBB_63 socBB_64 socBB_65 socBB_66 socBB_67 socBB_68 socBB_69 socBB_70 socBB_71 socBB_72 "
	local xvars "`xvars' 	socBB_73 socBB_74 socBB_75 socBB_76 socBB_77 socBB_78 socBB_79 socBB_80 socBB_81 socBB_82 socBB_83 socBB_84 socBB_85 socBB_86 socBB_87 socBB_88 socBB_89 socBB_90 socBB_91 "
	local xvars "`xvars' 	socBB_92 socBB_93 socBB_94 socBB_95 socBB_96 socBB_97 socBB_98 socBB_99 socBB_100 socBB_101 socBB_102 socBB_103 socBB_104 socBB_105 socBB_106 socBB_107 socBB_108 socBB_109 "
	local xvars "`xvars' 	socBB_110 socBB_111 socBB_112 socBB_113 socBB_114 socBB_115 socBB_116 socBB_117 socBB_118 "
quietly eststo occonly: reg Dscale socBB_2-socBB_118 																	[pweight=_weight_eibR] if $extraif		// Only using occ categories
quietly eststo linear:  reg Dscale age hours `xvars' 																	[pweight=_weight_eibR] if $extraif		// Linear age and hours
quietly eststo mfp_rep: reg Dscale Iage__* Ihour__* `xvars' 															[pweight=_weight_eibR] if $extraif		// Replication of the MFP command
quietly eststo allvars: reg Dscale Iage__* Ihour__* `xvars' employeeB										  			[pweight=_weight_eibR] if $extraif		// MFP + the vars it dropped
esttab occonly linear mfp mfp_rep allvars using "$tabdir\Dmfp", not order(*age* *hour*) r2 keep(*age* *hour* *maxqual* fulltimeB male *region*) scalars("df_m # Covariates") mtitles ///
	fixed replace addnotes("Dscale, done on $S_DATE" "Varlist from MFP is `xvars'")


// Cleaning up
drop _I*
