// Sample selection and variable lists
// NOTE that this is slightly changed from the main IF files - Fage_all not Fage, and Fivfio==1 removed (as don't want to restrict this to people answering at the following wave!)
global if1 		"age>=20 & ((Fage_all<65 & sex==1) | (Fage_all<60 & sex==2)) & employR==1 & jbsemp==1 & region2<=11 & wave<=2006 & ivfio==1 & pidselect>=0 & pidselect<=1"		


// Creating variables that get the best balance between no separation probs and the full effect of D-C
clonevar sicICE = sic92_1A
recode sicICE (1 3=1)


// Recoded variables for sensitivity analyses, grouped to avoid separation problems
* RENAME THIS IN GLBOBALS TOO.  Otherwise the factor variables syntax renames this weirdly below
rename hoursGRP  	hrsC 						
* age at t+1, even for those that didn't reply at t+1 (assumed it was a year later)
clonevar Fage_all = Fage
replace Fage_all = age+1 if Fage>=. & age<.
* The recoded _REGION variable for the allsamples weighted analyses (where some regions currently too small for a rare outcome)
recode _region (1 3=1 "1_NE/Yorkshire") (2=2 "2_NW") (4/5=3 "3_Midlands") (6 9=4 "4_East/SW") (7/8=5 "5_London/SE") (10=10 "10_Wales") (11=11 "11_Scotland"), gen(_region2) 
	label var _region "Region for wt_allsamples analysis, recoded from _region"
* The recoded SIC92_1A variable for other analyses that struggle with sample size problems
recode sic92_1A (1/6=1 "1_Manuf/Agri/Constr") (7/8=2 "2_Retail/HoReCa") (9=3 "3_Transport/storage") (10/11=4 "4_Finance/Real Estate") ///
	(12=5 "5_Public adm") (13=6 "6_Education") (14/15=7 "7_Health/social/community"), gen(sicGRP)
	label var sicGRP "Industry regrouped for small sample analysis, recoded from sic92_1A"
* The recoded hlprb variables for the medation analysis (IBreceipt only)
clonevar hlprbOth = hlprbm
	replace hlprbOth = 1 if hlprbk==1
	label var hlprbOth "health problems: other(hlprbm)+epilepsy(hlprbk)"
clonevar hlprbiR = hlprbi
	replace hlprbiR = 1 if hlprbj==1
	label var hlprbiR "health problems: MH inc addiction (hlprbi + hlprbj)"

// Globals
* Globals
global demvars			"i.agegrp i.sex i.married i.nchildR i._region  bem"
  global demvars_wts	"i.agegrp i.sex i.married i.nchildR i._region2 "
local lsilist			"hlprba hlprbb hlprbc hlprbd hlprbe hlprbf hlprbg hlprbh hlprbi hlprbj hlprbk hlprbl hlprbm 	hlltaR hlltbR hlltcR hlltdR		hospR"
global hlthvars 		"`lsilist' ghqB"
  global hlthvars_cs 	"hlprba hlprbb hlprbc hlprbd hlprbe hlprbf hlprbg hlprbh hlprbiR 	   		  hlprbl hlprbOth   i.hllt 							hospR ghqB"
  global hlthvarsICE	 "hlprba hlprbb hlprbc hlprbd hlprbe hlprbf hlprbg hlprbh hlprbiR 	   		  hlprbl hlprbOth   hlltaR hlltbR hlltcR hlltdR		hospR ghqB"
global sesvars_nost		"i.maxqual        loginc  i.housing"
global workvars			"i.hrsC occpenR i.sector tempjob i.sme i.sic92_1A"
  global workvars_small	"i.hrsC occpenR i.sector tempjob i.sme                                              i.sicGRP"			// For when I get convergence problems due to the small sizes of some industries
  global workvarsICE	"i.hrsC occpenR i.sector tempjob i.sme i.sicICE"														// For when I get convergence problems due to the small sizes of some industries
global partnervars		"partnered sp_wldB sp_IBreceipt sp_employR"
global waves			"i.wave"						// Note that this must be replaced if 1991 isn't the base year
* The full lists used here
global origreg			"$demvars		$hlthvars		$sesvars_nost	$workvars		$partnervars $waves"
global MIreg			"$demvars_wts	$hlthvarsICE	$sesvars_nost	$workvarsICE	$partnervars $waves"
global tokeep			"$origreg		_pid _region2 hlprbiR hlprbOth hllt sicGRP sicICE"
global ICElist			"agegrp sex m.married nchildR _region2 hlprba hlprbb hlprbc hlprbd hlprbe hlprbf hlprbg hlprbh hlprbiR  hlprbl hlprbOth ghqB hlltaR hlltbR hlltdR hospR o.maxqual loginc m.housing o.hrsC m.occpenR m.sector m.tempjob m.sme m.sicICE wave"


//Other bits of preparation 
* Missing vars DV
xi: egen allvars = rowmiss(wldB IBreceipt JEMC2 ${origreg}) 								
gen missTPLUS1 = (FwldB>=. | FIBreceipt>=.) if allvars==0 
* Creating new tertiles - otherwise C-D are missing for people who don't respond at the following wave
foreach JEMvar in JEMC2 JEMD2 JEMP2	{
	drop `JEMvar't
	if "`JEMvar'"~="JEMP3"		xtile `JEMvar't = `JEMvar' if ${if1}, nquant(3)		// JEMP3 has no observations
	if "`JEMvar'"~="JEMP3"		label var `JEMvar't "Tertiles of `JEMvar'"
	/**/							}
* Keeping variables - I need to remove the i. factor variables notation, and this short code enables me to do this within Stata's 244 character limit for string functions
global cleanvars = ""
global cleanvars2 = ""
foreach text in $tokeep	{
	local dot		= strpos("`text'", ".")
	local minusXI 	= substr("`text'",`dot'+1,.)
	if length("${cleanvars}")<200		global cleanvars  = "${cleanvars}  `minusXI'"
	if length("${cleanvars}")>200		global cleanvars2 = "${cleanvars2} `minusXI'"
	/**/				}
keep $cleanvars $cleanvars2 JEM?2t *wldB *IBreceipt missTPLUS1 age employR jbsemp region2 ivfio pidselect Fage* allvars
keep if $if1
drop F2*
compress


	
///////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////
// Cross-sectional imputation 
///////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////

capture log close miss
quietly log using "$logdir\missing_data", text replace name(miss)		// This is not reported in tables, but instead stored in an additional log file

// Looking at item-missingness (for people who give dem-con data) and attrition (between baseline & follow-up)
tab wave missTPLUS1 if ${if1}, row
tab JEMC2t missTPLUS1 if ${if1} & (wave~=1998 & wave~=2003), row
misschk $cleanvars JEM?2t age employR jbsemp region2 ivfio pidselect if ${if1} & (wave~=1998 & wave~=2003)
// Categorical D-C
xtlogit missTPLUS1 i.JEMC2t i.JEMD2t 										if ${if1} & (wave~=1998 & wave~=2003), vce(robust) i(_pid) pa corr(exchangeable)
xtlogit missTPLUS1 i.JEMC2t i.JEMD2t i.JEMP2t wldB IBreceipt ${MIreg}	 	if ${if1} & (wave~=1998 & wave~=2003), vce(robust) i(_pid) pa corr(exchangeable)
xtlogit missTPLUS1 i.JEMC2t i.JEMD2t i.JEMP2t wldB IBreceipt ${origreg} 	if ${if1} & (wave~=1998 & wave~=2003), vce(robust) i(_pid) pa corr(exchangeable)
// Continuous D-C
xtlogit missTPLUS1   JEMC2    JEMD2 										if ${if1} & (wave~=1998 & wave~=2003), vce(robust) i(_pid) pa corr(exchangeable)
xtlogit missTPLUS1   JEMC2    JEMD2    JEMP2  wldB IBreceipt ${MIreg} 		if ${if1} & (wave~=1998 & wave~=2003), vce(robust) i(_pid) pa corr(exchangeable)
xtlogit missTPLUS1   JEMC2    JEMD2    JEMP2  wldB IBreceipt ${origreg} 	if ${if1} & (wave~=1998 & wave~=2003), vce(robust) i(_pid) pa corr(exchangeable)



// Checking reduced varlist against the full model
/* Differences: 
	i._region replaced by i._region2
	bem omitted
	hlprbi and hlprbj combined into hlprbiR
	hlprbk and hlprbm combined into hlprbOth
	hlltcR omitted (previously all of these were omitted and i.hlltR inc)
	i.sic92_1A replaced by i.sicICE (previously i.sicGRP)
	$partnervars omitted
*/
global both "i.agegrp i.sex i.married i.nchildR hlprba hlprbb hlprbc hlprbd hlprbe hlprbf hlprbg hlprbh hlprbl ghqB hospR i.maxqual loginc i.housing i.hrsC occpenR i.sector tempjob i.sme i.wave"
eststo MIreg: 		xtlogit FwldB i.JEMC2t i.JEMD2t i.JEMP2t ${MIreg} 					if ${if1}					, vce(robust) i(_pid) pa corr(exchangeable)
eststo origreg: 	xtlogit FwldB i.JEMC2t i.JEMD2t i.JEMP2t ${origreg} 				if ${if1}					, vce(robust) i(_pid) pa corr(exchangeable)



// Getting the dataset ready for MI - look at $MIreg, and then replace it with the appropriate ICE syntax
time
	local cmth = month(date(c(current_date), "DMY"))
	local cyr  = year(date(c(current_date), "DMY"))
	global period "_`cyr'_`cmth'"
dis `"${dir}\ICE_`cyr'_`cmth'"'
ice FwldB FIBreceipt m.JEMC2t m.JEMD2t m.JEMP2t ${ICElist} if ${if1} & (wave~=1998 & wave~=2003),								///
	m(20) cycles(10) drop saving(ICE${period}, replace) trace(ICEtr${period}) 		///
	/*dryrun																		///
	*/seed (1234) orderasis															
time
quietly log close miss


// Checks on the imputed dataset
quietly log using "$logdir\missing_data", text append name(miss)		// This is not reported in tables, but instead stored in an additional log file
use "$dir\ICE${period}", replace
* ID variables
tostring _pid, gen(_pid2) format(%10.0f)
tostring _mj, gen(_mj2) format(%3.0f)
replace _pid2 = _pid2 + _mj2
destring _pid2, gen(_pidICE)
capture drop _pid2 _mj2
* Allvars
xi: egen allvars = rowmiss(wldB IBreceipt JEMC2 ${MIreg}) if _mj==0
bysort _pid wave: egen allvarsMJ = max(allvars)


// Running MIM
* WLD
forvalues i = 0/2	{
	eststo wldBMIM`i': 			xtlogit FwldB i.JEMC2t i.JEMD2t i.JEMP2t ${MIreg} if ${if1} & _mj==`i'	, vce(robust) i(_pid) pa corr(exchangeable)
	/**/			}
esttab wldBMIM0 wldBMIM1 wldBMIM2, keep(*JEM*) pr2 not
time
eststo wldBMIM11: mim, storebv:	xtlogit FwldB i.JEMC2t i.JEMD2t i.JEMP2t ${MIreg} if ${if1}				, vce(robust) i(_pid) pa corr(exchangeable)
	mim, mcerror
time
eststo wldBMIM12: mim, storebv:	xtlogit FwldB i.JEMC2t i.JEMD2t i.JEMP2t ${MIreg} if ${if1} & allvarsMJ==0, vce(robust) i(_pid) pa corr(exchangeable)
	mim, mcerror
time
* IB receipt
forvalues i = 0/2	{
	eststo IBreceiptMIM`i': 			xtlogit FIBreceipt i.JEMC2t i.JEMD2t i.JEMP2t ${MIreg} if ${if1} & _mj==`i'	, vce(robust) i(_pid) pa corr(exchangeable)
	/**/			}
esttab IBreceiptMIM0 IBreceiptMIM1 IBreceiptMIM2, keep(*JEM*) pr2 not
time
eststo IBreceiptMIM11: mim, storebv:	xtlogit FIBreceipt i.JEMC2t i.JEMD2t i.JEMP2t ${MIreg} if ${if1}			, vce(robust) i(_pid) pa corr(exchangeable)
	mim, mcerror
time
eststo IBreceiptMIM12: mim, storebv:	xtlogit FIBreceipt i.JEMC2t i.JEMD2t i.JEMP2t ${MIreg} if ${if1} & allvarsMJ==0, vce(robust) i(_pid) pa corr(exchangeable)
	mim, mcerror
time


quietly log close miss



	
	
	