// Descriptive analyses, written 3/1/2011
/*
	use JEM_$filename, replace
	estread * using "$dir/wldB_ests", id(uniqueid) 
	estread * using "$dir/IBreceipt_ests", id(uniqueid) 
*/
global if1 		"age>=20 & ((Fage<65 & sex==1) | (Fage<60 & sex==2)) & region2<=11 & employR==1 & jbsemp==1 & wave<=2006 & ivfio==1 & Fivfio==1 & pidselect>=0 & pidselect<=1"
svyset psu [pweight=wt_allwaves], strata(strata)			// SVY prefix is only for sensitivity analyses, but makes sense to set this at the start

* Creating the categorical demands/control/strain measures - done here so that it can reflect $if1
capture drop ?_T?
forvalues i = 1/2 	{
		xtile C_T`i' = JEMC`i' if ${if1}, nquant(3)			// I haven't added [pweight=wt_allwaves] as the main analyses are unweighted
			label var C_T`i' "Control from JEM`i'a: tertiles"
		xtile D_T`i' = JEMD`i' if ${if1}, nquant(3)			// I haven't added [pweight=wt_allwaves] as the main analyses are unweighted
			label var D_T`i' "Demands from JEM`i'a: tertiles"
		gen S_T`i' = (C_T`i'==1 & D_T`i'==3) if C_T`i'<. & D_T`i'<.
			label var S_T`i' "Job strain from JEM1a (low control + high demands)"
		xtile S2_T`i' = JEMS`i' if ${if1}, nquant(3)			// I haven't added [pweight=wt_allwaves] as the main analyses are unweighted
			label var D_T`i' "Demands from JEM`i'a: tertiles"
		xi, prefix("_") i.C_T`i' i.D_T`i'
		global CD`i' 	"_C_T`i'_2 _C_T`i'_3 _D_T`i'_2 _D_T`i'_3"
		global STR`i' 	"_C_T`i'_2 _C_T`i'_3 _D_T`i'_2 _D_T`i'_3 S_T`i'"
	/**/			}

// Variable list 
global demvars			"i.agegrp i.sex i.married i.nchildR bem i._region "
local lsilist			"hlprba hlprbb hlprbc hlprbd hlprbe hlprbf hlprbg hlprbh hlprbi hlprbj hlprbk hlprbl hlprbm"
global hlthvars 		"`lsilist' ghqB"
global sesvars			"i.maxqual status loginc  i.housing"
  global sesvars_nost	"i.maxqual        loginc  i.housing"
global workvars			"i.hoursGRP occpenR i.sector tempjob i.sme i.sic92_1A"
global partnervarsWLD	"partnered sp_wldB sp_IBreceipt sp_employR"
global partnervarsIB	"partnered         sp_IBreceipt sp_employR"
global policyvars		"dda IVBreform"
global waves			"i.wave"						// Note that this must be replaced if 1991 isn't the base year
	
// Set sample - copied across 21/6/2011 from the ALLVARS commands in the two files
capture drop allvars*
xi: egen allvarsWLD  = rowmiss(JEMC2 FwldB wldB $demvars $waves $hlthvars $partnervars $sesvars i.money $sesvars_oth $workvars i.money)
xi: egen allvarsIB  = rowmiss(JEMC2 FIBreceipt IBreceipt $demvars $waves $hlthvars $partnervars $sesvars i.money $sesvars_oth $workvars i.money)


	
//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Descriptive analysis
//////////////////////////////////////////////////////////////////////////////////////////////////////////////
* WLD: prevalence (wldB, FwldB), trend over time
tab wld_amt, gen(amtB)
tab Fwld_amt, gen(FamtB)
sum wld*B wld_type Fwld*B Fwld_type *amtB* if ${if1} & allvarsWLD==0, separator(0)
* Quick check that this is the right sample - which (eventually) it is
estimates restore wldB_CDm35
	sum wld*B wld_type Fwld*B Fwld_type *amtB* if e(sample), separator(0)

* Transition matrix
tab wldB FwldB if allvarsWLD==0 & ${if1}, row
tab wld_type Fwld_type if allvarsWLD==0 & ${if1}, row
tab wld_amt Fwld_amt if allvarsWLD==0 & ${if1}, row
* WLD by LLSI
svy: tab wldB llsi if allvarsWLD==0 & ${if1}, row

* Demands-control
bysort D_T2: sum JEMD2 if allvarsWLD==0 & $if1
bysort C_T2: sum JEMC2 if allvarsWLD==0 & $if1
sum JEMD2 JEMC1 S_T2 if allvarsWLD==0 & $if1
* Bivariate analysis
tab C_T2 FwldB if ${if1} & allvarsWLD==0, row nof
tab D_T2 FwldB if ${if1} & allvarsWLD==0, row nof
tab S_T2 FwldB if ${if1} & allvarsWLD==0, row nof
tab S2_T2 FwldB if ${if1} & allvarsWLD==0, row nof


* Control variables
global allvars 	"         i.agegrp i.sex i.married i.nchildR bem i._region i.maxqual i.housing i.money"
global allvars	"$allvars hlprba hlprbb hlprbc hlprbd hlprbe hlprbf hlprbg hlprbh hlprbi hlprbj hlprbk hlprbl hlprbm"
global allvars	"$allvars ghqB hlltaR hlltbR hlltcR hlltdR hospR i.srh i.hl2gp hlghq1 llsi i.jobsat i.secur_sat i.jboppsR i.jbmngr"
global allvars	"$allvars i.hoursGRP occpenR i.sector tempjob i.sme i.sic92_1A partnered sp_wldB sp_IBreceipt sp_employR"
global allvars	"$allvars i.soc90_1R i.nssec i.statusGRP i.wrkimp_last i.srclass i.boss_sat i.init_sat i.pay_sat i.JEMP2t"
xi: sum ${allvars} if ${if1} & allvarsWLD==0, sep(0)

global contvars "loginc hlghq1 status statusMR statusFR camsis CGstatus"
sum ${contvars} if $if1 & allvarsWLD==0, sep(0)

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
// WLD Trends

* Trends in WLD and related vars
capture drop prhlth
	gen prhlth = (hlstat==4 | hlstat==5) if hlstat<.
	label var prhlth "Poor or v poor hlth, recoded from HLSTAT"
estimates clear
/* svyset psu [pweight=wt_allwaves], strata(strata)
	eststo wldB_aw: 	svy: mean wldB if ${iftrend}, over(wave)
	eststo llsi_aw: 	svy: mean llsi if ${iftrend}, over(wave)
	eststo lhlstat_aw: 	svy: mean hlstat if ${iftrend}, over(wave)
	eststo prhlth_aw:	svy: mean prhlth if ${iftrend}, over(wave)
COMMENTED OUT*/
global iftrend "age>=20 & ((age<65 & sex==1) | (age<60 & sex==2)) & region2<=11"
svyset psu [pweight=xrwght], strata(strata)									// Decided to ignore the extension samples here, to make interpretation easier
	eststo wldB_xs: 	svy: mean wldB 		if ${iftrend}, over(wave)
	eststo wld_amtB_xs:	svy: mean wld_amtB 	if ${iftrend}, over(wave)
	eststo wld_type_xs: svy: mean wld_type	if ${iftrend}, over(wave)
	eststo llsi_xs:		svy: mean llsi 		if ${iftrend}, over(wave)
	eststo hlstat_xs:	svy: mean hlstat 	if ${iftrend}, over(wave)
	eststo prhlth_xs:	svy: mean prhlth 	if ${iftrend}, over(wave)
	// Among workers
global iftrend "age>=20 & ((age<65 & sex==1) | (age<60 & sex==2)) & region2<=11 & employR==1 & jbsemp==1 "
	eststo wldB_wk: 	svy: mean wldB if ${iftrend}, over(wave)
	eststo wld_amtB_wk:	svy: mean wld_amtB 	if ${iftrend}, over(wave)
	eststo wld_type_wk: svy: mean wld_type	if ${iftrend}, over(wave)
	eststo llsi_wk:		svy: mean llsi if ${iftrend}, over(wave)
	eststo hlstat_wk:	svy: mean hlstat if ${iftrend}, over(wave)
	eststo prhlth_wk:	svy: mean prhlth if ${iftrend}, over(wave)

* mean wldB if ${iftrend}, over(wave)
esttab wldB_xs wld_amtB_xs wld_type_xs llsi_xs prhlth_xs, not drop(1999 2004) nostar b(%4.3f) mtitles("WLD" "WLD-amt" "WLD-type" "LLSI" "Poor hlth") noeqlines nonum
esttab wldB_wk wld_amtB_wk wld_type_wk llsi_wk prhlth_wk, not drop(1999 2004) nostar b(%4.3f) mtitles("WLD" "WLD-amt" "WLD-type" "LLSI" "Poor hlth") noeqlines nonum



// Checking the trends in specific types of LSI (this helped me spot the 2001 problem)
svy: proportion hlprba-hlprbm if ${iftrend}, over(wave)
	matrix working = e(b)'
	forvalues i = 1/26	{
		local startcount = (`i'-1)*18+1
		local endcount 	 = `i'*18
		dis "`startcount' `endcount'"
		matrix output`i' = working[`startcount'..`endcount',1]
		/*end loop*/	}
	matrix outputAM = output2, output4, output6, output8, output10, output12, output14, output16, output18, output20, output22, output24, output26
svy: proportion hlprbn hlprbo if wave>=2001 & ${iftrend}, over(wave)
	matrix working = e(b)'
	forvalues i = 1/4	{
		local startcount = (`i'-1)*8+1
		local endcount 	 = `i'*8
		dis "`startcount' `endcount'"
		matrix output`i' = working[`startcount'..`endcount',1]
		/*end loop*/	}
	matrix outputNO = output2, output4


	
	

//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////////////////////////
// IB receipt analysis
//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////////////////////////////

sum FIBreceipt Fltsick FnonemployR if ${if1} & allvarsIB==0, separator(0)
tab C_T2 FIBreceipt if ${if1} & allvarsIB==0, row nof
tab D_T2 FIBreceipt if ${if1} & allvarsIB==0, row nof
tab S_T2 FIBreceipt if ${if1} & allvarsIB==0, row nof
tab S2_T2 FIBreceipt if ${if1} & allvarsIB==0, row nof


svyset psu [pweight=xrwght], strata(strata)									// Decided to ignore the extension samples here, to make interpretation easier
global iftrend1 "age>=20 & ((age<65 & sex==1) | (age<60 & sex==2)) & region2<=11 "
global iftrend2 "age>=20 & ((age<65 & sex==1) | (age<60 & sex==2)) & region2<=11 & employR==1 & jbsemp==1 "
global iftrend3 "age>=16 & ((age<65 & sex==1) | (age<60 & sex==2)) "
	eststo IBreceiptR1: 	svy: mean IBreceipt  if ${iftrend1}, over(wave)
	eststo ltsick1: 		svy: mean ltsick      if ${iftrend1}, over(wave)
	eststo nonemploy1: 		svy: mean nonemploy   if ${iftrend1}, over(wave)
	eststo IBreceiptR2: 	svy: mean FIBreceipt if ${iftrend2}, over(wave)
	eststo ltsick2: 		svy: mean Fltsick     if ${iftrend2}, over(wave)
	eststo nonemploy2: 		svy: mean Fnonemploy  if ${iftrend2}, over(wave)
	eststo IBreceiptR3: 	svy: mean IBreceipt  if ${iftrend3}, over(wave)
esttab IBreceiptR1 ltsick1 nonemploy1 , not drop(1999 2004) nostar b(%5.4f) mtitles("IB" "Ltsick" "Nonemployed" "IB-employees" "Ltsick-employees" "Nonemp-emp") noeqlines nonum
esttab IBreceiptR2 ltsick2 nonemploy2 , not drop(1999 2004) nostar b(%5.4f) mtitles("IB" "Ltsick" "Nonemployed" "IB-employees" "Ltsick-employees" "Nonemp-emp") noeqlines nonum
