/* MUCH OF THIS COMMENTED OUT TO AVOID RE-RUNNING GLLAMM

/////////////////////////////////////////////////
/////////////////////////////////////////////////
// Revised EB JEM file, created 26/4/2011
/////////////////////////////////////////////////
/////////////////////////////////////////////////

/* Changes from the 2_JEM_C1 & 2_JEM_D1 files
	Removed most of the covariates from the gllamm command line
	Then removed most covariates from the GLLLAPRED working
END CHANGES */
/* When moving to a new JEM, note that I haven't structured this in locals as I want to make sure this list is followed:
	1. Replace the outcome var (e.g. Cscale4), using Find&Replace
	2. Change the control variables that come after the outcome var for XTMIXED, GLLAMM, and the hypothetical individual
	3. Replace the size of the matrix between XTMIXED and GLLAMM - will change depending on the number of covariates (this is the main reason these lists aren't automated)
	4. Replace the soc classification - this needs to be in a new file with many changes.  [The code below needs changing for the soc?0_1_? dummies, as well as soc?0_BB and catlists]. 
	ALSO check that the MFP model above only produces a single term for age, rather than two terms (then need to change all code)
END OF NOTES */



/////////////////////////////////////////////////
// Preparation 
/////////////////////////////////////////////////
global extraif "strain4_eib<. & age>=20 & age<=60 & WORK==1 & _country~=3 & selfemp1==1 & soc90_allyr<. & fulltimeHRS<. & maxqual<. & sic92_1A<."
	include "$workdatadir\reweight_SOCallyrs.doi"     
	svyset [pweight=_w_eibsocR]	
capture gen pwt1 = _w_eibsocR		// For the GLLAMM commands below
catlist soc90_BB
keep if $extraif




/////////////////////////////////////////////////
// Control
/////////////////////////////////////////////////

// Running the model
global JEMvarlist "i.order soc90_1_2-soc90_1_9"
* Running XTMIXED as faster to feed this into GLLAMM than run GLLAMM from scratch
xi: xtmixed Cscale4 ${JEMvarlist} || soc90_BB: 						, mle			// Speeds up GLLAMM to feed this in from XTMIXED; needs following syntax - see http://www.stata.com/statalist/archive/2009-12/msg00446.html
	local matworking = e(k)
	local minusone	 = `matworking' - 1
	matrix a = e(b)
	matrix b = a 
	matrix b[1,`matworking'] = exp(a[1,`minusone'])		// I need to change the last two entries in e(b) - change these numbers if using additional covariates
	matrix b[1,`minusone'] = a[1,`matworking']			// "
time
xi: gllamm Cscale4 ${JEMvarlist}, link(identity) i(soc90_BB) nip(8) from(b) copy pweight(pwt)
time


// Getting the EB estimates for each occ, using GLLAPRED
local catlist "${catlist_soc90_BB}"
local count = 0
	preserve
		* Hypothetical individual - remember to use the DVs and dummy variables in the code above!
		bysort soc90_BB: gen mark = (_n==1)
			expand 4 if mark==1, gen(expanded)
			bysort soc90_BB expanded: gen newnum = _n if expanded==1		// For identifying the different hypothetical individuals
			replace uniqueid=""		if expanded==1
			replace Cscale4=. 		if expanded==1
			unab dummylist: _Iorder* 
			foreach dumvar in `dummylist'	{		// This sets all the dummies to zero, which is the equivalent of putting all of them to their base categorise (region==1, fulltime==1, maxqual==0, order==52, industry==1)
				replace `dumvar' = 0 if expanded==1
			/* loop */						}
			replace _Iorder_56=1						if expanded==1 & newnum==2						// Year=2001 rather than year=1992
			replace _Iorder_57=1						if expanded==1 & newnum==3						// Year=2006 rather than year=1992
		* Outputs
		gllapred JEMest, mu fsample
			*list uniqueid mark expanded newnum Cscale4 ageMFP_C1 _Imaxqual_1 JEMest if soc90_BB==101 & mark==1, nol 		// For when I was checking that GLLAPRED was working correctly 
		quietly tab soc90_BB
			scalar soc_cats = r(r)
			matrix C_JEM1 = J(soc_cats,3,.)
			global rowsC_JEM1 ""
		foreach lev in `catlist'	{
			local count = `count' + 1
			quietly sum JEMest if soc90_BB==`lev' & expanded==1 & newnum==1
				scalar mean1 = r(mean)
			quietly sum JEMest if soc90_BB==`lev' & expanded==1 & newnum==2
				scalar mean2 = r(mean)
			quietly sum JEMest if soc90_BB==`lev' & expanded==1 & newnum==3
				scalar mean3 = r(mean)
			if "`lev'"=="101"		dis "EB estimates by occ" ///
				_newline _col(40) "1992" _col(60) "2001" _col(80) "2006"  
			dis "soc90_BB `lev'" _col(40) mean1 _col(60) mean2 _col(80) mean3
			matrix C_JEM1[`count',1] = mean1
			matrix C_JEM1[`count',2] = mean2
			matrix C_JEM1[`count',3] = mean3
			global rowsC_JEM1 "$rowsC_JEM1 `lev'"
			/*loop*/				}
	restore
matrix rownames C_JEM1 = $rowsC_JEM1
matrix colnames C_JEM1 = "EB_C1992" "EB_C2001" "EB_C2006"
*pause "Every time you run a changed model, you need to (i) change the dummylist; and (ii) change the working to create the hypothetical age underlying this matrix"






/////////////////////////////////////////////////
// Demands
/* CHANGED FROM ABOVE
	C_JEM1 to D_JEM1 (name of matrices and output files)
	Cscale4 to Dscale3 (name of var being used)
	The column headings of the output matrix
END CHANGES */
/////////////////////////////////////////////////

// Running the model
global JEMvarlist "i.order soc90_1_2-soc90_1_9"
* Running XTMIXED as faster to feed this into GLLAMM than run GLLAMM from scratch
xi: xtmixed Dscale3 ${JEMvarlist} || soc90_BB: 						, mle			// Speeds up GLLAMM to feed this in from XTMIXED; needs following syntax - see http://www.stata.com/statalist/archive/2009-12/msg00446.html
	local matworking = e(k)
	local minusone	 = `matworking' - 1
	matrix a = e(b)
	matrix b = a 
	matrix b[1,`matworking'] = exp(a[1,`minusone'])		// I need to change the last two entries in e(b) - change these numbers if using additional covariates
	matrix b[1,`minusone'] = a[1,`matworking']			// "
time
xi: gllamm Dscale3 ${JEMvarlist}, link(identity) i(soc90_BB) nip(8) from(b) copy pweight(pwt)
time

// Getting the EB estimates for each occ, using GLLAPRED
local catlist "${catlist_soc90_BB}"
local count = 0
	preserve
		* Hypothetical individual - remember to use the DVs and dummy variables in the code above!
		bysort soc90_BB: gen mark = (_n==1)
			expand 4 if mark==1, gen(expanded)
			bysort soc90_BB expanded: gen newnum = _n if expanded==1		// For identifying the different hypothetical individuals
			replace uniqueid=""		if expanded==1
			replace Dscale3=. 		if expanded==1
			unab dummylist: _Iorder* 
			foreach dumvar in `dummylist'	{		// This sets all the dummies to zero, which is the equivalent of putting all of them to their base categorise (region==1, fulltime==1, maxqual==0, order==52, industry==1)
				replace `dumvar' = 0 if expanded==1
			/* loop */						}
			replace _Iorder_56=1						if expanded==1 & newnum==2						// Year=2001 rather than year=1992
			replace _Iorder_57=1						if expanded==1 & newnum==3						// Year=2006 rather than year=1992
		* Outputs
		gllapred JEMest, mu fsample
			*list uniqueid mark expanded newnum Dscale3 ageMFP_C1 _Imaxqual_1 JEMest if soc90_BB==101 & mark==1, nol 		// For when I was checking that GLLAPRED was working correctly 
		quietly tab soc90_BB
			scalar soc_cats = r(r)
			matrix D_JEM1 = J(soc_cats,3,.)
			global rowsD_JEM1 ""
		foreach lev in `catlist'	{
			local count = `count' + 1
			quietly sum JEMest if soc90_BB==`lev' & expanded==1 & newnum==1
				scalar mean1 = r(mean)
			quietly sum JEMest if soc90_BB==`lev' & expanded==1 & newnum==2
				scalar mean2 = r(mean)
			quietly sum JEMest if soc90_BB==`lev' & expanded==1 & newnum==3
				scalar mean3 = r(mean)
			if "`lev'"=="101"		dis "EB estimates by occ" ///
				_newline _col(40) "1992" _col(60) "2001" _col(80) "2006"  
			dis "soc90_BB `lev'" _col(40) mean1 _col(60) mean2 _col(80) mean3
			matrix D_JEM1[`count',1] = mean1
			matrix D_JEM1[`count',2] = mean2
			matrix D_JEM1[`count',3] = mean3
			global rowsD_JEM1 "$rowsD_JEM1 `lev'"
			/*loop*/				}
	restore
matrix rownames D_JEM1 = $rowsD_JEM1
matrix colnames D_JEM1 = "EB_D1992" "EB_D2001" "EB_D2006"
*pause "Every time you run a changed model, you need to (i) change the dummylist; and (ii) change the working to create the hypothetical age underlying this matrix"






/////////////////////////////////////////////////
// Outputting (newly automated in this version)
/////////////////////////////////////////////////

clear
svmat2 C_JEM1, names(col) rnames(soc90_BB)
svmat2 D_JEM1, names(col)
	reshape long EB_C EB_D, i(soc90_BB) j(wave)
	// creating multiple observations for each soc90_BB
	expand 17 if wave==1992, gen(expanded)
	bysort soc90_BB wave expanded: replace wave = wave - 2 + _n if expanded==1
	bysort soc90_BB wave (expanded): gen dup=_n
	drop if dup==2
	// interpolating
	foreach char in EB_C EB_D	{
		replace `char' = . if expanded==1
		by soc90_BB: ipolate `char' wave, gen(i`char')
		replace i`char' = i`char'[_n + 1] if wave==1991
		/**/				}
// merging
keep soc90_BB wave i*
destring soc90_BB, replace
save `"$workdatadir\EB_JEM"', replace


*/

* Final merge in
use "JEM_$filename", replace
	merge m:1 soc90_BB wave using `"$workdatadir\EB_JEM"', gen(merge_EB)		// On 26/4/11, there were no soc90_BB==101 in wave==1992 - but this isn't an error
	drop if _pid==.
	drop merge_EB

* Labelling the JEMs
foreach char in C D S P	{
	label var JEM`char'1 "`char' scale from JEM, occ only"
	label var JEM`char'2 "`char' scale from JEM, occ & year"
	label var JEM`char'3 "`char' scale from JEM, soc1Xyear + socBB"
	label var JEM`char'4 "`char' scale from JEM, occ, year, industry, ed"
	label var JEM`char'5 "`char' scale from JEM, occ, year, all covariates"
	label var JEM`char'6 "`char' scale from JEM, occXind (BB) & year"
	label var JEM`char'7 "`char' scale from JEM, occ only exc SS06 (for WinBUGS)"
	label var JEM`char'8 "`char' scale from JEM, soc1Xyear + socBB exc SS06 (for WinBUGS)"
	/**/				}
	label var iEB_C "C scale from EB JEM, occ & year"
	label var iEB_D "D scale from EB JEM, occ & year"
	renvars iEB*, suffix("_EB")
	renvars iEB*, presub("iEB_" "JEM") 

* Lagged versions
tsset _pid wave
unab lagvars: JEM*
foreach var in `lagvars' {
	local varlab: var label `var'
	gen L`var' = L.`var'
		label var L`var' "t-1 `varlab'"
	order ?`var', after(`var')
/*end of loop*/																	}

