///////////////////////////////////////////////////////
///////////////////////////////////////////////////////
// The fixed effects (rather than Empirical Bayes) JEMs
// Created 25/4/2011
///////////////////////////////////////////////////////
///////////////////////////////////////////////////////

ren fulltimeHRS fulltimeH
global extraif "age>=20 & age<65 & WORK==1 & _country~=3 & selfemp1==1 & soc90_allyr<. & fulltimeH<. & maxqual<. & sic92_1A<."
	include "$workdatadir\reweight_SOCallyrs.doi"     
	svyset [pweight=_w_eibsocR]	
// Giving vars the same name as in BHPS
drop agegrp
recode age (0/17=.) (18/24=1 "18-24") (25/29=2 "25-29") (30/34=3 "30-34") (35/39=4 "35-39") (40/44=5 "40-44") (45/49=6 "45-49") (50/54=7 "50/54") ///
	(55/59=8 "55-59") (60/64=9 "60-64") (65/max=10 "65+") (else=.), gen(agegrp)
	
/////////////////////////////////////////////////
// The regression models underlying the JEMs
/////////////////////////////////////////////////

global covariates1	"i.sic92_1A i.maxqual"		// Can't use sector as no nonprofit response cat in EiB
global covariates2	"i.agegrp i.sex i.fulltimeH"		

* Control
eststo C1: reg Cscale4 ibn.soc90_BB 													[pweight=_w_eibsocR], nocons
eststo C2: reg Cscale4 ibn.soc90_BB ib57.order 											[pweight=_w_eibsocR], nocons
eststo C3: reg Cscale4 ibn.soc90_BB ibn.soc90_1_allyr#ib57.order 						[pweight=_w_eibsocR], nocons
eststo C4: reg Cscale4 ibn.soc90_BB ib57.order ${covariates1}							[pweight=_w_eibsocR], nocons
eststo C5: reg Cscale4 ibn.soc90_BB ib57.order ${covariates1} ${covariates2}			[pweight=_w_eibsocR], nocons
eststo C6: reg Cscale4 ibn.soc90_BBR ib57.order 										[pweight=_w_eibsocR], nocons
eststo C7: reg Cscale4 ibn.soc90_BB 													if order~=57, nocons
eststo C8: reg Cscale4 ibn.soc90_BB ibn.soc90_1_allyr#ib57.order						if order~=57, nocons

* Demands
eststo D1: reg Dscale3 ibn.soc90_BB 													[pweight=_w_eibsocR], nocons
eststo D2: reg Dscale3 ibn.soc90_BB ib57.order 											[pweight=_w_eibsocR], nocons
eststo D3: reg Dscale3 ibn.soc90_BB ibn.soc90_1_allyr#ib57.order 						[pweight=_w_eibsocR], nocons
eststo D4: reg Dscale3 ibn.soc90_BB ib57.order ${covariates1}							[pweight=_w_eibsocR], nocons
eststo D5: reg Dscale3 ibn.soc90_BB ib57.order ${covariates1} ${covariates2}			[pweight=_w_eibsocR], nocons
eststo D6: reg Dscale3 ibn.soc90_BBR ib57.order 										[pweight=_w_eibsocR], nocons
eststo D7: reg Dscale3 ibn.soc90_BB 													if order~=57, nocons
eststo D8: reg Dscale3 ibn.soc90_BB ibn.soc90_1_allyr#ib57.order						if order~=57, nocons

* Strain
eststo S1: reg Scont ibn.soc90_BB 														[pweight=_w_eibsocR], nocons
eststo S2: reg Scont ibn.soc90_BB ib57.order 											[pweight=_w_eibsocR], nocons
eststo S3: reg Scont ibn.soc90_BB ibn.soc90_1_allyr#ib57.order 							[pweight=_w_eibsocR], nocons
eststo S4: reg Scont ibn.soc90_BB ib57.order ${covariates1}								[pweight=_w_eibsocR], nocons
eststo S5: reg Scont ibn.soc90_BB ib57.order ${covariates1} ${covariates2}				[pweight=_w_eibsocR], nocons
eststo S6: reg Scont ibn.soc90_BBR ib57.order 											[pweight=_w_eibsocR], nocons
eststo S7: reg Scont ibn.soc90_BB 														if order~=57, nocons
eststo S8: reg Scont ibn.soc90_BB ibn.soc90_1_allyr#ib57.order							if order~=57, nocons

* Physicality
eststo P1: reg Pscale2 ibn.soc90_BB 													[pweight=_w_eibsocR], nocons
eststo P2: reg Pscale2 ibn.soc90_BB ib57.order 											[pweight=_w_eibsocR], nocons
eststo P3: reg Pscale2 ibn.soc90_BB ibn.soc90_1_allyr#ib57.order 						[pweight=_w_eibsocR], nocons
eststo P4: reg Pscale2 ibn.soc90_BB ib57.order ${covariates1}							[pweight=_w_eibsocR], nocons
eststo P5: reg Pscale2 ibn.soc90_BB ib57.order ${covariates1} ${covariates2}			[pweight=_w_eibsocR], nocons
eststo P6: reg Pscale2 ibn.soc90_BBR ib57.order 										[pweight=_w_eibsocR], nocons
eststo P7: reg Pscale2 ibn.soc90_BB 													if order~=57, nocons
eststo P8: reg Pscale2 ibn.soc90_BB ibn.soc90_1_allyr#ib57.order						if order~=57, nocons

esttab C* D* S* P* using "$JEMdir/JEM_fixed", csv replace varwidth(30) not nostar nonum r2 order(*sic* *qual* *age* *sex* *H*) mtitles (C1 C2 C3 C4 C5 C6 C7 C8 D1 D2 D3 D4 D5 D6 D7 D8 S1 S2 S3 S4 S5 S6 S7 S8 P1 P2 P3 P4 P5 P6 P7 P8)


///////////////////////////////////////////////////
// Trying to clean this up in Stata rather than Excel (so can impute based on year more easily)

// Preparing the original data file
global JEMvars		"soc90_BB soc90_BBR maxqual sic92_1A agegrp sex fulltimeH"
use "$filename", replace
	keep _pid wave soc90_1R $JEMvars 
	save `"$JEMv2file"', replace

	
// Importing the JEMs
clear
insheet using "$JEMdir\JEM_fixed.csv", comma case
ren v1 text
replace text=rtrim(text)
drop if text=="N" | text=="R-sq"


// Text manipulation
gen hash = strpos(text, "#")
	gen part1 = substr(text,1,hash-1) if hash>0
	replace part1 = text if hash==0
// Part 1
gen dot1 = strpos(part1, ".")
gen code1 = substr(part1,1,dot1-1)
replace code1 = subinstr(code1,"o","",.)
replace code1 = subinstr(code1,"b","",.)
gen var1 = substr(part1,dot1+1,.)
// Part 2
gen part2 = substr(text, hash+1,.) if hash>0
gen dot2 = strpos(part2, ".") if hash>0
gen code2 = substr(part2,1,dot2-1) if hash>0
replace code2 = subinstr(code2,"o","",.) if hash>0
replace code2 = subinstr(code2,"b","",.) if hash>0
gen var2 = substr(part2,dot2+1,.)
// Tidying up
drop dot? part? hash
destring code?, replace
outsheet using "$JEMdir\JEM_fixed_cleaned.csv", comma replace


// Fixing the problem of the wrong base category for the ?8 models (should be 56, but then requires changes to other models as can't vary baseline category in ESTTAB)
drop in 386/394							// The #o.soc90_1_allyr#56o.order variables
foreach V in C D P S	{
	replace `V'8 = 0 if var1=="soc90_1_allyr" & code2==56
	replace `V'8 = . if var1=="soc90_1_allyr" & code2==57
	/**/				}


// Merging in each covariate, one at a time
foreach var in $JEMvars	{
	preserve
		tempfile JEM`var'
		keep if var1=="`var'" & var2==""
		keep C* D* S* P* code1
		renvars C* D* S* P*, prefix(`var')
		ren code1 `var'
		save "`JEM`var''"
		use `"$JEMv2file"', replace
		merge m:1 `var' using "`JEM`var''", gen(merge_`var')
		save, replace
		*pause
	restore
	/**/				}
// Imputing by year
preserve
	tempfile JEMwave
	keep if var1=="order" & var2==""
	// creating black rows for missing waves
	recode code1 (53=1992) (55=1997) (56=2001) (57=2006) if var1=="order", gen(wave)
	expand 17 if wave==1992, gen(expanded)
	bysort wave expanded: replace wave = wave - 2 + _n if expanded==1
	bysort wave (expanded): gen dup=_n
	drop if dup==2
	// interpolating
		forvalues i = 1/8	{
			foreach char in C D S 		{
				replace `char'`i' = . if expanded==1
				ipolate `char'`i' wave, gen(i`char'`i')
				replace i`char'`i' = i`char'`i'[_n + 1] if wave==1991
				/**/					}
			foreach char in P 			{					// Separated out to extrapolate before 2001 (assumed the same slight trend as 2001-2006)
				replace `char'`i' = . if expanded==1
				ipolate `char'`i' wave, gen(i`char'`i') epolate
				*replace i`char'`i' = i`char'`i'[_n + 1] if wave==1991		// Not needed given that I'm extrpolating
				/**/					}
		/**/			}
	// merging
	*pause
	renvars i*, prefix(wave_)
	keep wave*
	save "`JEMwave'"
	use `"$JEMv2file"', replace
	merge m:1 wave using "`JEMwave'", gen(merge_wave)
	save, replace
restore
// Imputing by 1-digit occ X year
preserve
	tempfile JEMwaveXocc
	keep if var1=="soc90_1_allyr"
	// creating black rows for missing waves
	recode code2 (53=1992) (55=1997) (56=2001) (57=2006), gen(wave)
	expand 17 if wave==1992, gen(expanded)
	bysort code1 wave expanded: replace wave = wave - 2 + _n if expanded==1
	bysort code1 wave (expanded): gen dup=_n
	drop if dup==2
	// interpolating
		forvalues i = 1/8	{
			foreach char in C D S P 	{
				replace `char'`i' = . if expanded==1
				bysort code1 (wave): ipolate `char'`i' wave, gen(i`char'`i')
				bysort code1 (wave): replace i`char'`i' = i`char'`i'[_n + 1] if wave==1991
				/**/					}
		/**/				}
	// merging
	renvars i*, prefix(wXocc_)
	keep wave wXocc* code1
	ren code1 soc90_1R
	save "`JEMwaveXocc'"
	use `"$JEMv2file"', replace
	merge m:1 wave soc90_1R using "`JEMwaveXocc'", gen(merge_wXocc)
	save, replace
	*pause
restore


// Combining these into imputed single values of Control
use `"$JEMv2file"', replace
global ifJEM	"soc90_BB<. & maxqual<. & sic92_1A<. & agegrp<. & sex<. & fulltimeH<. & wave<=2006 & agegrp<10"
forvalues i = 1/8	{
	foreach char in C D S P 	{
		egen JEM`char'`i'= rowtotal(*`char'`i') if $ifJEM
		/**/					}
	/**/			}
/* CHECKS
	tabstat JEMC* JEMD*, by(wave)
	tabstat JEMS* JEMP*, by(wave)
	tabstat JEMC* JEMD*, by(soc90_1R) lab(8)
	tabstat JEMS* JEMP*, by(soc90_1R) lab(8)
	corr JEMC* JEMD*
	corr JEMS* JEMP*
END CHECKS */
replace JEMP3=. 							// This is because I would have to change the occXwave code to extrapolate (rather than just interpolate) Physicality for the pre-2001 period
order _pid wave JEM*, first
save, replace


// Final merge into full dataset
use "$filename", replace
	merge 1:1 _pid wave using `"$JEMv2file"'
	drop soc90_BBC1-_merge
	* P3 is *deliberately* left blank - see a few lines above


	
